package com.xp.arouter;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.widget.Toast;

import com.alibaba.android.arouter.facade.Postcard;
import com.alibaba.android.arouter.launcher.ARouter;
import com.google.gson.Gson;
import com.wgmf.library.utils.AssetsUtil;
import com.xp.arouter.IInterceptor.InterruptCallback;
import com.xp.arouter.model.PCClass;

import rx.Observable;
import rx.Subscriber;
import rx.android.schedulers.AndroidSchedulers;
import rx.functions.Action1;

/**
 * @author xiep
 */
public class RouterCommonUtil {

    private static void toastInterruptInfo(final Activity activity, final Postcard postcard) {
        if (postcard.getTag() instanceof String) {
            Observable.create(new Observable.OnSubscribe<String>() {
                @Override
                public void call(Subscriber<? super String> subscriber) {
                    subscriber.onNext((String) postcard.getTag());
                }
            }).observeOn(AndroidSchedulers.mainThread()).subscribe(new Action1<String>() {
                @Override
                public void call(String s) {
                    if (!TextUtils.isEmpty(s) && activity != null) {
                        Toast.makeText(activity, (String) postcard.getTag(), Toast.LENGTH_SHORT).show();
                    }
                }
            });
        }
    }

    public static void startFunctionActivityResult(final Activity activity, int flag, Long resId, Bundle mBundle, int resultCode) {
        String funcionName = getFunctionName(flag, resId, activity);
        ARouter.getInstance().build(funcionName)
                .with(mBundle)
                .navigation(activity, resultCode, new InterruptCallback() {
                    @Override
                    public void onInterrupt(Postcard postcard) {
                        toastInterruptInfo(activity, postcard);
                    }
                });
    }

    /**
     * Activity页面跳转
     */
    public static void startFunctionActivity(final Activity activity, int flag, Long resId, Bundle mBundle) {
        String funcionName = getFunctionName(flag, resId, activity);
        ARouter.getInstance().build(funcionName)
                .with(mBundle)
                .navigation(activity, new InterruptCallback() {
                    @Override
                    public void onInterrupt(Postcard postcard) {
                        toastInterruptInfo(activity, postcard);
                    }
                });
    }

    /**
     * Broadcast页面跳转
     */
    public static void startFunctionActivity(final Context context, int flag, Long resId, Bundle mBundle) {
        String funcionName = getFunctionName(flag, resId, context);
        ARouter.getInstance().build(funcionName)
                .with(mBundle)
                .navigation(context, new InterruptCallback() {
                    @Override
                    public void onInterrupt(Postcard postcard) {

                    }
                });
    }

    /**
     * 广告页面跳转
     */
    public static void startFunctionActivity(final Context context, String functionName) {
        ARouter.getInstance().build(functionName)
                .navigation(context, new InterruptCallback() {
                    @Override
                    public void onInterrupt(Postcard postcard) {

                    }
                });
    }

    @NonNull
    private static String getFunctionName(int flag, Long resId, Context context) {
        String funcionName = RouterParams.URL_HTML5DETAILACTIVITY;
        if (flag == 0) {
            funcionName = RouterParams.URL_HTML5DETAILACTIVITY;
        }
        if (flag == -1) {
            funcionName = RouterParams.URL_DATALISTACTIVITY;
        } else if (flag == -2) {
            funcionName = RouterParams.URL_SELECTORSTOREGETNEARESTACTIVITY;
        } else if (flag == -3) {
            funcionName = RouterParams.URL_HOMEACTIVITY;
        } else if (flag == -4) {
            funcionName = RouterParams.URL_LOGINACTIVITY;
        } else if (flag == -5) {
            funcionName = RouterParams.URL_MESSAGEACTIVITY;
        } else if (flag == -6) {
            funcionName = RouterParams.URL_SOUNDRECORDER;
        } else if (flag == -7) {
            funcionName = RouterParams.URL_PART_TIME_LOGIN_ACTIVITY;
        } else if (flag == -8) {
            funcionName = RouterParams.URL_DEVELOPERACTIVITY;
        } else if (flag == -9) {
            funcionName = RouterParams.URL_URL_SELECTORCITYSTOREGETNEARESTACTIVITY;
        } else {
            String fuction = AssetsUtil.getFromAssets(context, "FunctionData.json");
            PCClass functions = new Gson().fromJson(fuction, PCClass.class);
            if (null != functions && null != functions.getResultList()) {
                for (int i = 0; i < functions.getResultList().size(); i++) {
                    if (null != resId && resId == functions.getResultList().get(i).getSid()) {
                        funcionName = functions.getResultList().get(i).getName();
                    }
                }
            }
        }
        return funcionName;
    }
}