package com.wgmf.yxgj.module.business.managecapital.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;
import com.wgmf.yxgj.module.business.managecapital.service.request.GoodsReceiptsUpdateRequest;

import java.lang.ref.WeakReference;

/**
 * 资材管理网络请求服务
 */
@SuppressWarnings("all")
public class CapitalManagerService extends BaseService {
    private static BaseSingleton<CapitalManagerService, Void> mMainService = new BaseSingleton<CapitalManagerService, Void>() {
        @Override
        protected CapitalManagerService create(Void var1) {
            return new CapitalManagerService();
        }
    };

    public static CapitalManagerService getInstance() {
        return mMainService.get(null);
    }

    private CapitalManagerService() {
    }

    /**
     * GET /capitalManagement/findCapitalReceipts 资材收货查询
     */
    public void requestFindCapitalReceipts(final String staffId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_RECEIPTS;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_CAPITAL_RECEIPTS + "?" + "staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /capitalManagement/findCapitalReceiptsDetail 资材收货明细查询
     */
    public void requestFindCapitalReceiptsDetail(final String capitalReceiptsId, final String storeNo, final String isNotOeDBFlag,
                                                 ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_RECEIPTS_DETAIL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_CAPITAL_RECEIPTS_DETAIL + "?" + "capitalReceiptsId=" + capitalReceiptsId + "&storeNo=" + storeNo + "&isNotOeDBFlag=" + isNotOeDBFlag;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /capitalManagement/updateCapitalReceipts 资材收货确认
     */
    public void requestUpdateCapitalReceipts(final String capitalReceiptsId, final String operateStaffId, final String isNotOeDBFlag,
                                             ResultData.BusinessCallback callback) {
        GoodsReceiptsUpdateRequest request = new GoodsReceiptsUpdateRequest(capitalReceiptsId, operateStaffId, isNotOeDBFlag);
        request.taskID = BusinessID.CapitalManager.MSG_ON_UPDATE_CAPITAL_RECEIPTS;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_UPDATE_CAPITAL_RECEIPTS;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostRequest(request);
    }

    /**
     * GET /capitalManagement/findCapitalStockSearch 资材库存查询
     */
    public void requestFindCapitalStockSearch(final String staffId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_STOCK_SEARCH;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_CAPITAL_STOCK_SEARCH + "?" + "staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /capitalManagement/findCapitalStockDetail 资材库存查询明细
     */
    public void requestFindCapitalStockDetail(final String storeNo, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_STOCK_DETAIL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_CAPITAL_STOCK_DETAIL + "?" + "storeNo=" + storeNo;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /capitalManagement/capitalStockTransferred 资材调拨
     */
    public void requestSaveCapitalStockTransferred(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.CapitalManager.MSG_ON_SAVE_CAPITAL_STOCK_TRANSFERRED;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_CAPITAL_STOCK_TRANSFERRED;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_RECEIPTS:
                case BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_RECEIPTS_DETAIL:
                case BusinessID.CapitalManager.MSG_ON_UPDATE_CAPITAL_RECEIPTS:
                case BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_STOCK_SEARCH:
                case BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_STOCK_DETAIL:
                case BusinessID.CapitalManager.MSG_ON_SAVE_CAPITAL_STOCK_TRANSFERRED: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}