package com.wgmf.yxgj.module.business.managecapital.ui;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ListView;

import com.bumptech.glide.Glide;
import com.google.gson.Gson;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.module.business.managecapital.R;
import com.wgmf.yxgj.module.business.managecapital.model.CapitalReceiptsDetailsEntity;
import com.wgmf.yxgj.module.business.managecapital.model.CapitalReceiptsDetailsList;
import com.wgmf.yxgj.module.business.managecapital.service.CapitalManagerService;

import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * 资材调入调出资材选择列表
 */
public class CapitalTransferredInOrOutCapitalListActivity extends BaseParentAct implements View.OnClickListener, CapitalTransferredInOrOutAddAdapter.OnAdapterClick {

    private ListView mListView;
    private CapitalTransferredInOrOutAddAdapter adapter;
    public static final int RESULTCODE = BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_STOCK_DETAIL;
    /**
     * 全部常用功能集合
     */
    private List<CapitalReceiptsDetailsEntity> itemData;
    /**
     * 选中的集合
     */
    private List<CapitalReceiptsDetailsEntity> listData;
    private Button publicComfirmBtnTotalLeftBtn;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.public_list_view);
        initTitle();
        initView();
        initContent();
        initData();
    }

    private void initData() {
        listData = (List<CapitalReceiptsDetailsEntity>) getIntent().getSerializableExtra("listData");
        //移除已经添加过的产品
    }

    private void initContent() {
        String storeNo = getIntent().getStringExtra("storeNo");

        CapitalManagerService.getInstance().requestFindCapitalStockDetail(storeNo, CapitalTransferredInOrOutCapitalListActivity.this);
    }

    @Override
    public void initTitle() {
        super.initTitle();
        homeTitleText.setText("选择资材");
        homeTitleMoreLl.setVisibility(View.VISIBLE);
        homeTitleBackLl.setVisibility(View.VISIBLE);
    }

    private void initView() {
        EventBus.getDefault().register(this);
        itemData = new ArrayList<>();
        listData = new ArrayList<>();
        mListView = (ListView) findViewById(R.id.public_list_view_lv);
        //为列表添加空布局
        View emptyView = findViewById(R.id.public_list_view_empty_ll);
        ImageView publicListViewEmptyIv = (ImageView) findViewById(R.id.public_list_view_empty_iv);
        Glide.with(this).load(R.drawable.img_load_fail).asGif().into(publicListViewEmptyIv);
        mListView.setEmptyView(emptyView);
        adapter = new CapitalTransferredInOrOutAddAdapter(this, this, itemData);
        mListView.setAdapter(adapter);
//        mListView.setOnItemClickListener(this);

        LinearLayout publicComfirmBtnTotalLl = (LinearLayout) findViewById(R.id.public_comfirm_btn_total_ll);
        publicComfirmBtnTotalLeftBtn = (Button) findViewById(R.id.public_comfirm_btn_total_left_btn);
        Button publicComfirmBtnTotalRightBtn = (Button) findViewById(R.id.public_comfirm_btn_total_right_btn);
        publicComfirmBtnTotalLl.setVisibility(View.VISIBLE);
        publicComfirmBtnTotalLeftBtn.setOnClickListener(this);
        publicComfirmBtnTotalRightBtn.setOnClickListener(this);
    }

    @Subscribe
    public void onEventMainThread(CapitalReceiptsDetailsList item) {
        if (item != null && !item.getResultList().isEmpty()) {
            //清空数据，保证每次显示的都是接口返回的数据
            itemData.clear();
            itemData.addAll(item.getResultList());
            adapter = new CapitalTransferredInOrOutAddAdapter(this, this, itemData);
            mListView.setAdapter(adapter);
            adapter.notifyDataSetChanged();
        }
    }

    @Override
    public void onClick(View v) {
        if (v.getId() == R.id.public_comfirm_btn_total_right_btn) {
            Intent intent = new Intent();
            intent.putExtra("listData", (Serializable) listData);
            setResult(RESULTCODE, intent);
            this.finish();
        }
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_STOCK_DETAIL: {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        CapitalReceiptsDetailsList mCapitalReceiptsDetailsList = new Gson().fromJson(msg, CapitalReceiptsDetailsList.class);
                        Log.d(TAG, "mCapitalReceiptsDetailsList=" + mCapitalReceiptsDetailsList.toString());
                        if (!mCapitalReceiptsDetailsList.getResultList().isEmpty()) {
                            EventBus.getDefault().post(mCapitalReceiptsDetailsList);
                        }
                    } else {
                        showMsg(result.getResultInfo());
                    }
                }
                break;
                default:
                    break;
            }
        }
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        EventBus.getDefault().unregister(this);
    }

    @Override
    public void onItemClick(List<CapitalReceiptsDetailsEntity> itemData, int position) {
        if (null != itemData) {
            listData.clear();//先清除所选数据
//            itemData.get(position).setChoice(!itemData.get(position).isChoice());
            for (int i = 0; i < itemData.size(); i++) {
                if (itemData.get(i).isChoice()) {
                    listData.add(itemData.get(i));
                }
            }
            adapter.notifyDataSetChanged();
            publicComfirmBtnTotalLeftBtn.setText("已选（" + listData.size() + "）");
        }
    }
}