package com.wgmf.yxgj.module.business.manageproduct.ui;

import android.content.Context;
import android.content.DialogInterface;
import android.graphics.Color;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.View.OnFocusChangeListener;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.library.utils.Arith;
import com.wgmf.library.utils.StringUtil;
import com.wgmf.yxgj.base.BaseActivity;
import com.wgmf.yxgj.dialog.AdDialog;
import com.wgmf.yxgj.dialog.PublicConformTipDialog;
import com.wgmf.yxgj.model.OrderGoodsAuditDetail;
import com.wgmf.yxgj.module.business.manageproduct.R;
import com.wgmf.yxgj.widgets.TextView.MarqueeTextView;

import java.util.Collections;
import java.util.Comparator;
import java.util.List;

/**
 * 订货审核明细
 *
 * @author XiePing
 */
@SuppressWarnings("all")
class GoodsAuditingDetailsAdapter extends BaseAdapter {
    private List<OrderGoodsAuditDetail> list;
    private BaseActivity context;
    private static final String PRODUCT_TYPE = "产成品";

    private CountFocusChangeListener countFocusChangeListener;

    public interface CountFocusChangeListener {
        /**
         * 不合法输入时，只有超过次大订货量是可以提交的
         */
        void onOverMaxSuggestOrderGoodsNum();

    }

    GoodsAuditingDetailsAdapter(List<OrderGoodsAuditDetail> list, BaseActivity context, CountFocusChangeListener countFocusChangeListener) {
        this.list = list;
        this.context = context;
        this.countFocusChangeListener = countFocusChangeListener;
        initList();
    }

    /**
     * 按是否是新添加排序，非新添加排在前面
     */
    private void initList() {
        Collections.sort(list, new Comparator<OrderGoodsAuditDetail>() {
            @Override
            public int compare(OrderGoodsAuditDetail lhs,
                               OrderGoodsAuditDetail rhs) {
                if (lhs.getType() > rhs.getType()) {
                    return 1;
                } else if (lhs.getType() == rhs.getType()) {
                    return 0;
                } else {
                    return -1;
                }
            }
        });
        Collections.sort(list, new Comparator<OrderGoodsAuditDetail>() {
            @Override
            public int compare(OrderGoodsAuditDetail lhs, OrderGoodsAuditDetail rhs) {
                if (lhs.getCreateTime() < rhs.getCreateTime()) {
                    return 1;
                } else if (lhs.getCreateTime() == rhs.getCreateTime()) {
                    return 0;
                } else {
                    return -1;
                }
            }
        });
    }

    @Override
    public int getCount() {
        return list == null ? 0 : list.size();
    }

    @Override
    public Object getItem(int position) {
        return list == null ? null : list.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(final int position, View convertView, ViewGroup parent) {
        final ViewHolder holder;
        convertView = null;
        if (convertView == null) {
            holder = new ViewHolder();
            convertView = LayoutInflater.from(context).inflate(R.layout.second_order_goods_menu_item2, null);
            holder.name = (MarqueeTextView) convertView.findViewById(R.id.goods_name);
            holder.tvShdl = (TextView) convertView.findViewById(R.id.tv_shdl);
            holder.unit = (MarqueeTextView) convertView.findViewById(R.id.goods_unit);
            holder.goodsType = (MarqueeTextView) convertView.findViewById(R.id.goods_type);
            holder.qtyCount = (TextView) convertView.findViewById(R.id.qty_count);
            holder.maxqtyCount = (TextView) convertView.findViewById(R.id.max_qty_count);
            holder.llShowDetail = (LinearLayout) convertView.findViewById(R.id.ll_show_detail);
            holder.count = (EditText) convertView.findViewById(R.id.goods_count);
            holder.tvKucun = (TextView) convertView.findViewById(R.id.tv_kucun);
            holder.tvCyl = (TextView) convertView.findViewById(R.id.tv_cyl);
            holder.tvXiaoliang = (TextView) convertView.findViewById(R.id.tv_xiaoliang);
            holder.tvAlreadyOrder = (TextView) convertView.findViewById(R.id.tv_already_order);
            holder.tvLastMonthOrder = (TextView) convertView.findViewById(R.id.tv_last_month_order);
            holder.add = (ImageButton) convertView.findViewById(R.id.goods_plus);
            holder.reduce = (ImageButton) convertView.findViewById(R.id.goods_decrease);
            holder.productIsNotStock = (TextView) convertView.findViewById(R.id.product_is_not_stock);
            holder.productImg = (TextView) convertView.findViewById(R.id.product_img);
            holder.maxqtyCount.setVisibility(View.INVISIBLE);

            convertView.setTag(holder);
        } else {
            holder = (ViewHolder) convertView.getTag();
        }
        final OrderGoodsAuditDetail data = list.get(position);

        holder.count.setTag(position);

        if (data.isProductIsNotStock()) {
            holder.productIsNotStock.setVisibility(View.VISIBLE);
        } else {
            holder.productIsNotStock.setVisibility(View.INVISIBLE);
        }
        if (!TextUtils.isEmpty(data.getProductImage())) {
            holder.productImg.setVisibility(View.VISIBLE);
        } else {
            holder.productImg.setVisibility(View.INVISIBLE);
        }
        if ("".equals(data.getProductUnit()) || null == data.getProductUnit() || "null".equals(data.getProductUnit())) {
            holder.unit.setText("(" + "包" + ")");
        } else {
            holder.unit.setText("(" + data.getProductUnit() + " " + data.getProductCode() + ")");
        }
        holder.name.setText(data.getProductName());
        //订货数量，getOrderGoodsNum
        holder.goodsType.setText(data.getProductBigFatherType());
        holder.tvShdl.setText("订货数量:" + data.getOrderGoodsNum() + "");
        holder.tvCyl.setText("库存天数:" + StringUtil.formatDouble(calculatorCyDay(data, data.getOrderGoodsAuditNum()), "0") + "(天)");
        //库存天数：四舍五入取整
        holder.tvKucun.setText("库存+在途:" + data.getProductStockNum() + "");
        holder.tvXiaoliang.setText("月用量:" + data.getProductLastMonthSaleNum() + "");
        holder.count.setText("" + StringUtil.formatDouble(data.getOrderGoodsAuditNum(), "0.00") + "");
        //订货审核数量，orderGoodsAuditNum
        holder.count.setSelection(holder.count.getText().length());
        holder.qtyCount.setText("建议订货量" + data.getSuggestOrderGoodsNum() + "");
        //建议订货量
        if (holder.count.getText().length() == 0) {
            holder.reduce.setEnabled(false);
        } else {
            holder.reduce.setEnabled(true);
        }
        if (Double.valueOf(holder.count.getText().toString()) >= data.getMaxSuggestOrderGoodsNum()) {
            holder.add.setEnabled(false);
        } else {
            holder.add.setEnabled(true);
        }
        /*当产品类型是产成品（非卖品）或是辅料资材时，显示信息调整如下：
        去掉“库存天数”
        “库存+在途”改为“在途”
        增加“已提交数量”，“近30天已订货数量”*/
        if (("产成品".equals(data.getProductBigFatherType()) && "非卖品".equals(data.getProductBigType())) || "辅料".equals(data.getProductBigFatherType())) {
            holder.tvCyl.setVisibility(View.GONE);
            holder.tvAlreadyOrder.setVisibility(View.VISIBLE);
            holder.tvLastMonthOrder.setVisibility(View.VISIBLE);
            holder.tvKucun.setText("在途:" + data.getProductFutureNum() + "");
            holder.tvAlreadyOrder.setText("已提交数量:" + data.getProductAlreadyOrderNum() + "");
            holder.tvLastMonthOrder.setText("近30天已订货数量:" + data.getProductLastMonthOrderNum() + "");
        }
        if (data.isInvalid()) {
            holder.count.setTextColor(Color.RED);
        }
        if (Double.valueOf(holder.count.getText().toString()) <= 0d) {
            holder.reduce.setEnabled(false);
        }
        holder.add.setOnClickListener(new OnClickListener() {

            @Override
            public void onClick(View v) {

                final OrderGoodsAuditDetail cell = list.get(position);
                double pDHPack = cell.getProductBoxNum();
                double d = Arith.add(cell.getOrderGoodsAuditNum(), pDHPack);
                cell.setOrderGoodsAuditNum(d);
                String temp = "";
                holder.count.setText(StringUtil.formatDouble(d, "0.00"));
                if (d < 0 || d >= cell.getMaxSuggestOrderGoodsNum()) {
                    if (d > cell.getMaxSuggestOrderGoodsNum()) {
                        temp = "请检查产品：" + cell.getProductName()
                                + ",不能超过最大订货量" + cell.getMaxSuggestOrderGoodsNum()
                                + "! 您输入的数量为：" + d;
                    }
                }
                if (PRODUCT_TYPE.equals(cell.getProductType()) && cell.getProductLastMonthSaleNum() > 0 && d >= cell.getProductLastMonthSaleNum() * 1.5) {
                    temp = "请检查产品：" + cell.getProductName()
                            + ",不能超过次大订货量" + cell.getProductLastMonthSaleNum() * 1.5
                            + "! 您输入的数量为：" + d;
                    cell.setSecondValid(true);
                }
                if (!TextUtils.isEmpty(temp)) {
                    PublicConformTipDialog.Builder builder = new PublicConformTipDialog.Builder(context);
                    builder.setTitle("提示");
                    builder.setMessage(temp);
                    builder.setNegativeButton("知道了并重新输入", new DialogInterface.OnClickListener() {
                        @Override
                        public void onClick(DialogInterface dialog, int which) {
                            dialog.dismiss();
                        }
                    });
                    if (!cell.isInvalid()) {
                        builder.create().show();
                    }
                    cell.setInvalid(true);
                    holder.count.setTextColor(Color.RED);
                    holder.add.setEnabled(false);

                } else {
                    cell.setInvalid(false);
                    holder.count.setTextColor(Color.BLACK);
                }
                if (d > 0) {
                    holder.reduce.setEnabled(true);
                }
                if (d == data.getMaxSuggestOrderGoodsNum()) {
                    holder.add.setEnabled(false);
                }
                if (d <= 0) {
                    holder.reduce.setEnabled(false);
                }
                countFocusChangeListener.onOverMaxSuggestOrderGoodsNum();
                holder.tvCyl.setText("库存天数:" + StringUtil.formatDouble(calculatorCyDay(data, getCount(holder)), "0") + "(天)");
                //库存天数：四舍五入取整

            }
        });
        holder.reduce.setOnClickListener(new OnClickListener() {

            @Override
            public void onClick(View v) {

                OrderGoodsAuditDetail cell = list.get(position);
                double pDHPack = cell.getProductBoxNum();
                double d = Arith.sub(cell.getOrderGoodsAuditNum(), pDHPack);
                cell.setOrderGoodsAuditNum(d);
                holder.count.setText(StringUtil.formatDouble(d, "0.00"));
                if (d <= 0) {
                    holder.reduce.setEnabled(false);
                }
                if (d < 0 || (d > cell.getMaxSuggestOrderGoodsNum())) {
                    cell.setInvalid(true);
                    holder.count.setTextColor(Color.RED);
                } else {
                    cell.setInvalid(false);
                    holder.add.setEnabled(true);
                    holder.count.setTextColor(Color.BLACK);
                }
                if (PRODUCT_TYPE.equals(cell.getProductType()) && cell.getProductLastMonthSaleNum() > 0 && d >= cell.getProductLastMonthSaleNum() * 1.5) {
                    cell.setSecondValid(false);
                }
                if (d > 0) {
                    holder.reduce.setEnabled(true);
                }
                if (d == data.getMaxSuggestOrderGoodsNum()) {
                    holder.add.setEnabled(false);
                }
                if (d <= 0) {
                    holder.reduce.setEnabled(false);
                }
                countFocusChangeListener.onOverMaxSuggestOrderGoodsNum();
                holder.tvCyl.setText("库存天数:" + StringUtil.formatDouble(calculatorCyDay(data, getCount(holder)), "0") + "(天)");
                //库存天数：四舍五入取整

            }
        });
        holder.count.setSelectAllOnFocus(true);
        holder.count.setOnClickListener(new OnClickListener() {

            @Override
            public void onClick(View v) {
                holder.count.setText(holder.count.getText().toString());
                holder.count.selectAll();
            }
        });
        holder.count.setOnFocusChangeListener(new OnFocusChangeListener() {

            @Override
            public void onFocusChange(final View v, boolean hasFocus) {

                if (!hasFocus && null != list && list.size() > position) {
                    countChanged(position, holder, data);
                }
            }
        });

        holder.count.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {

            }

            @Override
            public void afterTextChanged(Editable s) {
                countChanged(position, holder, data);
            }
        });
        holder.productImg.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                showAdDialog(context, data.getProductImage());
            }
        });
        return convertView;
    }

    private double getCount(ViewHolder holder) {
        double count;
        try {
            count = Double.parseDouble(holder.count.getText().toString());
        } catch (Exception e) {
            count = 0;
        }
        return count;
    }

    private void countChanged(int position, ViewHolder holder, OrderGoodsAuditDetail data) {
        OrderGoodsAuditDetail cell = list.get(position);
        String input = holder.count.getText().toString();
        double d;
        double pDHPack = cell.getProductBoxNum();
        try {
            d = Double.parseDouble(input);
        } catch (NumberFormatException e) {
            d = 0;
        }
        cell.setOrderGoodsAuditNum(d);
        String temp = "";
        if (d < 0) {
            temp = "请检查产品：" + cell.getProductName()
                    + ",必须输入有效的数字！";
            holder.reduce.setEnabled(false);
        }
        if (d > cell.getMaxSuggestOrderGoodsNum()) {
            temp = "请检查产品：" + cell.getProductName()
                    + ",不能超过最大订货量" + cell.getMaxSuggestOrderGoodsNum()
                    + "! 您输入的数量为：" + d;
            holder.add.setEnabled(false);
        }
        if (PRODUCT_TYPE.equals(cell.getProductType()) && cell.getProductLastMonthSaleNum() > 0 && d >= cell.getProductLastMonthSaleNum() * 1.5) {
            temp = "请检查产品：" + cell.getProductName()
                    + ",不能超过次大订货量" + cell.getProductLastMonthSaleNum() * 1.5
                    + "! 您输入的数量为：" + d;
            cell.setSecondValid(true);
            holder.add.setEnabled(false);
        }
        if (0 != pDHPack && 0 != d && d % pDHPack != 0) {
            temp = "请检查产品：" + cell.getProductName()
                    + ",数量必须是" + pDHPack + "倍数";
            data.setOrderGoodsAuditNum((int) data.getOrderGoodsAuditNum()
                    / (int) pDHPack * pDHPack);// 非法规格输入调整
            d = data.getOrderGoodsNum();
            data.setOrderGoodsAuditNum(d);
        }

        if (!TextUtils.isEmpty(temp)) {
            PublicConformTipDialog.Builder builder = new PublicConformTipDialog.Builder(context);
            builder.setTitle("提示");
            builder.setMessage(temp);
            builder.setNegativeButton("知道了并重新输入", new DialogInterface.OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                    dialog.dismiss();
                }
            });
            if (!cell.isInvalid()) {
                builder.create().show();
            }
            cell.setInvalid(true);
            holder.count.setTextColor(Color.RED);
        } else {
            cell.setInvalid(false);
            holder.add.setEnabled(true);
            holder.reduce.setEnabled(true);
            holder.count.setTextColor(Color.BLACK);
        }
        if (d > 0) {
            holder.reduce.setEnabled(true);
        }
        if (d == data.getMaxSuggestOrderGoodsNum()) {
            holder.add.setEnabled(false);
        }
        if (d <= 0d) {
            holder.reduce.setEnabled(false);
        }
        countFocusChangeListener.onOverMaxSuggestOrderGoodsNum();
        holder.tvCyl.setText("库存天数:" + StringUtil.formatDouble(calculatorCyDay(data, getCount(holder)), "0") + "(天)");
        // /库存天数：四舍五入取整
    }

    class ViewHolder {
        MarqueeTextView name, unit, goodsType;
        TextView qtyCount, maxqtyCount, tvKucun, tvAlreadyOrder, tvLastMonthOrder,
                tvXiaoliang, tvCyl, tvShdl;
        EditText count;
        ImageButton add, reduce;
        LinearLayout llShowDetail;
        TextView productIsNotStock;
        TextView productImg;
    }

    /**
     * 实时计算库存天数
     *
     * @param data   订货审核产品实体
     * @param counts 审核数量
     * @return 库存天数=（（库存数量+审核数量）/月用量）*30   结果的单位为：天 ；注：产品库存数量=（库存+在途）
     * cyd=(（ProductStockNum+OrderGoodsAuditNum）/ProductLastMonthSaleNum)*30,
     * StringUtil.formatDouble(calculatorCyDay(data, data.getOrderGoodsAuditNum()), "0")；四舍五入取整
     */
    private double calculatorCyDay(OrderGoodsAuditDetail data, double counts) {
        double cyd;
        if (data.getProductLastMonthSaleNum() == 0
                || (counts + data.getProductStockNum()) == 0) {
            cyd = 0;
        } else {
            try {
                cyd = ((data.getProductStockNum() + data.getOrderGoodsAuditNum())
                        / data.getProductLastMonthSaleNum()) * 30;
            } catch (Exception e) {
                cyd = 0;
            }
        }
        return cyd;
    }

    /**
     * 弹出图片弹窗
     */
    private void showAdDialog(Context context, String adInfo) {
        final AdDialog adDialog = new AdDialog(context, adInfo);
        //点击空白区域能不能退出
        adDialog.setCanceledOnTouchOutside(false);
        //按返回键能能退出
        adDialog.setCancelable(true);
        adDialog.setClickLink(adInfo);
        adDialog.setLinkType("url");
        adDialog.show();
    }
}