package com.wgmf.yxgj.module.business.manageproduct.ui;

import android.content.Context;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.library.utils.StringUtil;
import com.wgmf.yxgj.module.business.manageproduct.R;
import com.wgmf.yxgj.module.business.manageproduct.model.StockGoodsCheckDetailsList;
import com.wgmf.yxgj.module.business.manageproduct.model.StockGoodsDetailsGroup;
import com.wgmf.yxgj.widgets.EditText.LimitEditText;

import java.util.ArrayList;
import java.util.List;

/**
 * 订货盘点明细页适配器
 */
@SuppressWarnings("all")
class GoodsStockCheckDetailsListAdapter extends BaseAdapter {
    /**
     * 0，查询；1，可修改；2，正在编辑
     */
    private int mode;
    /**
     * 0:五谷磨房，1，食补集
     */
    private int type;

    private String mCheckDate;

    private Context context;

    private List<StockGoodsDetailsGroup> stockGoodsDetailsGroups;

    private List<StockGoodsCheckDetailsList> stockGoodsCheckDetailsLists;

    private ModifyNumClickListener mListener;

    public void setAdapterData(List<StockGoodsDetailsGroup> mlist, int type) {
        this.type = type;
        stockGoodsCheckDetailsLists = mlist.get(type).getStockGoodsCheckDetailsList();
    }

    public void setAdapterMode(int mode) {
        this.mode = mode;
    }

    interface ModifyNumClickListener {
        void onModifyNumClickListener(List<StockGoodsDetailsGroup> list);

        void onModifyNumClickListener(String error);
    }

    GoodsStockCheckDetailsListAdapter(List<StockGoodsDetailsGroup> mlist, Context context, ModifyNumClickListener mListener, String mDate) {
        this.stockGoodsDetailsGroups = mlist;
        this.context = context;
        this.mListener = mListener;
        this.mCheckDate = mDate;
        stockGoodsCheckDetailsLists = new ArrayList<>();
    }

    @Override
    public int getCount() {
        return stockGoodsCheckDetailsLists == null ? 0 : stockGoodsCheckDetailsLists.size();
    }

    @Override
    public Object getItem(int position) {
        return stockGoodsCheckDetailsLists == null ? null : stockGoodsCheckDetailsLists.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(final int position, View convertView, ViewGroup parent) {
        final StockGoodsCheckDetailsList ent = stockGoodsCheckDetailsLists.get(position);
        final ViewHolder viewHolder;
        convertView = null;
        if (null == convertView) {
            convertView = LayoutInflater.from(context).inflate(R.layout.stock_goods_details_item, null);
            viewHolder = new ViewHolder(convertView);

            viewHolder.pdAlterNum.addTextChangedListener(new TextWatcher() {
                @Override
                public void beforeTextChanged(CharSequence s, int start, int count, int after) {

                }

                @Override
                public void afterTextChanged(Editable s) {
                    double pdkc = 0;
                    try {
                        pdkc = Double.parseDouble(s.toString());
                        if (pdkc >= 0) {
                            //盘点数量应大于或等于零
                            stockGoodsCheckDetailsLists.get(position).setPdAlterNum(s.toString());
                            updateView(pdkc, position, viewHolder);
                            mListener.onModifyNumClickListener(stockGoodsDetailsGroups);
                        } else {
                            //修改盘点数量出错
                            pdkc = stockGoodsCheckDetailsLists.get(position).getPdFrontNum();
                        }
                    } catch (Exception e) {
                        //修改盘点数量出错
                        pdkc = stockGoodsCheckDetailsLists.get(position).getPdFrontNum();
                    }
                }

                @Override
                public void onTextChanged(CharSequence s, int start, int before, int count) {

                }
            });
            viewHolder.pdAlterTips.addTextChangedListener(new TextWatcher() {
                @Override
                public void beforeTextChanged(CharSequence s, int start, int count, int after) {

                }

                @Override
                public void afterTextChanged(Editable s) {
                    if (!TextUtils.isEmpty(s)) {
                        //修改原因
                        stockGoodsCheckDetailsLists.get(position).setPdUpdateReson(s.toString());
                    }else{
                        stockGoodsCheckDetailsLists.get(position).setPdUpdateReson(null);
                    }
                }

                @Override
                public void onTextChanged(CharSequence s, int start, int before, int count) {

                }
            });
            convertView.setTag(viewHolder);
        } else

        {
            viewHolder = (ViewHolder) convertView.getTag();
        }

        if (mode == 1)

        {
            //如果正在编辑状态，显示编辑框
            viewHolder.stockGoodsCheckDetailsLl3.setVisibility(View.VISIBLE);
            viewHolder.stockGoodsCheckDetailsLl4.setVisibility(View.VISIBLE);
            viewHolder.pdAlterNum.setVisibility(View.VISIBLE);
            viewHolder.modify.setVisibility(View.VISIBLE);
            viewHolder.pdAlterNum.setTag(position);
        } else

        {
            //默认只可查看，不可修改
            viewHolder.stockGoodsCheckDetailsLl3.setVisibility(View.GONE);
            viewHolder.stockGoodsCheckDetailsLl4.setVisibility(View.GONE);
            viewHolder.pdAlterNum.setVisibility(View.INVISIBLE);
            viewHolder.modify.setVisibility(View.INVISIBLE);
        }
        viewHolder.proname.setText("" + ent.getProName() + "");
        viewHolder.procode.setText("" + ent.getProCode() + "");
        viewHolder.proprice.setText("零售价：" + ent.getProPrice() + "");

        viewHolder.pdnum.setText("实盘数量：" + ent.getPdNum() + "");
        viewHolder.pdamount.setText("实盘金额：" + StringUtil.formatDouble(ent.getPdAmount(), "0.0") + "");
        ent.setPdFrontNum(ent.getPdNum());

        String modNum;
        if (null == ent.getPdAlterNum()
                || ent.getPdAlterNum().equals("null")
                || ent.getPdAlterNum().equals("-1")) {
            modNum = "";
        } else {
            modNum = ent.getPdAlterNum() + "";
        }
        viewHolder.pdAlterNum.setText(modNum);
        viewHolder.pdAlterTips.setText(ent.getPdUpdateReson());
        return convertView;
    }

    private void updateView(double pdkc, int position, ViewHolder viewHolder) {
        stockGoodsCheckDetailsLists.get(position).setYearMonth(mCheckDate);
        stockGoodsCheckDetailsLists.get(position).setPdDiffNum(pdkc - stockGoodsCheckDetailsLists.get(position).getStockNum());
        stockGoodsCheckDetailsLists.get(position).setPdAmount(pdkc * stockGoodsCheckDetailsLists.get(position).getProPrice());
        stockGoodsCheckDetailsLists.get(position).setPdDiffAmount((pdkc - stockGoodsCheckDetailsLists.get(position).getStockNum()) * stockGoodsCheckDetailsLists.get(position).getProPrice());

        viewHolder.pdamount.setText("实盘金额：" + StringUtil.formatDouble(stockGoodsCheckDetailsLists.get(position).getPdAmount(), "0.0") + "");
    }

    class ViewHolder {
        /**
         * 产品名字
         */
        TextView proname;
        /**
         * 产品编号
         */
        TextView procode;
        /**
         * 产品价格
         */
        TextView proprice;
        /**
         * 盘点数量
         */
        TextView pdnum;
        /**
         * 修改提示
         */
        TextView modify;
        /**
         * 盘点金额
         */
        TextView pdamount;
        /**
         * 修改盘点数量后的数量
         */
        LimitEditText pdAlterNum;
        /**
         * 修改盘点数量后的备注
         */
        EditText pdAlterTips;

        LinearLayout stockGoodsCheckDetailsLl3;

        LinearLayout stockGoodsCheckDetailsLl4;

        ViewHolder(View convertView) {
            proname = (TextView) convertView.findViewById(R.id.stock_goods_details_pro_name);
            procode = (TextView) convertView.findViewById(R.id.stock_goods_details_pro_code);
            proprice = (TextView) convertView.findViewById(R.id.stock_goods_details_pro_price);
            pdnum = (TextView) convertView.findViewById(R.id.stock_goods_details_pd_num);
            pdamount = (TextView) convertView.findViewById(R.id.stock_goods_details_pd_amount);
            modify = (TextView) convertView.findViewById(R.id.modify_tv);
            pdAlterNum = (LimitEditText) convertView.findViewById(R.id.stock_goods_details_modify);
            pdAlterTips = (EditText) convertView.findViewById(R.id.stock_goods_details_tips);
            stockGoodsCheckDetailsLl3 = (LinearLayout) convertView.findViewById(R.id.stock_goods_check_details_ll3);
            stockGoodsCheckDetailsLl4 = (LinearLayout) convertView.findViewById(R.id.stock_goods_check_details_ll4);
        }
    }
}