package com.wgmf.yxgj.module.business.manageproduct.ui;

import android.content.Intent;
import android.os.Bundle;
import android.support.v4.content.ContextCompat;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.google.gson.Gson;
import com.jakewharton.rxbinding.view.RxView;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.DateUtil;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.db.GreenDaoManager;
import com.wgmf.yxgj.db.OrderGoodsAuditDetailDao;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.model.FixedProductListEntity;
import com.wgmf.yxgj.model.OrderGoodsAuditDetail;
import com.wgmf.yxgj.module.business.manageproduct.model.ProductTransferredInAndOutNumLists;
import com.wgmf.yxgj.module.business.manageproduct.model.ProductTransferredInAndOutNumListEntity;
import com.wgmf.yxgj.module.business.manageproduct.R;
import com.wgmf.yxgj.module.business.manageproduct.model.ProductAndSuggestOrderGoodsList;
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService;
import com.wgmf.yxgj.pop.PublicThreeSecondsPop;
import com.wgmf.yxgj.publics.ui.SelectorStoreGetNearestActivity;
import com.wgmf.yxgj.utils.helper.DialogHelper;
import com.wgmf.yxgj.widgets.ListView.SlideDeleteListView;
import com.xp.arouter.RouterParams;

import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;

import rx.functions.Action1;

/**
 * 货品调入调出
 */
@Route(path = RouterParams.URL_GOODSTRANSFERREDINOROUTACTIVITY)
public class GoodsTransferredInOrOutActivity extends BaseParentAct implements View.OnClickListener, PublicThreeSecondsPop.ThreeSecondsPopListener {

    private static final int TRANSFER_OUT_SHOP = 1;
    private static final int TRANSFER_IN_SHOP = 2;
    private String storeidOut;
    private String storeidIn;
    /**
     * 调入调出功能选择门店
     */
    private Long branchID;
    private TextView transferOutShopNameTxt;
    private TextView transferInShopNameTxt;
    private TextView selectDateTxt;
    private TextView submit;

    private List<OrderGoodsAuditDetail> list = new ArrayList<>();
    private GoodsTransferredInOrOutAdapter adapter;
    private SlideDeleteListView slv;
    private OrderGoodsAuditDetailDao mOrderGoodsAuditDetailDao;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_transfer_goods);
        initTitle();
        initView();
        initContent();
    }

    private void initContent() {
        //将需要审核的信息存入数据库
        mOrderGoodsAuditDetailDao = GreenDaoManager.getInstance().getDaoSession(this).getOrderGoodsAuditDetailDao();
        mOrderGoodsAuditDetailDao.deleteAll();// 删除审核信息表

        slv = (SlideDeleteListView) findViewById(R.id.listview);
        TextView dataEmpty = (TextView) findViewById(R.id.data_empty);
        slv.setEmptyView(dataEmpty);
        adapter = new GoodsTransferredInOrOutAdapter(list, GoodsTransferredInOrOutActivity.this);
        slv.setAdapter(adapter);
        slv.setOnRemovedListener(new SlideDeleteListView.OnRemovedListener() {
            @Override
            public void onRemoveItem(int position) {
                try {
                    if (list.get(position).getType() == 0) {
                        showMsg("不能删除该条数据！");
                    } else {
                        mOrderGoodsAuditDetailDao.deleteByKey(list.get(position).getProductId());
                    }
                } catch (Exception e) {
                    Log.e(TAG, "数据库出错");
                }
                list = mOrderGoodsAuditDetailDao.loadAll();
                adapter = new GoodsTransferredInOrOutAdapter(list, GoodsTransferredInOrOutActivity.this);
                slv.setAdapter(adapter);
            }
        });
        //5秒钟之内只取一个点击事件，防抖操作
        RxView.clicks(submit).throttleFirst(5, TimeUnit.SECONDS).subscribe(new Action1<Void>() {
            @Override
            public void call(Void aVoid) {
                if (TextUtils.isEmpty(storeidOut)) {
                    showMsg("请选择调出门店");
                } else if (TextUtils.isEmpty(storeidIn)) {
                    showMsg("请先选择调入门店");
                } else if (transferOutShopNameTxt.getText().toString().equals(transferInShopNameTxt.getText().toString())) {
                    showMsg("调入调出门店不能相同");
                } else if (checkDate(selectDateTxt.getText().toString()) == 1) {
                    showMsg("日期选择有误，请重新选择");
                } else {
                    showDialog();
                    setDialogCancel(false, false);
                    uploadCommitOper();//提交数据
                    submit.setText("正在提交");
                    submit.setBackgroundColor(ContextCompat.getColor(GoodsTransferredInOrOutActivity.this, R.color.common_txt_color));
                }
            }
        });
    }

    @Override
    public void initTitle() {
        super.initTitle();
        String branchTitle = getIntent().getStringExtra("branchTitle");
        branchID = getIntent().getLongExtra("branchID", 0);
        homeTitleText.setText(branchTitle);
        homeTitleMoreLl.setVisibility(View.INVISIBLE);
        homeTitleBackLl.setVisibility(View.VISIBLE);
    }

    private void initView() {
        EventBus.getDefault().register(this);
        LinearLayout transferOutShopNameLl = (LinearLayout) findViewById(R.id.transfer_out_shop_name_ll);
        LinearLayout transferInShopNameLl = (LinearLayout) findViewById(R.id.transfer_in_shop_name_ll);
        transferOutShopNameTxt = (TextView) findViewById(R.id.transfer_out_shop_name_txt);
        transferInShopNameTxt = (TextView) findViewById(R.id.transfer_in_shop_name_txt);
        TextView selectProductsTxt = (TextView) findViewById(R.id.select_products_txt);
        selectDateTxt = (TextView) findViewById(R.id.select_date_txt);
        submit = (TextView) findViewById(R.id.submit);

        selectDateTxt.setText(DateUtil.getDate(new Date()));

        transferOutShopNameLl.setOnClickListener(this);
        transferInShopNameLl.setOnClickListener(this);
        selectProductsTxt.setOnClickListener(this);
        selectDateTxt.setOnClickListener(this);
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        switch (requestCode) {
            case TRANSFER_OUT_SHOP:
                try {
                    storeidOut = data.getStringExtra("shopId");
                    String shopNameOut = data.getStringExtra("shopName");
                    transferOutShopNameTxt.setText(shopNameOut);
                } catch (Exception e) {
                    Log.e(TAG, "onActivityResult: data.getStringExtra error ");
                }
                break;
            case TRANSFER_IN_SHOP:
                try {
                    storeidIn = data.getStringExtra("shopId");
                    String shopNameIn = data.getStringExtra("shopName");
                    transferInShopNameTxt.setText(shopNameIn);
                } catch (Exception e) {
                    Log.e(TAG, "onActivityResult: data.getStringExtra error ");
                }
                break;
            default:
                break;
        }
    }

    /**
     * 继续添加订货后返回的明细实体
     *
     * @param item 产品明细
     */
    @Subscribe
    public void onEventMainThread(List<ProductAndSuggestOrderGoodsList> item) {
        if (item != null && !item.isEmpty()) {
            list = mOrderGoodsAuditDetailDao.loadAll();
            adapter = new GoodsTransferredInOrOutAdapter(list, GoodsTransferredInOrOutActivity.this);
            slv.setAdapter(adapter);
            if (!list.isEmpty()) {
                submit.setVisibility(View.VISIBLE);
            }
        }
    }

    /**
     * 上传订货审核数据
     */
    private void uploadCommitOper() {
        ProductTransferredInAndOutNumLists mProductTransferredInAndOutNumList = new ProductTransferredInAndOutNumLists();
        List<ProductTransferredInAndOutNumListEntity> mProductTransferredInAndOutNumListEntitys = new ArrayList<>();
        for (int i = 0; i < list.size(); i++) {
            ProductTransferredInAndOutNumListEntity mProductTransferredInAndOutNumListEntity = new ProductTransferredInAndOutNumListEntity();
            mProductTransferredInAndOutNumListEntity.setTransferredInAndOutNum(list.get(i).getOrderGoodsAuditNum());
            FixedProductListEntity mFixedProductListEntity = new FixedProductListEntity();
            //产品ID
            mFixedProductListEntity.setProId(list.get(i).getProductId());
            //产品大类
            mFixedProductListEntity.setProductBigType(list.get(i).getProductBigType());
            //产品箱装数量
            mFixedProductListEntity.setProductBoxNum(list.get(i).getProductBoxNum());
            //产品编码
            mFixedProductListEntity.setProductCode(list.get(i).getProductCode());
            //产品名称
            mFixedProductListEntity.setProductName(list.get(i).getProductName());
            //产品规格
            mFixedProductListEntity.setProductPack(list.get(i).getProductPack());
            //产品价格
            mFixedProductListEntity.setProductPrice(list.get(i).getProductPrice());
            //产品类别
            mFixedProductListEntity.setProductType(list.get(i).getProductType());
            //产品单位
            mFixedProductListEntity.setProductUnit(list.get(i).getProductUnit());
            //产品单位id
            mFixedProductListEntity.setProductUnitId(list.get(i).getProductUnitId());
            mProductTransferredInAndOutNumListEntity.setFixedProduct(mFixedProductListEntity);
            mProductTransferredInAndOutNumListEntitys.add(mProductTransferredInAndOutNumListEntity);
        }
        mProductTransferredInAndOutNumList.setTransferredInOrOutDate(selectDateTxt.getText().toString());
        mProductTransferredInAndOutNumList.setUserInfo(userInfo);
        mProductTransferredInAndOutNumList.setTransferredInStoreId(storeidIn);
        mProductTransferredInAndOutNumList.setTransferredOutStoreId(storeidOut);
        mProductTransferredInAndOutNumList.setProductTransferredInAndOutNumList(mProductTransferredInAndOutNumListEntitys);

        String content = new Gson().toJson(mProductTransferredInAndOutNumList);
        Log.d(TAG, content);
        GoodsManagerService.getInstance().requestSaveTransferredInOrOut(content, GoodsTransferredInOrOutActivity.this);
    }

    @Override
    public void onClick(View v) {
        Intent intent = new Intent();
        if (v.getId() == R.id.transfer_out_shop_name_ll) {
            //调出门店
            intent.setClass(GoodsTransferredInOrOutActivity.this,
                    SelectorStoreGetNearestActivity.class);
            intent.putExtra("branchTitle", "选择门店");
            intent.putExtra("branchID", branchID);
            startActivityForResult(intent, TRANSFER_OUT_SHOP);
        } else if (v.getId() == R.id.transfer_in_shop_name_ll) {
            //调入门店
            intent.setClass(GoodsTransferredInOrOutActivity.this,
                    SelectorStoreGetNearestActivity.class);
            intent.putExtra("branchTitle", "选择门店");
            intent.putExtra("branchID", branchID);
            startActivityForResult(intent, TRANSFER_IN_SHOP);
        } else if (v.getId() == R.id.select_date_txt) {
            //调入调出日期
            DialogHelper.AlertDatePicker(this, this, selectDateTxt);
        } else if (v.getId() == R.id.select_products_txt) {
            //选择产品
            if (TextUtils.isEmpty(storeidOut)) {
                showMsg("请先选择调出门店");
            }else if (TextUtils.isEmpty(storeidIn)) {
                showMsg("请先选择调入门店");
            }else {
                intent.setClass(GoodsTransferredInOrOutActivity.this, GoodsAuditingAddProductsActivity.class);
                intent.putExtra("orderGoodsAuditId", 1);
                intent.putExtra("storeNo", storeidOut);
                intent.putExtra("inStoreNo", storeidIn);
                intent.putExtra("type", "CPML");
                startActivity(intent);
            }
        }
    }

    private int checkDate(String mDate) {
        Date date = new Date();
        SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
        try {
            Date date0 = DateUtil.getFirstDayOfMonth(DateUtil.string2Date(mDate, "yyyy-MM"));
            // 选中的日期
            Date date1 = formatter.parse(formatter.format(date0));
            // 今天
            Date date2 = formatter.parse(formatter.format(date));
            // 下月1日
            Date date3 = formatter.parse(formatter.format(DateUtil.getDayOfMonth(DateUtil.string2Date(mDate, "yyyy-MM"), 1, 1)));
            //本月和下月1号之前可修改，其余时间不可修改
            if (DateUtil.getMonth(date1) == DateUtil.getMonth(date2) || ((DateUtil.daysBetween(date2, date3) <= 1) && (DateUtil.daysBetween(date2, date3) >= 0))) {
                //可修改
                return 0;
            } else {
                //不修改
                return 1;
            }
        } catch (Exception e) {
            //可修改
            return 0;
        }
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.GoodsManager.MSG_ON_SAVE_TRANSFERRED_INOROUT: {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        try {
                            BaseResponse mBaseResponse = new Gson().fromJson(msg, BaseResponse.class);
                            Log.d(TAG, "mBaseResponse=" + mBaseResponse.toString());

                            showMsg(mBaseResponse.retInfo);
                            if (ConstantParams.CONSTANT_PARAMS_0.equals(mBaseResponse.retCode)) {
                                //弹出提示进度条,等待OE返回
                                showPopwindow();
                            }
                        } catch (Exception e) {
                            showMsg(getString(R.string.request_data_fail));
                        }
                    } else {
                        showMsg(result.getResultInfo());
                    }
                    submit.setText(R.string.submit_btn_txt);
                    submit.setBackgroundColor(ContextCompat.getColor(GoodsTransferredInOrOutActivity.this, R.color.normal_color));
                }
                break;
                default:
                    break;
            }
        }
    }

    /**
     * 弹出延时窗
     */
    private void showPopwindow() {
        PublicThreeSecondsPop publicThreeSecondsPop = new PublicThreeSecondsPop(this, this);
        if (!publicThreeSecondsPop.isShowing()) {
            publicThreeSecondsPop.show(this.findViewById(R.id.title));
        }
    }

    @Override
    public void onTimingFinish() {
        GoodsTransferredInOrOutActivity.this.finish();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        EventBus.getDefault().unregister(this);
    }
}