package com.wgmf.yxgj.module.business.manageproduct.ui;

import android.content.Context;
import android.content.DialogInterface;
import android.graphics.Color;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.View.OnFocusChangeListener;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.library.utils.Arith;
import com.wgmf.library.utils.StringUtil;
import com.wgmf.yxgj.dialog.PublicConformTipDialog;
import com.wgmf.yxgj.model.OrderGoodsAuditDetail;
import com.wgmf.yxgj.module.business.manageproduct.R;

import java.util.Collections;
import java.util.Comparator;
import java.util.List;

/**
 * 货品调入调出添加产品
 */
@SuppressWarnings("all")
class GoodsTransferredInOrOutAdapter extends BaseAdapter {
    private List<OrderGoodsAuditDetail> list;
    private Context context;
    private boolean dialogIsShowing = false;

    GoodsTransferredInOrOutAdapter(List<OrderGoodsAuditDetail> list, Context context) {
        this.list = list;
        this.context = context;
        initList();
    }

    /**
     * 按选择后添加顺序排列
     */
    private void initList() {
        Collections.sort(list, new Comparator<OrderGoodsAuditDetail>() {
            @Override
            public int compare(OrderGoodsAuditDetail lhs,
                               OrderGoodsAuditDetail rhs) {

                if (lhs.getCreateTime() < rhs.getCreateTime()) {
                    return 1;
                } else if (lhs.getCreateTime() == rhs.getCreateTime()) {
                    return 0;
                } else {
                    return -1;
                }
            }
        });
    }

    @Override
    public int getCount() {
        return list == null ? 0 : list.size();
    }

    @Override
    public Object getItem(int position) {
        return list == null ? null : list.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(final int position, View convertView, ViewGroup parent) {
        final OrderGoodsAuditDetail data = list.get(position);
        final ViewHolder holder;
        convertView = null;
        if (null == convertView) {
            convertView = LayoutInflater.from(context).inflate(R.layout.goods_transferred_in_or_out_item, null);
            holder = new ViewHolder(convertView);
            if ("".equals(data.getProductUnit()) || null == data.getProductUnit() || "null".equals(data.getProductUnit())) {
                holder.unit.setText("(" + "包" + ")");
            } else {
                holder.unit.setText("(" + data.getProductUnit() + " " + data.getProductCode() + ")");
            }
            holder.name.setText(data.getProductName());
            holder.price.setText("￥" + data.getProductPrice() + "");
            holder.count.setText("" + StringUtil.formatDouble(data.getOrderGoodsAuditNum(), "0.00") + "");
            holder.count.setSelection(holder.count.getText().length());
            if (holder.count.getText().length() == 0) {
                holder.reduce.setEnabled(false);
            } else {
                holder.reduce.setEnabled(true);
            }
            if (data.getMaxSuggestOrderGoodsNum() > 0
                    && Double.valueOf(holder.count.getText().toString()) >= data.getMaxSuggestOrderGoodsNum()) {
                holder.add.setEnabled(false);
            } else {
                holder.add.setEnabled(true);
            }
            holder.add.setOnClickListener(new OnClickListener() {

                @Override
                public void onClick(View v) {
                    final OrderGoodsAuditDetail cell = list.get(position);
                    double pDHPack = 1;
                    double d = Arith.add(cell.getOrderGoodsAuditNum(), pDHPack);
                    cell.setOrderGoodsAuditNum(d);
                    holder.count.setText(StringUtil.formatDouble(d, "0.00"));
                    if (d < 0) {
                        PublicConformTipDialog.Builder builder = new PublicConformTipDialog.Builder(context);
                        builder.setTitle("提示");
                        builder.setMessage("请检查产品：" + data.getProductName()
                                + ",必须输入有效的数字!");
                        builder.setNegativeButton("知道了并重新输入", new DialogInterface.OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog, int which) {
                                dialog.dismiss();
                                dialogIsShowing = false;
                            }
                        });
                        if (!dialogIsShowing) {
                            builder.create().show();
                            dialogIsShowing = true;
                        }
                        cell.setInvalid(true);
                        holder.count.setTextColor(Color.RED);
                        holder.add.setEnabled(false);
                    } else {
                        cell.setInvalid(false);
                        holder.count.setTextColor(Color.BLACK);
                    }
                    if (d > 0) {
                        holder.reduce.setEnabled(true);
                    }

                }
            });
            holder.reduce.setOnClickListener(new OnClickListener() {

                @Override
                public void onClick(View v) {
                    OrderGoodsAuditDetail cell = list.get(position);
                    double pDHPack = 1;
                    double d = Arith.sub(cell.getOrderGoodsAuditNum(), pDHPack);
                    cell.setOrderGoodsAuditNum(d);
                    holder.count.setText(StringUtil.formatDouble(d, "0.00"));
                    if (d <= 0) {
                        holder.reduce.setEnabled(false);
                    }
                    if (d < 0
                            || (cell.getMaxSuggestOrderGoodsNum() > 0 && d > cell
                            .getMaxSuggestOrderGoodsNum())) {

                        cell.setInvalid(true);
                        holder.count.setTextColor(Color.RED);
                    } else {
                        cell.setInvalid(false);
                        holder.add.setEnabled(true);
                        holder.count.setTextColor(Color.BLACK);
                    }
                }
            });
            holder.count.setSelectAllOnFocus(true);
            holder.count.setOnClickListener(new OnClickListener() {

                @Override
                public void onClick(View v) {
                    holder.count.setText(holder.count.getText().toString());
                    holder.count.selectAll();
                }
            });
            holder.count.setOnFocusChangeListener(new OnFocusChangeListener() {

                @Override
                public void onFocusChange(final View v, boolean hasFocus) {
                    if (!hasFocus && null != list && list.size() > position) {
                        OrderGoodsAuditDetail cell = list.get(position);
                        String input = holder.count.getText().toString();
                        double d;
                        try {
                            d = Double.parseDouble(input);
                        } catch (NumberFormatException e) {
                            d = 0;
                        }
                        cell.setOrderGoodsAuditNum(d);
                        holder.count.setText(StringUtil.formatDouble(d, "0.00"));
                        String temp = "";
                        if (d < 0) {
                            temp = "请检查产品：" + data.getProductName()
                                    + ",必须输入有效的数字！";
                            holder.reduce.setEnabled(false);
                        }
                        if (!TextUtils.isEmpty(temp)) {
                            PublicConformTipDialog.Builder builder = new PublicConformTipDialog.Builder(context);
                            builder.setTitle("提示");
                            builder.setMessage(temp);
                            builder.setNegativeButton("知道了并重新输入", new DialogInterface.OnClickListener() {
                                @Override
                                public void onClick(DialogInterface dialog, int which) {
                                    dialog.dismiss();
                                    dialogIsShowing = false;
                                }
                            });
                            if (!dialogIsShowing) {
                                builder.create().show();
                                dialogIsShowing = true;
                            }
                            cell.setInvalid(true);
                            holder.count.setTextColor(Color.RED);
                        } else {
                            cell.setInvalid(false);
                            holder.add.setEnabled(true);
                            holder.reduce.setEnabled(true);
                            holder.count.setTextColor(Color.BLACK);
                        }
                    }
                }
            });
            convertView.setTag(holder);
        } else {
            holder = (ViewHolder) convertView.getTag();
        }
        holder.count.setTag(position);

        return convertView;
    }

    class ViewHolder {
        TextView name;
        TextView unit;
        TextView price;
        EditText count;
        ImageButton add;
        ImageButton reduce;
        LinearLayout llShowDetail;

        ViewHolder(View convertView) {
            name = (TextView) convertView.findViewById(R.id.goods_name);
            unit = (TextView) convertView.findViewById(R.id.goods_unit);
            price = (TextView) convertView.findViewById(R.id.goods_price);
            llShowDetail = (LinearLayout) convertView.findViewById(R.id.ll_show_detail);
            count = (EditText) convertView.findViewById(R.id.goods_count);
            add = (ImageButton) convertView.findViewById(R.id.goods_plus);
            reduce = (ImageButton) convertView.findViewById(R.id.goods_decrease);
        }
    }
}