package com.wgmf.yxgj.module.business.manageproduct.ui;

import android.os.Bundle;
import android.support.v4.content.ContextCompat;
import android.util.Log;
import android.view.View;
import android.widget.ExpandableListView;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;

import com.google.gson.Gson;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;
import com.wgmf.yxgj.module.business.manageproduct.model.ProductTransferredInAndOutNumLists;
import com.wgmf.yxgj.module.business.manageproduct.model.ProductTransferredInAndOutNumResultList;
import com.wgmf.yxgj.module.business.manageproduct.R;
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService;
import com.wgmf.yxgj.widgets.EditText.ClearEditText;

import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;

import java.util.ArrayList;
import java.util.List;

/**
 * 调入调出明细
 */
public class GoodsTransferredInOrOutDetailsActivity extends BaseParentAct {

    private List<ProductTransferredInAndOutNumLists> list;
    private GoodsTransferredInOrOutDetailsAdapter adapter;
    private ExpandableListView publicListViewElv;
    private String storeNo;
    private String startDate;
    private String endDate;

    @Override
    protected void onCreate(Bundle savedInstanceState) {

        super.onCreate(savedInstanceState);
        setContentView(R.layout.public_list_view);
        initTitle();
        initContent();
        getShopData();
    }

    private void getShopData() {
        list.clear();
        adapter.notifyDataSetChanged();
        showDialog();
        String url = NetworkParams.URL_FIND_TRANSFERRED_INANDOUT_DETAIL;
        GoodsManagerService.getInstance().requestFindTransferredInAndOutDetail(url, storeNo, startDate, endDate, GoodsTransferredInOrOutDetailsActivity.this);
    }

    @Override
    public void initTitle() {
        super.initTitle();
        homeTitleText.setText("调入调出查询");
        homeTitleMoreLl.setVisibility(View.INVISIBLE);
        homeTitleBackLl.setVisibility(View.VISIBLE);
    }

    private void initContent() {
        EventBus.getDefault().register(this);
        String storeName = getIntent().getStringExtra("storeName");
        storeNo = getIntent().getStringExtra("storeNo");
        startDate = getIntent().getStringExtra("startDate");
        endDate = getIntent().getStringExtra("endDate");
        list = new ArrayList<>();
        ListView mListView = (ListView) findViewById(R.id.public_list_view_lv);
        mListView.setVisibility(View.GONE);
        publicListViewElv = (ExpandableListView) findViewById(R.id.public_list_view_elv);
        publicListViewElv.setVisibility(View.VISIBLE);
        View dataEmpty = findViewById(R.id.public_list_view_empty_ll);
        publicListViewElv.setEmptyView(dataEmpty);
        ClearEditText storeNameEt = (ClearEditText) findViewById(R.id.store_name_et);
        storeNameEt.setVisibility(View.GONE);
        LinearLayout onclickTitleLl = (LinearLayout) findViewById(R.id.public_top_content_ll);
        TextView onclickName = (TextView) findViewById(R.id.store_name_tv);
        TextView onclickTitle = (TextView) findViewById(R.id.store_rank_tv);
        onclickName.setText(storeName);
        String text = startDate + "至" + endDate;
        onclickTitle.setText(text);
        onclickTitleLl.setVisibility(View.VISIBLE);
        onclickName.setTextColor(ContextCompat.getColor(this, R.color.white));
        onclickTitle.setTextColor(ContextCompat.getColor(this, R.color.white));
        onclickTitleLl.setBackgroundResource(R.color.normal_color);

        adapter = new GoodsTransferredInOrOutDetailsAdapter(list, this);
        publicListViewElv.setAdapter(adapter);
        adapter.notifyDataSetChanged();
    }

    /**
     * 在主线程处理服务端返回的数据
     *
     * @param item
     */
    @Subscribe
    public void onEventMainThread(ProductTransferredInAndOutNumResultList item) {
        if (item != null && !item.getResultList().isEmpty()) {
            list.addAll(item.getResultList());
            adapter = new GoodsTransferredInOrOutDetailsAdapter(list, this);
            publicListViewElv.setAdapter(adapter);
            adapter.notifyDataSetChanged();
            // 1、首次加载全部展开：
            publicListViewElv.setAdapter(adapter);
            for (int i = 0; i < list.size(); i++) {
                publicListViewElv.expandGroup(i);
            }
            //提醒：加载前别忘了判断adapter是否为空和有没有Group数据哦、

            //2、不能点击收缩：
            publicListViewElv.setOnGroupClickListener(new ExpandableListView.OnGroupClickListener() {

                @Override
                public boolean onGroupClick(ExpandableListView parent, View v,
                                            int groupPosition, long id) {
                    return true;
                }
            });
        }
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.GoodsManager.MSG_ON_FIND_TRANSFERRED_INANDOUT_DETAIL: {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        ProductTransferredInAndOutNumResultList mProductTransferredInAndOutNumResultList = new Gson().fromJson(msg, ProductTransferredInAndOutNumResultList.class);
                        Log.d(TAG, "mProductTransferredInAndOutNumResultList=" + mProductTransferredInAndOutNumResultList.toString());
                        if (!mProductTransferredInAndOutNumResultList.getResultList().isEmpty()) {
                            EventBus.getDefault().post(mProductTransferredInAndOutNumResultList);
                        } else {
                            showMsg(result.getResultInfo());
                        }
                    }
                }
                break;
                default:
                    break;
            }
        }

    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        EventBus.getDefault().unregister(this);
    }
}