package com.wgmf.yxgj.module.business.managestaff.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

/**
 * 作者：XiePing on 2016/5/31 16:31
 * 邮箱：2975837870@qq.com
 */
@SuppressWarnings("all")
public class StaffManageService extends BaseService {
    private static BaseSingleton<StaffManageService, Void> mMainService = new BaseSingleton<StaffManageService, Void>() {
        @Override
        protected StaffManageService create(Void var1) {
            return new StaffManageService();
        }
    };

    public static StaffManageService getInstance() {
        return mMainService.get(null);
    }

    private StaffManageService() {
    }

    /**
     * 查询营养顾问 GET /nutritionConsultant/queryNutritionConsultant
     */
    public void requestQueryNutritionConsultant(final String staffIdOrName, final String organizationId,
                                                ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_QUERY_NUTRITION_CONSULTANT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_STAFF_QUERY + "?"
                + "staffIdOrName="
                + staffIdOrName
                + "&organizationId="
                + organizationId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * 员工入职 POST /nutritionConsultant/entryNutritionConsultant
     */
    public void requestEntryNutritionConsultant(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_ENTRY_NUTRITIONCONSULTANT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_STAFF_ENTRY;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * 员工离职 POST /nutritionConsultant/resignNutritionConsultant
     */
    public void requestResignNutritionConsultant(final String json,
                                                 ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_RESIGN_NUTRITIONCONSULTANT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_STAFF_EXIT;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * 员工入职审批 POST /nutritionConsultant/approveNutritionConsultant
     */
    public void requestApproveNutritionConsultant(final String json,
                                                  ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_APPROVE_NUTRITIONCONSULTANT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_STAFF_APPROVE;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * 营养顾问信息修改 POST /nutritionConsultant/updateNutritionConsultant
     */
    public void requestUpdateNutritionConsultant(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_UPDATE_USER_REHIRE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_UPDATE_NUTRITION_CONSULTANT;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * post /nutritionConsultant/updateUserRehire 营养顾问返聘
     */
    public void requestUpdateUserRehire(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_UPDATE_NUTRITION_CONSULTANT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_UPDATE_USER_REHIRE;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /nutritionConsultant/checkNutritionConsultant 检验营养顾问是否可以入职
     */
    public void requestCheckNutritionConsultant(final String staffId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_CHECK_NUTRITION_CONSULTANT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_CHECK_NUTRITION_CONSULTANT + "?"
                + "staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /nutritionConsultant/findNutConsultantScheduling 流动营养顾问排班查询
     *
     * @param orgId    销售组织id
     * @param orgCode1 销售组织code1
     * @param callback
     */
    public void requestFindNutConsultantScheduling(final String orgId, final String orgCode1,
                                                   ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_FIND_NUTCONSULTANT_SCHEDULING;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_NUTCONSULTANT_SCHEDULING + "?"
                + "orgId=" + orgId + "&orgCode1=" + orgCode1;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /nutritionConsultant/findThreeAndCurrentDayScheduling 流动营养顾问排班查询-当天和前三天
     *
     * @param staffId  流动营养顾问id
     * @param callback
     */
    public void requestFindThreeAndCurrentDayScheduling(final String staffId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_FIND_THREEANDCURRENTDAY_SCHEDULING;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_THREEANDCURRENTDAY_SCHEDULING + "?"
                + "staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /nutritionConsultant/findOneMonthScheduling 查询一个月的流动营养顾问排班查询
     */
    public void requestFindOneMonthScheduling(final String staffId, final String month, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_FIND_ONEMONTH_SCHEDULING;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_ONEMONTH_SCHEDULING + "?"
                + "staffId=" + staffId + "&month=" + month;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /nutritionConsultant/saveOrUpdateScheduling 新增或者更新流动营养顾问排班
     */
    public void requestSaveOrUpdateScheduling(final String json,
                                              ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_SAVEORUPDATE_SCHEDULING;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVEORUPDATE_SCHEDULING;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /nutritionConsultant/findTrainTutor 查询门店的督导或店长 又或营养顾问
     */
    public void requestFindTrainTutor(final String staffId, final String shopId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_FIND_TRAIN_TUTOR;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_TRAIN_TUTOR + "?"
                + "staffId=" + staffId + "&shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /nutritionConsultant/findOutsourced 外包公司查询
     */
    public void requestFindOutsourced(ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_FIND_OUT_SOURCED;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_OUT_SOURCED;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /nutritionConsultant/findStaffAuditionAppraiseList 查询营养顾问面试评估记录
     */
    public void requestFindStaffAuditionAppraiseList(final String staffId, final String yearMonth,
                                                     ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_FIND_STAFF_AUDITION_APPRAISELIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_STAFF_AUDITION_APPRAISELIST + "?" + "yearMonth=" + yearMonth + "&staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /nutritionConsultant/findStaffAuditionAppraise 查询单个营养顾问面试评估记录
     */
    public void requestFindStaffAuditionAppraise(final String identityCard, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_FIND_STAFF_AUDITION_APPRAISE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_STAFF_AUDITION_APPRAISE + "?" + "identityCard=" + identityCard;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /nutritionConsultant/saveStaffAuditionAppraise 新增营养顾问面试评估
     */
    public void requestSaveStaffAuditionAppraise(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_SAVE_STAFF_AUDITION_APPRAISE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_STAFF_AUDITION_APPRAISE;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /nutritionConsultant/getNutrConsultantSalary 获取顾问底薪
     */
    public void requestGetNutrConsultantSalary(final String url, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_GET_NUTRCONSULTANT_SALARY;
        request.callback = new WeakReference<>(callback);
        request.url = url;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /nutritionConsultant/queryNeedUpdateWorkersList 查询没有合同图片的顾问信息
     */
    public void requestQueryNeedUpdateWorkersList(final String staffId, final String organizationId,
                                                  ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StaffManage.MSG_ON_QUERY_NEED_UPDATE_WORKERS_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_NEED_UPDATE_WORKERS_LIST + "?"
                + "staffId="
                + staffId
                + "&organizationId="
                + organizationId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.StaffManage.MSG_ON_QUERY_NUTRITION_CONSULTANT:
                case BusinessID.StaffManage.MSG_ON_ENTRY_NUTRITIONCONSULTANT:
                case BusinessID.StaffManage.MSG_ON_RESIGN_NUTRITIONCONSULTANT:
                case BusinessID.StaffManage.MSG_ON_APPROVE_NUTRITIONCONSULTANT:
                case BusinessID.StaffManage.MSG_ON_UPDATE_NUTRITION_CONSULTANT:
                case BusinessID.StaffManage.MSG_ON_UPDATE_USER_REHIRE:
                case BusinessID.StaffManage.MSG_ON_CHECK_NUTRITION_CONSULTANT:
                case BusinessID.StaffManage.MSG_ON_FIND_NUTCONSULTANT_SCHEDULING:
                case BusinessID.StaffManage.MSG_ON_FIND_THREEANDCURRENTDAY_SCHEDULING:
                case BusinessID.StaffManage.MSG_ON_FIND_ONEMONTH_SCHEDULING:
                case BusinessID.StaffManage.MSG_ON_SAVEORUPDATE_SCHEDULING:
                case BusinessID.StaffManage.MSG_ON_FIND_TRAIN_TUTOR:
                case BusinessID.StaffManage.MSG_ON_FIND_OUT_SOURCED:
                case BusinessID.StaffManage.MSG_ON_FIND_STAFF_AUDITION_APPRAISELIST:
                case BusinessID.StaffManage.MSG_ON_FIND_STAFF_AUDITION_APPRAISE:
                case BusinessID.StaffManage.MSG_ON_SAVE_STAFF_AUDITION_APPRAISE:
                case BusinessID.StaffManage.MSG_ON_QUERY_NEED_UPDATE_WORKERS_LIST:
                case BusinessID.StaffManage.MSG_ON_GET_NUTRCONSULTANT_SALARY: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}