package com.wgmf.yxgj.app;

import android.content.Context;
import android.support.multidex.MultiDex;
import android.util.Log;

import com.alibaba.android.arouter.launcher.ARouter;
import com.facebook.stetho.Stetho;
import com.taobao.sophix.SophixManager;
import com.taobao.sophix.listener.PatchLoadStatusListener;
import com.tencent.bugly.Bugly;
import com.wgmf.library.app.WGMFLibApplication;
import com.wgmf.library.global.AppParams;
import com.wgmf.library.utils.LogUtils;
import com.wgmf.yxgj.db.GreenDaoManager;
import com.wgmf.yxgj.utils.helper.CrashHandler;

import cn.jpush.android.api.JPushInterface;

/**
 * @author xiep on 2017/6/21 15:30
 */
@SuppressWarnings("all")
public class LibApplication extends WGMFLibApplication {

    @Override
    public void onCreate() {
        super.onCreate();
        queryPatch();
        initContext();
        initCrash();
        initDB();
        initSDK();
    }

    private void initCrash() {
        CrashHandler crashHandler = CrashHandler.getInstance();
        crashHandler.init(getApplicationContext());
    }

    private void initDB() {
        GreenDaoManager.getInstance().getDaoSession(this);
    }

    private void queryPatch() {
        SophixManager.getInstance().queryAndLoadNewPatch();
    }

    @Override
    protected void attachBaseContext(Context base) {
        super.attachBaseContext(base);
        MultiDex.install(base);
        initSophix();
    }

    private void initSophix() {
        String appVersion;
        try {
            appVersion = this.getPackageManager().getPackageInfo(this.getPackageName(), 0).versionName;
        } catch (Exception e) {
            appVersion = "2.9.0";
        }
        SophixManager.getInstance().setContext(this)
                .setAppVersion(appVersion)
                //加入修复出错，暂时不加,setEnableDebug(false)
                .setAesKey("YXGJ20170707YXGJ")
                .setEnableDebug(false)
                .setPatchLoadStatusStub(new PatchLoadStatusListener() {
                    @Override
                    public void onLoad(final int mode, final int code, final String info, final int handlePatchVersion) {
                        String msg = new StringBuilder("").append("Mode:").append(mode)
                                .append(" Code:").append(code)
                                .append(" Info:").append(info)
                                .append(" HandlePatchVersion:").append(handlePatchVersion).toString();
                        Log.e("Sophix", msg);
                    }
                }).initialize();
    }

    private void initSDK() {
        initJPush();
        initBugly();
        initArouter();
        initStetho();
    }

    private void initJPush() {
        // 设置开启日志,发布时请关闭日志
        JPushInterface.setDebugMode(false);
        // 初始化 JPush
        JPushInterface.init(LibGroupContext.getApplication());
    }

    private void initBugly() {
        String buglyAppId = AppParams.BUGLY_APP_ID;
        if (!LogUtils.isApkDebugable(this)) {
            buglyAppId = AppParams.BUGLY_APP_ID_RELEASE;
        }
        Bugly.init(LibGroupContext.getApplication(), buglyAppId, false);
    }

    private void initArouter() {
        if (LogUtils.isApkDebugable(this)) {
            // 打印日志
            ARouter.openLog();
            // 开启调试模式(如果在InstantRun模式下运行，必须开启调试模式！线上版本需要关闭,否则有安全风险)
            ARouter.openDebug();
        }
        ARouter.init(this);
    }

    private void initStetho() {
        Stetho.initialize(Stetho
                .newInitializerBuilder(this)
                .enableDumpapp(Stetho.defaultDumperPluginsProvider(this))
                .enableWebKitInspector(
                        Stetho.defaultInspectorModulesProvider(this)).build());
    }

    @Override
    public void onLowMemory() {
        super.onLowMemory();
        System.gc();
    }
}