package com.wgmf.yxgj.base;

import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.os.Looper;
import android.util.Log;

import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.PermissionsCheckerUtil;
import com.wgmf.yxgj.other.PermissionsActivity;
import com.wgmf.yxgj.other.UpdateManager;

/**
 * @author xiep
 */
public class BaseParentAct extends BaseActivity implements ResultData.BusinessCallback {
    /**
     * 请求码
     */
    private static final int REQUEST_CODE = 0;
    /**
     * 权限检测器
     */
    private PermissionsCheckerUtil mPermissionsChecker;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        //动态权限检查
        mPermissionsChecker = new PermissionsCheckerUtil(this);
        //检测版本升级
        checkUpdate(this);
    }

    @Override
    public void onBusinessResult(final ResultData result) {
        if (!isFinishing()) {
            if (!isMainThread()) {
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        try {
                            onBusinessResultAtMainThread(result);
                        } catch (Exception e) {
                            Log.e("BaseParentAct", e + "");
                        }
                    }
                });
            } else {
                onBusinessResultAtMainThread(result);
            }
        }
    }

    /**
     * callBack回来到主线程执行
     */
    protected void onBusinessResultAtMainThread(ResultData result) {
        // 由子类继承处理业务逻辑
    }

    private boolean isMainThread() {
        return Looper.myLooper() == Looper.getMainLooper();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        // 拒绝时, 关闭页面, 缺少主要权限, 无法运行
        if (requestCode == REQUEST_CODE && resultCode == PermissionsActivity.PERMISSIONS_DENIED) {
            finish();
        }
    }

    @Override
    protected void onResume() {
        // 缺少权限时, 进入权限配置页面
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M && mPermissionsChecker.lacksPermissions(PermissionsCheckerUtil.PERMISSIONS)) {
            PermissionsActivity.startActivityForResult(this, REQUEST_CODE, PermissionsCheckerUtil.PERMISSIONS);
        }
        super.onResume();
    }

    /**
     * 检查版本更新
     *
     * @param context LoginActivity
     */
    void checkUpdate(Context context) {
        UpdateManager updateManager = new UpdateManager(context);
        updateManager.checkUpdate();
    }
}