package com.wgmf.yxgj.base;

import android.app.Activity;
import android.os.Bundle;
import android.os.Looper;
import android.support.annotation.Nullable;
import android.util.Log;

import com.trello.rxlifecycle.components.support.RxFragment;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.ThreadUtils;
import com.wgmf.library.utils.ToastUtil;
import com.wgmf.yxgj.db.CommonResourcesBeanDao;
import com.wgmf.yxgj.db.CommonUserinfoBeanDao;
import com.wgmf.yxgj.db.GreenDaoManager;
import com.wgmf.yxgj.dialog.PublicDialogLoading;
import com.wgmf.yxgj.model.CommonResourcesBean;
import com.wgmf.yxgj.model.CommonUserinfoBean;

import java.util.List;

/**
 * @author xiep
 */
public class BaseParentFra extends RxFragment implements ResultData.BusinessCallback {

    protected static String TAG = BaseParentFra.class.getSimpleName();

    protected static CommonUserinfoBean userInfo;

    protected static List<CommonResourcesBean> resources;

    private PublicDialogLoading dialog;

    protected void showMsg(String msg) {
        ToastUtil.show(getActivity(), msg);
    }

    protected void showDialog() {
        if (null == dialog) {
            dialog = new PublicDialogLoading(getActivity());
        }
        if (!dialog.isShowing()) {
            dialog.show();
        }
    }

    protected void dismissDialog() {
        try {
            if (null != dialog && dialog.isShowing()) {
                dialog.dismiss();
            }
        } catch (Exception e) {
            Log.e(TAG, "dismissDialog: error");
        }
    }

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getUserInfo();
        getResourcesData();
    }

    public CommonUserinfoBean getUserInfo() {
        try {
            CommonUserinfoBeanDao mCommonUserinfoBeanDao = GreenDaoManager.getInstance().getDaoSession(getActivity()).getCommonUserinfoBeanDao();
            userInfo = mCommonUserinfoBeanDao.loadAll().get(0);
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return userInfo;
    }

    public List<CommonResourcesBean> getResourcesData() {
        try {
            CommonResourcesBeanDao mCommonResourcesBeanDao = GreenDaoManager.getInstance().getDaoSession(getActivity()).getCommonResourcesBeanDao();
            resources = mCommonResourcesBeanDao.loadAll();
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return resources;
    }

    private boolean isMainThread() {
        return Looper.myLooper() == Looper.getMainLooper();
    }

    private boolean isAlive() {
        Activity activity = getActivity();
        return activity != null && !activity.isFinishing() && !isRemoving() && !isDetached() && isAdded();
    }

    @Override
    public void onBusinessResult(final ResultData result) {
        if (isAlive()) {
            if (isMainThread()) {
                onBusinessResultAtMainThread(result);
            } else {
                ThreadUtils.runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        if (isAlive()) {
                            onBusinessResultAtMainThread(result);
                        }
                    }
                });
            }
        }
    }

    /**
     * callBack回来到主线程执行
     */
    protected void onBusinessResultAtMainThread(ResultData result) {
        // 由子类继承处理业务逻辑
    }
}