package com.wgmf.yxgj.base;

import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import com.squareup.okhttp.Call;
import com.squareup.okhttp.Callback;
import com.squareup.okhttp.MediaType;
import com.squareup.okhttp.Request;
import com.squareup.okhttp.RequestBody;
import com.squareup.okhttp.Response;
import com.wgmf.library.base.BaseHttpClient;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.NetworkUtil;
import com.wgmf.library.utils.StringUtil;
import com.wgmf.library.utils.tools.PrefTool;
import com.wgmf.yxgj.app.LibGroupContext;
import com.wgmf.yxgj.global.Prefs;

import java.io.IOException;
import java.net.HttpURLConnection;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;

/**
 * @author xiep  on 2016/5/13 16:28
 */
@SuppressWarnings("all")
public abstract class BaseService {
    protected static final  String TAG = BaseService.class.getSimpleName();

    private static ExecutorService threadPool = Executors.newCachedThreadPool();

    private static final  BaseHttpClient CLIENT = BaseHttpClient.getInstance();

    /**
     * （单位：秒）
     */
    private static final int TIME_OUT_SECONDS = 30;

    static {
        CLIENT.setConnectTimeout(TIME_OUT_SECONDS, TimeUnit.SECONDS);
        CLIENT.setReadTimeout(TIME_OUT_SECONDS, TimeUnit.SECONDS);
        CLIENT.setWriteTimeout(TIME_OUT_SECONDS, TimeUnit.SECONDS);
    }

    private void onTaskDone(final ResultData data, final ResultData.BusinessCallback callback) {
        try {
            onTaskDone(data);
            // 在这里把所有请求异常给catch住
        } catch (Throwable e) {
            Log.e(TAG, "onTaskDone case error by " + e.getMessage());
            e.printStackTrace();
        }
        try {
            if (null != callback) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    @Override
                    public void run() {
                        callback.onBusinessResult(data);
                    }
                });

            }
            // 在这里把所有请求异常给catch住
        } catch (Throwable e) {
            Log.e(TAG, "callback onBusinessResult case error by " + e.getMessage());
            e.printStackTrace();
        }
    }

    /**
     * 子类必须继承处理相应的业务逻辑
     *
     * @param data 接口返回数据
     */
    protected abstract void onTaskDone(ResultData data);

    /**
     * OkHttp
     * get方式请求网络数据
     *
     * @param request BaseRequest
     */
    protected final void sendGetRequest(final BaseRequest request) {
        Request.Builder builder = new Request.Builder();
        setRequestHeader(builder);
        Request okRequest = builder.url(request.url).build();
        requestOkHttp(request, okRequest);
    }

    /**
     * OkHttp
     * post方式请求网络数据
     *
     * @param request BaseRequest
     */
    protected final void sendPostRequest(final BaseRequest request) {
        Request.Builder builder = new Request.Builder();
        setRequestHeader(builder);
        Request okRequest = builder
                .url(request.url)
                .post(request.builder.build())
                .build();
        requestOkHttp(request, okRequest);
    }

    /**
     * OkHttp
     * post方式请求发json网络数据
     *
     * @param request BaseRequest
     */

    protected final void sendPostJsonRequest(final BaseRequest request) {
        final MediaType mediaTypeJson = MediaType.parse("application/json; charset=utf-8");
        RequestBody requestBody = RequestBody.create(mediaTypeJson, request.json);
        Request.Builder builder = new Request.Builder();
        setRequestHeader(builder);
        Request okRequest = builder.url(request.url)
                .post(requestBody)
                .build();
        requestOkHttp(request, okRequest);
    }

    /**
     * 添加请求头
     */
    private void setRequestHeader(Request.Builder builder) {
        try {
            String staffId = PrefTool.getStringPerferences(LibGroupContext.getApplication(), Prefs.PRE_USER_STAFFID);
            if (staffId != null) {
                builder.addHeader("staffId", staffId);
            }
        } catch (Exception e) {
            Log.e(TAG, "run: ", e);
        }
    }

    /**
     * 请求网络数据
     *
     * @param request   BaseRequest
     * @param okRequest Request
     */
    private void requestOkHttp(final BaseRequest request, final Request okRequest) {
        if (StringUtil.isNullOrEmpty(request.url)) {
            throw new NullPointerException("BaseService sendPostRequest error request url can't be null!");
        }
        threadPool.submit(new Runnable() {
                              @Override
                              public void run() {
                                  Callback callback = new Callback() {
                                      ResultData resultData = new ResultData();

                                      @Override
                                      public void onFailure(Request requests, IOException e) {
                                          resultData.taskID = request.taskID;
                                          resultData.setSuccess(false);
                                          resultData.setResultInfo("服务器请求失败");
                                          onTaskDone(resultData, null == request.callback ? null : request.callback.get());
                                      }

                                      @Override
                                      public void onResponse(Response response) throws IOException {
                                          if (response.code() != HttpURLConnection.HTTP_OK) {
                                              resultData.setResultInfo("服务器请求失败！\n 错误码：" + response.code());
                                              resultData.setSuccess(false);
                                          }else{
                                              resultData.setSuccess(true);
                                          }
                                          resultData.taskID = request.taskID;
                                          resultData.setInfo(response.body().string());
                                          Log.d(TAG, "返回Json：" + resultData.getInfo());
                                          resultData.setRequest(request);
                                          onTaskDone(resultData, null == request.callback ? null : request.callback.get());
                                      }
                                  };
                                  final boolean isNetConnect = NetworkUtil.isNetworkAvailable(LibGroupContext.getApplication());
                                  final boolean isUrl = StringUtil.isUrl(request.url);
                                  if (isNetConnect && isUrl) {
                                      Call call = CLIENT.newCall(okRequest);
                                      call.enqueue(callback);
                                  } else {
                                      ResultData resultData = new ResultData();
                                      if (!isNetConnect) {
                                          resultData.setResultInfo("网络未连接，请检查网络设置。");
                                      } else {
                                          resultData.setResultInfo("网络不给力，请稍后重试。");
                                      }
                                      resultData.taskID = request.taskID;
                                      resultData.setRequest(request);
                                      resultData.setSuccess(false);
                                      onTaskDone(resultData, null == request.callback ? null : request.callback.get());
                                  }
                              }
                          }
        );
    }
}