package com.wgmf.yxgj.dialog;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.yxgj.base.R;

/**
 * @author xiep
 */
public class PublicConformTipDialog extends Dialog {

    public PublicConformTipDialog(Context context) {
        super(context);
    }

    @SuppressWarnings("all")
    private PublicConformTipDialog(Context context, int theme) {
        super(context, R.style.textview_dialog);
    }

    public static class Builder {
        private Context context;
        private String title;
        private String message;
        private String negativeButtonText;
        private View contentView;
        private TextView updateDialogTitleTv;
        private TextView textviewDialogContent;
        private OnClickListener negativeButtonClickListener;

        public Builder(Context context) {
            this.context = context;
        }

        public Builder setMessage(String message) {
            this.message = message;
            return this;
        }

        /**
         * Set the Dialog message from resource
         *
         * @param message 用户信息
         * @return Builder 对象
         */
        public Builder setMessage(int message) {
            this.message = (String) context.getText(message);
            return this;
        }

        /**
         * Set the Dialog title from resource
         *
         * @param title 标题
         * @return Builder对象
         */
        public Builder setTitle(int title) {
            this.title = (String) context.getText(title);
            return this;
        }

        /**
         * Set the Dialog title from resource
         *
         * @return Builder对象
         */
        public Builder setTitleView(int gravity, int color) {
            this.updateDialogTitleTv.setGravity(gravity);
            this.updateDialogTitleTv.setTextColor(color);
            return this;
        }
        /**
         * Set the Dialog message from resource
         *
         * @return Builder对象
         */
        public Builder setMessageView(int gravity, int color) {
            this.textviewDialogContent.setGravity(gravity);
            this.textviewDialogContent.setTextColor(color);
            return this;
        }

        /**
         * Set the Dialog title from String
         *
         * @param title 标题
         * @return Builder对象
         */

        public Builder setTitle(String title) {
            this.title = title;
            return this;
        }

        public Builder setNegativeButton(int negativeButtonText,
                                         OnClickListener listener) {
            this.negativeButtonText = (String) context
                    .getText(negativeButtonText);
            this.negativeButtonClickListener = listener;
            return this;
        }

        public Builder setNegativeButton(String negativeButtonText,
                                         OnClickListener listener) {
            this.negativeButtonText = negativeButtonText;
            this.negativeButtonClickListener = listener;
            return this;
        }

        public Builder setMessageView(View v) {
            this.contentView = v;
            return this;
        }

        public PublicConformTipDialog create() {
            // instantiate the dialog with the custom Theme
            final PublicConformTipDialog dialog = new PublicConformTipDialog(context, R.style.textview_dialog);
            View layout = LayoutInflater.from(context).inflate(R.layout.view_textview_dialog, null);
            dialog.addContentView(layout, new LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
            // set the dialog title
            updateDialogTitleTv = ((TextView) layout.findViewById(R.id.update_dialog_title_tv));
            updateDialogTitleTv.setText(title);
            // set the cancel button
            if (negativeButtonText != null) {
                ((Button) layout.findViewById(R.id.textview_dialog_cancel_btn))
                        .setText(negativeButtonText);
                if (negativeButtonClickListener != null) {
                    layout.findViewById(R.id.textview_dialog_cancel_btn)
                            .setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    negativeButtonClickListener.onClick(dialog,
                                            DialogInterface.BUTTON_NEGATIVE);
                                }
                            });
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.textview_dialog_cancel_btn).setVisibility(View.GONE);
            }
            // set the content message
            if (message != null) {
                textviewDialogContent = ((TextView) layout.findViewById(R.id.textview_dialog_content));
                textviewDialogContent.setText(message);
            } else if (contentView != null) {
                // if no message set
                // add the contentView to the dialog body
                ((LinearLayout) layout
                        .findViewById(R.id.dialog_btn_ll))
                        .removeAllViews();
                ((LinearLayout) layout
                        .findViewById(R.id.dialog_btn_ll)).addView(
                        contentView, new LayoutParams(LayoutParams.MATCH_PARENT,
                                LayoutParams.MATCH_PARENT));
            }
            dialog.setContentView(layout);
            return dialog;
        }
    }
}