package com.wgmf.yxgj.dialog;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.yxgj.base.R;

/**
 * @author xiep
 */
public class PublicTipDialog extends Dialog {

    private PublicTipDialog(Context context, int theme) {
        super(context, theme);
        //这句代码设置这个对话框是否能被用户触摸取消掉
        setCanceledOnTouchOutside(false);
        //这句代码设置这个对话框是否能被用户按[返回键]而取消掉
        setCancelable(false);
    }

    public static class Builder {
        private Context context;
        private String title;
        private String message;
        private String positiveButtonText;
        private String negativeButtonText;
        private View contentView;
        private TextView updateDialogTitleTv;
        private TextView updateDialogContentTv;
        private Button updateDialogConfirmBtn;
        private OnClickListener positiveButtonClickListener;
        private OnClickListener negativeButtonClickListener;

        public Builder(Context context) {
            this.context = context;
        }

        public Builder setMessage(String message) {
            this.message = message;
            return this;
        }

        /**
         * Set the Dialog message from resource
         */
        public Builder setMessage(int message) {
            this.message = (String) context.getText(message);
            return this;
        }

        /**
         * Set the Dialog title from resource
         */
        public Builder setTitle(int title) {
            this.title = (String) context.getText(title);
            return this;
        }

        /**
         * Set the Dialog title from String
         */

        public Builder setTitle(String title) {
            this.title = title;
            return this;
        }

        public Builder setContentView(View v) {
            this.contentView = v;
            return this;
        }

        /**
         * Set the Dialog title from resource
         *
         * @return Builder对象
         */
        public PublicTipDialog.Builder setTitleView(int gravity, int color) {
            this.updateDialogTitleTv.setGravity(gravity);
            this.updateDialogTitleTv.setTextColor(color);
            return this;
        }

        /**
         * Set the Dialog message from resource
         *
         * @return Builder对象
         */
        public PublicTipDialog.Builder setMessageView(int gravity, int color) {
            this.updateDialogContentTv.setGravity(gravity);
            this.updateDialogContentTv.setTextColor(color);
            return this;
        }

        /**
         * Set the Dialog message from resource
         *
         * @return Builder对象
         */
        public PublicTipDialog.Builder setDialogConfirmBtnView(int textColor, int bgColor) {
            this.updateDialogConfirmBtn.setTextColor(textColor);
            return this;
        }

        /**
         * Set the positive button resource and it's listener
         */
        public Builder setPositiveButton(int positiveButtonText, OnClickListener listener) {
            this.positiveButtonText = (String) context
                    .getText(positiveButtonText);
            this.positiveButtonClickListener = listener;
            return this;
        }

        public Builder setPositiveButton(String positiveButtonText, OnClickListener listener) {
            this.positiveButtonText = positiveButtonText;
            this.positiveButtonClickListener = listener;
            return this;
        }

        public Builder setNegativeButton(int negativeButtonText,
                                         OnClickListener listener) {
            this.negativeButtonText = (String) context
                    .getText(negativeButtonText);
            this.negativeButtonClickListener = listener;
            return this;
        }

        public Builder setNegativeButton(String negativeButtonText,
                                         OnClickListener listener) {
            this.negativeButtonText = negativeButtonText;
            this.negativeButtonClickListener = listener;
            return this;
        }

        public PublicTipDialog create() {
            // instantiate the dialog with the custom Theme
            final PublicTipDialog dialog = new PublicTipDialog(context,
                    R.style.textview_dialog);
            View layout = LayoutInflater.from(context).inflate(R.layout.view_update_dialog, null);
            dialog.addContentView(layout, new LayoutParams(
                    LayoutParams.MATCH_PARENT, LayoutParams.MATCH_PARENT));
            updateDialogTitleTv = ((TextView) layout.findViewById(R.id.update_dialog_title_tv));
            updateDialogTitleTv.setText(title);
            if (message != null) {
                updateDialogContentTv = ((TextView) layout.findViewById(R.id.update_dialog_content_tv));
                updateDialogContentTv.setText(message);
            }
            // set the confirm button
            if (positiveButtonText != null) {
                ((Button) layout.findViewById(R.id.update_dialog_cancel_btn))
                        .setText(positiveButtonText);
                if (positiveButtonClickListener != null) {
                    layout.findViewById(R.id.update_dialog_cancel_btn)
                            .setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    positiveButtonClickListener.onClick(dialog,
                                            DialogInterface.BUTTON_POSITIVE);
                                }
                            });
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.update_dialog_cancel_btn)
                        .setVisibility(View.GONE);
            }
            // set the cancel button
            if (negativeButtonText != null) {
                updateDialogConfirmBtn = ((Button) layout.findViewById(R.id.update_dialog_confirm_btn));
                updateDialogConfirmBtn.setText(negativeButtonText);
                if (negativeButtonClickListener != null) {
                    layout
                            .findViewById(R.id.update_dialog_confirm_btn)
                            .setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    negativeButtonClickListener.onClick(dialog,
                                            DialogInterface.BUTTON_NEGATIVE);
                                }
                            });
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.update_dialog_confirm_btn)
                        .setVisibility(View.GONE);
            }
            // set the content message
            if (message != null) {
                ((TextView) layout.findViewById(R.id.update_dialog_content_tv))
                        .setText(message);
            } else if (contentView != null) {
                // if no message set
                // add the contentView to the dialog body
                ((LinearLayout) layout
                        .findViewById(R.id.dialog_btn_ll))
                        .removeAllViews();
                ((LinearLayout) layout
                        .findViewById(R.id.dialog_btn_ll)).addView(
                        contentView, new LayoutParams(LayoutParams.MATCH_PARENT,
                                LayoutParams.MATCH_PARENT));
            }
            dialog.setContentView(layout);
            return dialog;
        }
    }
}