package com.wgmf.yxgj.dialog;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.wgmf.yxgj.base.R;

/**
 * @author xiep
 */
public class RatingsReportAppraiseEdtDialog extends Dialog {

    private RatingsReportAppraiseEdtDialog(Context context) {
        super(context, R.style.textview_dialog);
    }

    public static class Builder {
        private Context context;
        private int isComplete;
        private String title;
        private String positiveButtonText;
        private String negativeButtonText;
        private View contentView;
        private OnClickListener positiveButtonClickListener;
        private OnClickListener negativeButtonClickListener;
        private EditText isCompleteNumberEt;
        private RadioButton isCompleteContentYes;
        private RadioButton isCompleteContentNo;

        public Builder(Context context) {
            this.context = context;
        }

        public int getIsComplete() {
            return isComplete;
        }

        private void setIsComplete(int isComplete) {
            this.isComplete = isComplete;
        }

        /**
         * @return the nember
         */
        public String getNember() {
            return isCompleteNumberEt.getText().toString();
        }

        /**
         * Set the Dialog title from resource
         */
        public Builder setTitle(int title) {
            this.title = (String) context.getText(title);
            return this;
        }

        /**
         * Set the Dialog title from String
         */

        public Builder setTitle(String title) {
            this.title = title;
            return this;
        }

        public Builder setContentView(View v) {
            this.contentView = v;
            return this;
        }

        /**
         * Set the positive button resource and it's listener
         */
        public Builder setPositiveButton(int positiveButtonText,
                                         OnClickListener listener) {
            this.positiveButtonText = (String) context
                    .getText(positiveButtonText);
            this.positiveButtonClickListener = listener;
            return this;
        }

        public Builder setPositiveButton(OnClickListener listener) {
            this.positiveButtonText = "取消";
            this.positiveButtonClickListener = listener;
            return this;
        }

        public Builder setNegativeButton(int negativeButtonText,
                                         OnClickListener listener) {
            this.negativeButtonText = (String) context
                    .getText(negativeButtonText);
            this.negativeButtonClickListener = listener;
            return this;
        }

        public Builder setNegativeButton(OnClickListener listener) {
            this.negativeButtonText = "确定";
            this.negativeButtonClickListener = listener;
            return this;
        }

        public RatingsReportAppraiseEdtDialog create() {
            // instantiate the dialog with the custom Theme
            final RatingsReportAppraiseEdtDialog dialog = new RatingsReportAppraiseEdtDialog(context
            );
            View layout = LayoutInflater.from(context).inflate(R.layout.appriase_ratings_report_dialog, null);
            dialog.addContentView(layout, new LayoutParams(
                    LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT));
            // set the dialog title
            ((TextView) layout.findViewById(R.id.appriase_title_tv))
                    .setText(title);
            isCompleteNumberEt = ((EditText) layout
                    .findViewById(R.id.is_complete_et));
            isCompleteContentYes = ((RadioButton) layout
                    .findViewById(R.id.is_complete_content_yes));
            isCompleteContentNo = ((RadioButton) layout
                    .findViewById(R.id.is_complete_content_no));

            isCompleteContentYes.setOnClickListener(new View.OnClickListener() {

                @Override
                public void onClick(View arg0) {
                    if (isCompleteContentYes.isChecked()) {
                        setIsComplete(1);
                        isCompleteNumberEt.setVisibility(View.GONE);
                        isCompleteContentYes.setChecked(true);
                    } else {
                        setIsComplete(2);
                        isCompleteNumberEt.setVisibility(View.VISIBLE);
                        isCompleteContentNo.setChecked(true);
                    }
                }
            });
            isCompleteContentNo.setOnClickListener(new View.OnClickListener() {

                @Override
                public void onClick(View arg0) {
                    if (isCompleteContentNo.isChecked()) {
                        setIsComplete(2);
                        isCompleteNumberEt.setVisibility(View.VISIBLE);
                        isCompleteContentNo.setChecked(true);
                    } else {
                        setIsComplete(1);
                        isCompleteNumberEt.setVisibility(View.GONE);
                        isCompleteContentYes.setChecked(true);
                    }
                }
            });

            // set the confirm button
            if (positiveButtonText != null) {
                ((Button) layout.findViewById(R.id.appriase_cancel_btn))
                        .setText(positiveButtonText);
                if (positiveButtonClickListener != null) {
                    layout.findViewById(R.id.appriase_cancel_btn)
                            .setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    positiveButtonClickListener.onClick(dialog,
                                            DialogInterface.BUTTON_POSITIVE);

                                }
                            });
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.appriase_cancel_btn).setVisibility(View.GONE);
            }
            // set the cancel button
            if (negativeButtonText != null) {
                ((Button) layout.findViewById(R.id.appriase_confirm_btn))
                        .setText(negativeButtonText);
                if (negativeButtonClickListener != null) {
                    layout.findViewById(R.id.appriase_confirm_btn)
                            .setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    negativeButtonClickListener.onClick(dialog,
                                            DialogInterface.BUTTON_NEGATIVE);
                                }
                            });
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.appriase_confirm_btn).setVisibility(View.GONE);
            }
            if (contentView != null) {
                // if no message set
                // add the contentView to the dialog body
                ((RelativeLayout) layout.findViewById(R.id.appriase_content_rl))
                        .removeAllViews();
                ((RelativeLayout) layout.findViewById(R.id.appriase_content_rl))
                        .addView(contentView, new LayoutParams(
                                LayoutParams.WRAP_CONTENT,
                                LayoutParams.WRAP_CONTENT));
            }
            dialog.setContentView(layout);
            return dialog;
        }
    }
}