package com.wgmf.yxgj.other;

import android.app.AlertDialog.Builder;
import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.net.Uri;
import android.os.Build;
import android.os.Environment;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ProgressBar;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.AppUtils;
import com.wgmf.library.utils.Files;
import com.wgmf.library.utils.ToastUtil;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.base.R;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.dialog.PublicTipDialog;
import com.wgmf.yxgj.model.GetServerVsionResponse;
import com.wgmf.yxgj.publics.service.MainService;
import com.xp.arouter.RouterParams;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.Type;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.LinkedList;

import static android.support.v4.content.FileProvider.getUriForFile;

/**
 * @author xiep
 */
@SuppressWarnings("all")
@Route(path = RouterParams.URL_UPDATEMANAGER)
public class UpdateManager extends BaseParentAct {
    private String updataInformation;
    private URL url;
    /**
     * 下载中
     */
    private static final int DOWNLOAD = 1;
    /**
     * 下载结束
     */
    private static final int DOWNLOAD_FINISH = 2;
    /**
     * 下载保存路径
     */
    private String mSavePath;
    /**
     * 记录进度条数量
     */
    private int progress;
    /**
     * 是否取消更新
     */
    private boolean cancelUpdate = false;

    private Context mContext;
    /**
     * 更新进度条
     */
    private ProgressBar mProgress;
    private Dialog mDownloadDialog;

    private Handler mUpdateManagerHandler = new Handler() {
        public void handleMessage(Message msg) {
            switch (msg.what) {
                // 正在下载
                case DOWNLOAD:
                    // 设置进度条位置
                    mProgress.setProgress(progress);
                    break;
                case DOWNLOAD_FINISH:
                    // 安装文件
                    installApk();
                    break;
                default:
                    break;
            }
        }
    };

    public UpdateManager(Context context) {
        this.mContext = context;
    }

    /**
     * 检查软件是否有更新版本
     */
    public void checkUpdate() {
        try {
            Log.d(TAG, "checkUpdate: " + userInfo.getAuthorityRoleIdBean());
            MainService.getInstance().requestUpdate(userInfo.getStaffId(), userInfo.getAuthorityRoleIdBean(), AppUtils.getVersion(mContext), "android", UpdateManager.this);
        } catch (Exception e) {
            Log.d(TAG, "checkUpdate: error");
        }
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        if (null != result) {
            final int id = result.taskID;
            if (id == BusinessID.Update.MSG_ON_USER_UPDATE) {
                final String msg = result.getInfo();
                if (result.isSuccessed()) {
                    GetServerVsionResponse resource;
                    int isUpgrade;
                    try {
                        // 是否成功
                        Type listType = new TypeToken<LinkedList<GetServerVsionResponse>>() {
                        }.getType();
                        LinkedList<GetServerVsionResponse> resources = new Gson().fromJson(msg, listType);

                        if (resources != null && !resources.isEmpty()) {
                            resource = resources.get(0);
                            Log.d(TAG, "升级信息：" + resource.toString());
                            url = new URL(resource.getUpgradeUrl());
                            isUpgrade = resource.getIsUpgrade();
                            updataInformation = resource.getInformation()
                                    .replace("：", ":" + "\n\n")
                                    .replace("；", ";" + "\n\n");
                            Log.d(TAG, url + "");
                            // 版本判断
                            if (isUpgrade == 1) {
                                if (null != mContext) {
                                    // 如果登录界面还存在
//                                    if (PrefTool.getBooleanPreferences(mContext, Prefs.PRE_LOGINACT_STATUS, true)) {
                                    // 说明这个activity前台显示
                                    showNoticeDialog();
//                                    }
//                                    PrefTool.setBooleanSave(mContext, Prefs.PRE_LOGINACT_STATUS, false);
                                }
                            } else {
                                ToastUtil.show(mContext, "您正在使用营销管家最新版本：" + resource.getVersionNo());
                            }
//                        } else {
//                            ToastUtil.show(mContext, "当前版本：" + AppUtils.getVersion(mContext));
                        }
                    } catch (MalformedURLException e) {
                        Log.e(TAG, "Error onBusinessResultAtMainThread");
                    }
                } else {
                    ToastUtil.show(mContext, result.getResultInfo());
//                    showMsg(result.getResultInfo());
                }
            }
        }
    }

    /**
     * 显示软件更新对话框
     */
    private void showNoticeDialog() {
        PublicTipDialog.Builder builder = new PublicTipDialog.Builder(mContext);
        builder.setMessage(updataInformation);
        builder.setTitle("版本更新提示：");
        builder.setNegativeButton("确定",
                new OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        dialog.dismiss();
                        // 显示下载对话框
                        showDownloadDialog();
                    }
                });
        if (null != mContext) {
            builder.create().show();
        }
    }

    /**
     * 显示软件下载对话框
     */
    public void showDownloadDialog() {
        // 构造软件下载对话框
        Builder builder = new Builder(mContext, R.style.base_alert_dialog);
        builder.setTitle("提示");
        // 给下载对话框增加进度条
        final LayoutInflater inflater = LayoutInflater.from(mContext);
        View v = inflater.inflate(R.layout.softupdate_progress, null);
        mProgress = (ProgressBar) v.findViewById(R.id.update_progress);
        builder.setView(v);
        mDownloadDialog = builder.create();
        mDownloadDialog.setCanceledOnTouchOutside(false);
        mDownloadDialog.setCancelable(false);
        mDownloadDialog.show();
        // 现在文件
        downloadApk();
    }

    /**
     * 下载apk文件
     */
    private void downloadApk() {
        // 启动新线程下载软件
        new downloadApkThread().start();
    }

    /**
     * 下载文件线程
     */
    private class downloadApkThread extends Thread {
        @Override
        public void run() {
            InputStream is = null;
            FileOutputStream fos = null;
            try {
                // 判断SD卡是否存在，并且是否具有读写权限
                if (Environment.getExternalStorageState().equals(
                        Environment.MEDIA_MOUNTED)) {
                    // 获得存储卡的路径
                    mSavePath = Files.downfile;
                    // 创建连接
                    HttpURLConnection conn = (HttpURLConnection) url.openConnection();
                    conn.connect();
                    // 获取文件大小
                    int length = conn.getContentLength();
                    // 创建输入流
                    is = conn.getInputStream();
                    File file = new File(mSavePath);
                    // 判断文件目录是否存在
                    if (!file.exists()) {
                        file.mkdir();
                    }
                    File apkFile = new File(mSavePath, "YingXiaoGuanJia-" + AppUtils.getVersion(mContext));
                    fos = new FileOutputStream(apkFile);
                    int count = 0;
                    // 缓存
                    byte[] buf = new byte[1024];
                    // 写入到文件中
                    do {
                        int numread = is.read(buf);
                        count += numread;
                        // 计算进度条位置
                        progress = (int) (((float) count / length) * 100);
                        // 更新进度
                        mUpdateManagerHandler.sendEmptyMessage(DOWNLOAD);
                        if (numread <= 0) {
                            // 下载完成
                            mUpdateManagerHandler.sendEmptyMessage(DOWNLOAD_FINISH);
                            break;
                        }
                        // 写入文件
                        fos.write(buf, 0, numread);
                        // 点击取消就停止下载.
                    } while (!cancelUpdate);
                }
            } catch (IOException e) {
                Log.e(TAG, "Error downloadApkThread IOException", e);
            } finally {
                if (fos != null) {
                    try {
                        fos.close();
                    } catch (IOException e) {
                        Log.e(TAG, "Error downloadApkThread", e);
                    }
                }
                if (is != null) {
                    try {
                        is.close();
                    } catch (IOException e) {
                        Log.e(TAG, "Error downloadApkThread", e);
                    }
                }
            }
            // 取消下载对话框显示
            mDownloadDialog.dismiss();
        }
    }

    /**
     * 安装APK文件
     */
    private void installApk() {
        File apkfile = new File(mSavePath, "YingXiaoGuanJia-" + AppUtils.getVersion(mContext));
        if (!apkfile.exists()) {
            return;
        }
        Intent updateApk = new Intent(Intent.ACTION_VIEW);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
            //7.0及其以后版本使用升级后的代码处理
            // 由于没有在Activity环境下启动Activity,设置下面的标签
            updateApk.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
            //添加这一句表示对目标应用临时授权该Uri所代表的文件
            updateApk.addFlags(Intent.FLAG_GRANT_READ_URI_PERMISSION);
            Uri apkURI = getUriForFile(this, "com.wgmf.yxgj", apkfile);
            updateApk.setDataAndType(apkURI, "application/vnd.android.package-archive");
        } else {
            updateApk.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
            updateApk.setDataAndType(Uri.parse("file://" + apkfile.toString()),
                    "application/vnd.android.package-archive");
        }
        mContext.startActivity(updateApk);
    }
}