package com.wgmf.yxgj.publics.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;
import com.wgmf.yxgj.publics.service.request.SetJPushRequest;

import java.lang.ref.WeakReference;

/**
 * @author xiep on 2016/7/29 16:30
 */
public class PublicService extends BaseService {
    private static BaseSingleton<PublicService, Void> mMainService = new BaseSingleton<PublicService, Void>() {
        @Override
        protected PublicService create(Void var1) {
            return new PublicService();
        }
    };

    public static PublicService getInstance() {
        return mMainService.get(null);
    }

    private PublicService() {
    }

    /**
     * GET /userInfoManagement/queryManagerInfo 查询同级主管信息与门店
     */
    public void requestManagerInfo(final String url, final String code1,
                                   ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Publics.MSG_ON_MANAGER_INFO;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "code1=" + code1;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /userInfoManagement/queryWorkers 根据门店编号查找下面营养顾问
     */
    public void requestWorkersInfo(final String shopId, final String saleOrgId,
                                   ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Publics.MSG_ON_WORKERS_INFO;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_QUERY_WORKERS_LIST + "?" + "shopId=" + shopId + "&saleOrgId=" + saleOrgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /shop/getNearest 获取附近门店
     *
     * @param url         请求地址
     * @param keyWords    keywords
     * @param orgCode     组织结构编码
     * @param currentPage 当前页（从1开始）
     * @param pageSize    每页条数
     * @param lng         经度
     * @param lat         维度
     */
    public void requestgetNearestShop(final String url, final String keyWords, final String orgCode, final String currentPage, final String pageSize, final String lng, final String lat,
                                      ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Publics.MSG_ON_SHOP_GET_NEAREST;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "keyWords=" + keyWords + "&orgCode=" + orgCode + "&currentPage=" + currentPage + "&pageSize=" + pageSize + "&lng=" + lng + "&lat=" + lat;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /shop/getNearest 获取附近门店
     *
     * @param url         请求地址
     * @param keyWords    keywords
     * @param orgCode     组织结构编码
     * @param currentPage 当前页（从1开始）
     * @param pageSize    每页条数
     * @param lng         经度
     * @param lat         维度
     */
    public void requestgetNearestShopByCity(final String url, final String city, final String keyWords, final String orgCode, final String currentPage, final String pageSize, final String lng, final String lat,
                                            ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Publics.MSG_ON_SHOP_GET_NEAREST;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "keyWords=" + keyWords + "&city=" + city + "&orgCode=" + orgCode + "&currentPage=" + currentPage + "&pageSize=" + pageSize + "&lng=" + lng + "&lat=" + lat;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /shop/getNearest 获取附近门店
     * 兼职督察 盘点/门店检查功能，增加flag字段自动过滤闭店门店
     *
     * @param url         请求地址
     * @param keyWords    keywords
     * @param orgCode     组织结构编码
     * @param currentPage 当前页（从1开始）
     * @param pageSize    每页条数
     * @param lng         经度
     * @param lat         维度
     */
    public void requestgetNearestShopByFlag(final String url, final String flag, final String city, final String keyWords, final String orgCode, final String currentPage, final String pageSize, final String lng, final String lat,
                                            ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Publics.MSG_ON_SHOP_GET_NEAREST;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "keyWords=" + keyWords + "&flag=" + flag + "&city=" + city + "&orgCode=" + orgCode + "&currentPage=" + currentPage + "&pageSize=" + pageSize + "&lng=" + lng + "&lat=" + lat;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /shop/getNearest 获取附近门店
     * 经理查询直属门店标识：1表示查询直属；不传表示全部
     *
     * @param url         请求地址
     * @param keyWords    keywords
     * @param orgCode     组织结构编码
     * @param currentPage 当前页（从1开始）
     * @param pageSize    每页条数
     * @param lng         经度
     * @param lat         维度
     */
    public void requestgetNearestShopByZSFlag(final String url, final String zsShopFlag, final String city, final String keyWords, final String orgCode,
                                              final String currentPage, final String pageSize, final String lng, final String lat,
                                              ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Publics.MSG_ON_SHOP_GET_NEAREST;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "keyWords=" + keyWords + "&city=" + city + "&orgCode=" + orgCode
                + "&currentPage=" + currentPage + "&pageSize=" + pageSize + "&lng=" + lng + "&lat=" + lat + "&zsShopFlag=" + zsShopFlag;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * 获取七牛Token
     *
     * @param callback
     */
    public void requestQiNiuToken(ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Publics.MSG_ON_GET_QINIU_TOKEN;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_PRODUCT_TOKEN;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * post /frontDisplay/adPage 前端显示首页弹出广告列表
     */
    public void requestAdPage(final String staffId, final String orgId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Publics.MSG_ON_GET_AD_PAGE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_AD_PAGE + "?" + "staffId=" + staffId + "&systemType=2"+ "&orgId="+ orgId ;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.Publics.MSG_ON_GET_AD_PAGE:
                case BusinessID.Publics.MSG_ON_GET_QINIU_TOKEN:
                case BusinessID.Publics.MSG_ON_SHOP_GET_NEAREST: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}