package com.wgmf.yxgj.widgets.Dialog;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.NumberPicker;

import com.wgmf.yxgj.base.R;

import java.util.Calendar;

import javax.annotation.Nullable;

/**
 * @author xiep
 */
@SuppressWarnings("all")
public class DatePickerYearMonthDialog extends AlertDialog implements OnClickListener {
    private static final String YEAR = "year";
    private static final String MONTH = "month";
    private final OnDateSetListener mCallBack;

    private NumberPicker mNumberPickerYear;
    private NumberPicker mNumberPickerMonth;

    public interface OnDateSetListener {

        void onDateSet(int year, int monthOfYear);
    }

    public DatePickerYearMonthDialog(Context context, OnDateSetListener onDateSetListener) {
        this(context, onDateSetListener, Calendar.getInstance().get(Calendar.YEAR), Calendar.getInstance().get(Calendar.MONTH));
    }

    public DatePickerYearMonthDialog(Context context, OnDateSetListener onDateSetListener, int year, int monthOfYear) {
        super(context);
        mCallBack = onDateSetListener;
        setButton(BUTTON_NEGATIVE, "取消", this);
        setButton(BUTTON_POSITIVE, "确认", this);
        setTitle("选择日期");
        setIcon(0);
        View view = LayoutInflater.from(context).inflate(R.layout.date_picker_year_month, null);
        mNumberPickerYear = (NumberPicker) view.findViewById(R.id.year);
        mNumberPickerMonth = (NumberPicker) view.findViewById(R.id.month);
        mNumberPickerYear.setDisplayedValues(null);
        mNumberPickerYear.setMinValue(2001);
        mNumberPickerYear.setMaxValue(2020);
        mNumberPickerYear.setWrapSelectorWheel(true);

        String[] mMonths = {"1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月"};
        mNumberPickerMonth.setDisplayedValues(mMonths);
        mNumberPickerMonth.setMinValue(0);
        mNumberPickerMonth.setMaxValue(11);
        mNumberPickerMonth.setWrapSelectorWheel(true);

        mNumberPickerYear.setValue(year);
        mNumberPickerMonth.setValue(monthOfYear);

        setView(view);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

    }

    @Override
    public void onClick(DialogInterface dialog, int which) {
        if (BUTTON_POSITIVE == which) {
            tryNotifyDateSet();
        }
    }

    private void tryNotifyDateSet() {
        if (mCallBack != null) {
            mCallBack.onDateSet(mNumberPickerYear.getValue(), mNumberPickerMonth.getValue());
        }
    }

    @Override
    public @NonNull
    Bundle onSaveInstanceState() {
        Bundle state = super.onSaveInstanceState();
        state.putInt(YEAR, mNumberPickerYear.getValue());
        state.putInt(MONTH, mNumberPickerMonth.getValue());
        return state;
    }

    @Override
    public void onRestoreInstanceState(@Nullable Bundle savedInstanceState) {
        if (null!=savedInstanceState) {
            super.onRestoreInstanceState(savedInstanceState);
            int year = savedInstanceState.getInt(YEAR);
            int month = savedInstanceState.getInt(MONTH);
            mNumberPickerYear.setValue(year);
            mNumberPickerMonth.setValue(month);
        }
    }
}