package com.wgmf.yxgj.widgets

import android.content.DialogInterface
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Build
import android.os.Bundle
import android.os.Handler
import android.support.v4.app.DialogFragment
import android.support.v4.app.FragmentManager
import android.support.v7.widget.GridLayoutManager
import android.support.v7.widget.RecyclerView
import android.view.*
import android.view.animation.AccelerateDecelerateInterpolator
import android.view.animation.Animation
import android.view.animation.Interpolator
import android.view.animation.TranslateAnimation
import android.widget.Button
import android.widget.ImageView
import android.widget.TextView
import com.wgmf.yxgj.base.R
import com.wgmf.yxgj.utils.DensityUtil
import org.jetbrains.anko.find


/**
 * @author Sasuke on 2018/7/11.
 * 用于对TextView实现数字输入的自定义键盘
 *
 * 注：
 * ①对应的TextView在XML里的配置一定不要加  android:inputType ，
 * 这样有时候可能会弹不出这个自定义键盘，弹的仍然是系统自带的键盘。。。不知道是什么原因。。
 * 感觉是这个属性直接让TextView变成EditText了。
 *
 * ②因为需要显示光标，所以所作用于的TextView一定要把gravity设为right，
 * 因为这里的光标实现是在右侧顶端显示一条竖线，如果textView的gravity不靠右，
 * 那光标就会和输入的文字产生间隔，效果就不对了。
 * 或者也可以直接把layout_width设为wrap_content，然后再在外面套一层RelativeLayout之类的也行。
 */
class NumberKeyboard : DialogFragment() {
    /**
     * 限制的输入字符范围
     */
    var tv: TextView? = null
    var keyGrid: RecyclerView? = null
    private var textChangeListener: ((String?) -> Unit)? = null//监听textView的变化回调
    private var dismissListener: ((String?) -> Unit)? = null//当键盘收起的时候做的回调
    var decimalNum = 0//默认0位小数
    val handler: Handler = Handler()
    var isSelectAll = false;//是否是选中所有文本的模式，如果是，则输入时把所有文本都清空。
    var curcorRunnable: Runnable? = null//用于循环闪烁光标

    companion object {
        val GRID_COLUME_NUM: Int = 3//数字键盘 ，只需要3列

        val DEFAULT_RULE_LIST = listOf("1", "2", "3", "4", "5", "6", "7", "8", "9", ".", "0", "✔")

        var GRID_HEIGHT: Int = 0
        @JvmStatic
        fun newInstance(inputRule: ArrayList<List<String>>?): NumberKeyboard {
            GRID_HEIGHT = (inputRule?.size
                    ?: if (DEFAULT_RULE_LIST.size % GRID_COLUME_NUM == 0) DEFAULT_RULE_LIST.size / GRID_COLUME_NUM
                    else DEFAULT_RULE_LIST.size / GRID_COLUME_NUM + 1) * 50 + 40 + 5//整个高度的dp值
            val args = Bundle().apply { putSerializable("rule", inputRule) }
            val keyboard = NumberKeyboard()
            keyboard.arguments = args
//            keyboard.isCancelable = false
            return keyboard
        }
    }

    /**
     * 键盘消失时的监听
     */
    fun setOnDismissListener(dismissListener: ((String?) -> Unit)?){
        this.dismissListener = dismissListener
    }

    /**
     * 执行键盘消失时的监听回调。
     */
    override fun onDismiss(dialog: DialogInterface) {
        super.onDismiss(dialog)
        dismissListener?.invoke(tv?.text.toString())
    }

    override fun onPause() {
        super.onPause()
        dismiss()//在失去焦点时，会丢失textView，所以干脆直接把整个键盘都关掉算了。
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        dialog?.requestWindowFeature(Window.FEATURE_NO_TITLE)
        val root = inflater?.inflate(R.layout.number_keyboard_ll, container, false)
        //这东西就是限制只能输入哪些字符的List
        val ruleList = (arguments?.getSerializable("rule") as List<String>?)
                ?: DEFAULT_RULE_LIST
        keyGrid = root?.find(R.id.keyGrid)
        keyGrid?.apply {
            layoutManager = object : GridLayoutManager(activity, GRID_COLUME_NUM) {
                override fun canScrollVertically(): Boolean {
                    return false
                }
            }
            adapter = KeyGridAdapter(this@NumberKeyboard, ruleList, textChangeListener)
            //添加带颜色分割线
            addItemDecoration(DividerItemDecoration(context, DividerItemDecoration.BOTH_SET, 1, Color.parseColor("#E3E7EE")))
        }

        //挂删除监听
        root?.find<ImageView>(R.id.backspaceBtn)?.run {
            setOnClickListener {
                deleteLastChar(tv)
                textChangeListener?.invoke(tv?.text.toString())
            }
            setOnLongClickListener {
                tv?.setText("")
                textChangeListener?.invoke("")
                true
            }
        }

        //返回键
        dialog?.setOnKeyListener { dialog, keyCode, event ->
            if (keyCode == KeyEvent.KEYCODE_BACK && event.getAction() == KeyEvent.ACTION_DOWN) {
                //删除最后一个字符
                dismiss()
                true
            } else {
                false
            }
        }
        return if (root != null) root else super.onCreateView(inflater, container, savedInstanceState)
    }


    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        //其实下面两个是一样的
        val blackCursor = (if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) resources.getDrawable(R.drawable.cursor, null)
        else resources.getDrawable(R.drawable.cursor))
                .apply { tv?.let { setBounds(0, 0, 3, it.measuredHeight - 5) } }
        val transparentCursor = (if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) resources.getDrawable(R.drawable.cursor_white, null)
        else resources.getDrawable(R.drawable.cursor_white))
                .apply { tv?.let { setBounds(0, 0, 3, it.measuredHeight - 5) } }
        //循环闪烁光标
        curcorRunnable = object : Runnable {
            var count = 0
            override fun run() {
                tv?.setCompoundDrawables(null, null, if ((count++) % 2 == 0) blackCursor else transparentCursor, null)
                handler.postDelayed(curcorRunnable, 500)
            }
        }.apply { run() }


    }

    override fun onDestroyView() {
        resetState()//把标记复位，为了在同一界面共用一个keyboard实例的时候，多次弹出键盘时避免标记弄乱
        handler.removeCallbacksAndMessages(null)
        super.onDestroyView()
    }

    /**
     * 删除字符串的最后一个字符
     */
    fun deleteLastChar(tv: TextView?): Boolean {
        tv?.let { tv.text = tv.text.substring(0, if (tv.text.length - 1 < 0) 0 else tv.text.length - 1) }
        return true
    }


    override fun onStart() {
        super.onStart()
        val window: Window = dialog!!.window
        val params: WindowManager.LayoutParams = window.attributes
        params.gravity = Gravity.BOTTOM
        params.width = WindowManager.LayoutParams.MATCH_PARENT
        params.height = DensityUtil.dip2px(context,GRID_HEIGHT.toFloat())
        //加这一句可以使弹出时，背景不变暗
        params.dimAmount = 0.0f
        window.attributes = params
        window.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
    }


    override fun onDetach() {
        super.onDetach()
    }

    /**
     * 显示键盘
     */
    fun show(tv: TextView, manager: FragmentManager, textChangeListener: ((String?) -> Unit)?): NumberKeyboard {
        //如果换了一个textView，那就再滚回第一个面板
        this.tv = tv
        this.textChangeListener = textChangeListener
        super.show(manager, "")
        return this
    }



    /**
     * 对小数位做限制
     */
    fun setDecimal(decimalNum: Int): NumberKeyboard{
        this.decimalNum = decimalNum
        return this
    }

    /**
     * 把点击的TextView作一个全选。然后后面编辑的时候先做一个清空操作。
     *  模仿的是EditText 的selectAll属性
     */
    fun selectAll(): NumberKeyboard {
        tv?.setBackgroundColor(Color.CYAN)
        isSelectAll = true
        return this
    }

    /**
     * 把decimalNum小数位与isSelectAll是否全选 的标记复位，在键盘隐藏的时候执行
     */
    private fun resetState(){
        decimalNum = 0
        isSelectAll = false
        tv?.setCompoundDrawables(null, null, null, null)
        tv?.setBackgroundColor(Color.TRANSPARENT)
    }


    /**弹出动画（动画在我的索尼Z2上卡得一逼，还是不要了。。） */
    fun slideToUp(view: View) {
        val slide = TranslateAnimation(Animation.RELATIVE_TO_SELF, 0.0f,
                Animation.RELATIVE_TO_SELF, 0.0f, Animation.RELATIVE_TO_SELF,
                1.0f, Animation.RELATIVE_TO_SELF, 0.0f).apply {
            duration = 200
            fillAfter = true
            isFillEnabled = true
            interpolator = AccelerateDecelerateInterpolator() as Interpolator?
        }
        view.startAnimation(slide)
    }


    class KeyGridAdapter(val keyboard: NumberKeyboard, val ruleList: List<String>, val textChangeListener: ((String?) -> Unit)?) : RecyclerView.Adapter<KeyHolderView>() {
        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): KeyHolderView {
            return KeyHolderView(LayoutInflater.from(keyboard.activity).inflate(R.layout.key_btn_tv, parent, false))
        }

        override fun getItemCount(): Int {
            return ruleList?.size
        }

        override fun onBindViewHolder(holder: KeyHolderView, pos: Int) {
            holder?.apply {
                keyBtn.text = ruleList[pos]
                if (ruleList[pos] == "✔") keyBtn.setTextColor(Color.parseColor("#1D91E6"))
                if (ruleList[pos].isNullOrEmpty()) keyBtn.setBackgroundColor(Color.TRANSPARENT)

                keyBtn.setOnClickListener {
                    //如果是全选模式，就把textView上的文本清空，然后把全选的色块背景设为透明
                    keyboard.takeIf { it.isSelectAll }?.let {
                        it.isSelectAll = false
                        it.tv?.text = ""
                        it.tv?.setBackgroundColor(Color.TRANSPARENT)
                    }
                    //常规的键盘点击响应
                    val btnText = keyBtn.text.toString()
                    keyboard.tv?.text = (keyboard.tv?.text.toString() + btnText).run {
                        when (true) {
                            startsWith("0") && length == 1 -> "0."
                            startsWith(".") -> "0."
                            endsWith(".") && (indexOfFirst { it == '.' } != length - 1) -> substring(0, length - 1)
                            endsWith(".") && keyboard.decimalNum == 0 -> substring(0, length - 1)
                            endsWith("✔") -> substring(0, length - 1).apply { keyboard.dismiss() }
                            "." in this && split(".")[1].length > keyboard.decimalNum -> this.substring(0, length - 1)
                            else -> this
                        }
                    }

                    textChangeListener?.invoke(keyboard.tv?.text.toString())
                }
            }
        }
    }

    class KeyHolderView(view: View) : RecyclerView.ViewHolder(view) {
        var keyBtn: Button

        init {
            keyBtn = view.findViewById(R.id.keyBtn) as Button
        }
    }
}

