package com.wgmf.yxgj.loginmodule.service;

import android.text.TextUtils;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;

import android.util.Log;

import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;
import com.wgmf.yxgj.loginmodule.service.request.LoginRequest;

import java.lang.ref.WeakReference;

public class LoginService extends BaseService {
    private static BaseSingleton<LoginService, Void> mMainService = new BaseSingleton<LoginService, Void>() {
        @Override
        protected LoginService create(Void var1) {
            return new LoginService();
        }
    };

    public static LoginService getInstance() {
        return mMainService.get(null);
    }

    private LoginService() {
    }

    /**
     * 用户名登录
     */
    public void requestLogin(final String username, final String password,
                             ResultData.BusinessCallback callback) {
        LoginRequest request = new LoginRequest(username, password);
        request.taskID = BusinessID.Login.MSG_ON_USER_LOGIN;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_LOGIN + "?"
                + "username="
                + username
                + "&password="
                + password;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * 前端显示登录页面
     * get /frontDisplay/loginImage
     */
    public void requestLoginImage(final String type, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Login.MSG_ON_FRONT_DISPLAY;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_LOGIN_IMAGE + "?"
                + "type=" + type;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.Login.MSG_ON_USER_LOGIN:
                case BusinessID.Login.MSG_ON_FRONT_DISPLAY: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}