package com.wgmf.yxgj.loginmodule.ui;

import android.os.Build;
import android.os.Bundle;
import android.support.v4.content.ContextCompat;
import android.view.View;
import android.view.Window;
import android.widget.CheckBox;
import android.widget.ImageView;
import android.widget.TextView;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.bumptech.glide.Glide;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.tools.PrefTool;
import com.wgmf.library.utils.tools.SystemBarTintManager;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.global.Prefs;
import com.wgmf.yxgj.loginmodule.R;
import com.wgmf.yxgj.loginmodule.graph.components.DaggerLoginActivityComponent;
import com.wgmf.yxgj.loginmodule.graph.modules.LoginActivityModule;
import com.wgmf.yxgj.model.CommonDataBean;
import com.wgmf.yxgj.widgets.EditText.ClearEditText;
import com.xp.arouter.RouterCommonUtil;
import com.xp.arouter.RouterParams;

import javax.inject.Inject;

/**
 * @author XP created at 2016/1/12 15:31 登录
 */
@SuppressWarnings("all")
@Route(path = RouterParams.URL_LOGINACTIVITY)
public class LoginActivity extends BaseParentAct implements LoginView {

    ImageView loginBgIv;

    ImageView loginLogoIv;

    ClearEditText loginUseridEt;

    ClearEditText loginPasswordEt;

    CheckBox rememberLoginPasswordCb;

    TextView loginBtn;

    TextView versionTv;
    @Inject
    LoginPresenter loginPresenter;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        initView();
        initListener();
        initInjector();
        loginPresenter.initContent();
        loginPresenter.getLoginImage();
        loginPresenter.readAccount(this);
    }

    /**
     * 通知栏一体化
     */
    protected void initWindowView() {
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
            setTranslucentStatus();
        }
        SystemBarTintManager tintManager = new SystemBarTintManager(this);
        tintManager.setStatusBarTintEnabled(true);
        // 通知栏所需颜色
        tintManager.setStatusBarTintResource(R.color.transparent);
    }

    private void initView() {
        setContentView(R.layout.activity_login);
        loginBgIv = (ImageView) findViewById(R.id.login_bg_iv);
        loginLogoIv = (ImageView) findViewById(R.id.login_logo_iv);
        loginUseridEt = (ClearEditText) findViewById(R.id.login_userid_et);
        loginPasswordEt = (ClearEditText) findViewById(R.id.login_password_et);
        rememberLoginPasswordCb = (CheckBox) findViewById(R.id.remember_login_password_cb);
        loginBtn = (TextView) findViewById(R.id.login_btn);
        versionTv = (TextView) findViewById(R.id.version_tv);
    }

    private void initInjector() {
        DaggerLoginActivityComponent.builder()
                .loginActivityModule(new LoginActivityModule(this))
                .build()
                .inject(this);
    }

    private void initListener() {
        loginBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                doLogin();
            }
        });
        loginLogoIv.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                changeEnv();
            }
        });
        rememberLoginPasswordCb.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                doPwdStatusCheck();
            }
        });
    }

    /**
     * 登录信息校验
     */
    public void doLogin() {
        setDialogCancel(false, false);
        String username = loginUseridEt.getText().toString().trim();
        String password = loginPasswordEt.getText().toString().trim();
        loginPresenter.cleanAccout(this, username);
        loginPresenter.writeAccout(this, username, password);
        loginPresenter.login(username, password);
    }

    /**
     * 用户记住密码状态
     */
    public void doPwdStatusCheck() {
        loginPresenter.checkPwdStatus(this, rememberLoginPasswordCb.isChecked());
    }

    /**
     * 切换环境
     */
    public void changeEnv() {
        loginPresenter.changeEnv(this);
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        loginPresenter.switchService(result);
    }

    @Override
    public void rememberLoginPassword(boolean isRemember, String userName, String userPassword) {
        rememberLoginPasswordCb.setChecked(isRemember);
        loginUseridEt.setText(userName);
        loginPasswordEt.setText(userPassword);
        loginUseridEt.setSelection(loginUseridEt.getText().length());
        loginPasswordEt.setSelection(loginPasswordEt.getText().length());
    }

    @Override
    public void setVersion(String version, int color) {
        versionTv.setText(version);
        versionTv.setTextColor(ContextCompat.getColor(this, color));
    }

    @Override
    public void loginSuccess(CommonDataBean commonData) {
        loginPresenter.saveUserData(commonData, mCommonUserinfoBeanDao, mCommonResourcesBeanDao,mBrandListDao);
        loginPresenter.setAlias(this);
        loginPresenter.sendJPush(this);
        loginPresenter.getLocationInfo(this);
        loginPresenter.toNextActivity(this, commonData);
    }

    @Override
    public void loginBgImg(String url) {
        Glide.with(this).load(url).fitCenter().into(loginBgIv);
    }

    @Override
    public void loginHome() {
        Bundle mBundle = new Bundle();
        mBundle.putLong("branchID", 0L);
        mBundle.putString("branchTitle", "营销管家");
        RouterCommonUtil.startFunctionActivity(this, -3, 0L, mBundle);
        LoginActivity.this.finish();
    }

    @Override
    public void loginPartTime() {
        Bundle mBundle = new Bundle();
        mBundle.putLong("branchID", 525L);
        mBundle.putString("branchTitle", "兼职督察");
        RouterCommonUtil.startFunctionActivity(this, -7, 525L, mBundle);
        LoginActivity.this.finish();
    }

    /**
     * 登录权限判断
     *
     * @param commonData 用户功能数据
     */
    @Override
    public void loginAllow(CommonDataBean commonData) {
        // 登录前先清除原来的用户数据
        clearUserData();
        loginPresenter.checkAccount(this, commonData);
    }

    @Override
    public void showTip(String msg) {
        dismissDialog();
        showMsg(msg);
    }

    @Override
    public void showLoginDialog() {
        showDialog();
    }

    @Override
    public void dismissLoginDialog() {
        dismissDialog();
    }

    @Override
    protected void onResume() {
        super.onResume();
        PrefTool.setBooleanSave(this, Prefs.PRE_LOGINACT_STATUS, true);
    }

    @Override
    protected void onStop() {
        super.onStop();
        PrefTool.setBooleanSave(this, Prefs.PRE_LOGINACT_STATUS, false);
    }
}