package com.wgmf.yxgj.module.business.parttime.ui;

import android.content.DialogInterface;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v4.content.ContextCompat;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.google.gson.Gson;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.StringUtil;
import com.wgmf.library.utils.tools.PrefTool;
import com.wgmf.yxgj.base.BaseActivity;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.global.Prefs;
import com.wgmf.yxgj.module.business.parttime.R;
import com.wgmf.yxgj.module.business.parttime.model.ProtocolEntity;
import com.wgmf.yxgj.module.business.parttime.model.ProtocolEntityResult;
import com.wgmf.yxgj.module.business.parttime.service.PartTimeService;
import com.wgmf.yxgj.widgets.CountDownTextViewHelper;
import com.xp.arouter.RouterCommonUtil;
import com.xp.arouter.RouterParams;

/**
 * @author XP on 2017/6/23 17:10
 */
@Route(path = RouterParams.URL_PART_TIME_LOGIN_ACTIVITY)
public class PartTimeLoginActivity extends BaseParentAct implements View.OnClickListener {
    /**
     * 兼职督察协议 ，默认值为1
     */
    private int protocolId = 1;
    private TextView getProtocolTv;
    private TextView partTimeThreeSecondsTv;
    private TextView getProtocolDialogTv;
    private Button partTimeAgreeBtn;
    private LinearLayout partTimeAgreeLl;
    private LinearLayout partTimeAgreeSecondsLl;
    private LinearLayout getProtocolDialogLl;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        //1，首先从SP中读取兼职督察姓名（PRE_USER_PART_TIME_NAME），如存在则直接进入督察功能页面，不存在则弹出填写姓名弹框界面
        String userName = PrefTool.getStringPerferences(PartTimeLoginActivity.this, Prefs.PRE_USER_PART_TIME_NAME);
        checkPartTimeName(userName);
        initProtocol();
        initTitle();
    }

    /**
     * 初始化协议界面
     */
    private void initProtocol() {
        setContentView(R.layout.part_time_protocol);
        getProtocolTv = (TextView) findViewById(R.id.get_protocol_tv);
        partTimeThreeSecondsTv = (TextView) findViewById(R.id.part_time_three_seconds_tv);
        partTimeAgreeBtn = (Button) findViewById(R.id.part_time_agree_btn);
        partTimeAgreeLl = (LinearLayout) findViewById(R.id.part_time_agree_ll);
        partTimeAgreeSecondsLl = (LinearLayout) findViewById(R.id.part_time_agree_seconds_ll);
        getProtocolDialogLl = (LinearLayout) findViewById(R.id.get_protocol_dialog_ll);
        getProtocolDialogTv = (TextView) findViewById(R.id.get_protocol_dialog_tv);
    }

    @Override
    protected void initTitle() {
        super.initTitle();
        homeTitleText.setText("兼职督察");
        homeTitleBackLl.setVisibility(View.INVISIBLE);
    }

    /**
     * 检查perferences中是否有兼职督察姓名
     *
     * @param userName 本地兼职督察姓名
     */
    private void checkPartTimeName(String userName) {
        if (StringUtil.isNotNullAndNotEmpty(userName)) {
            loginPartTime();
        } else {
            final PartTimeEdtDialog.Builder builder = new PartTimeEdtDialog.Builder(PartTimeLoginActivity.this);
            builder.setNegativeButton(new DialogInterface.OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                    if (TextUtils.isEmpty(builder.getPartTimeName())) {
                        showMsg("请输入您的姓名！");
                        return;

                    }
                    dialog.dismiss();
                    //2，弹出填写姓名弹框界面，暂存兼职督察姓名（PRE_USER_PART_TIME_NAME_TEMP）
                    PrefTool.setStringsave(PartTimeLoginActivity.this, Prefs.PRE_USER_PART_TIME_NAME_TEMP, builder.getPartTimeName());
                    getProtocol();
                }
            });
            builder.create().show();
        }
    }

    /**
     * 获取兼职督察协议
     */
    private void getProtocol() {
        showDialog();
        PartTimeService.getInstance().requestGetProtocol("part_time", this);
    }

    private void loginPartTime() {
        Bundle mBundle = new Bundle();
        mBundle.putLong("branchID", 525L);
        mBundle.putString("branchTitle", "兼职督察");
        RouterCommonUtil.startFunctionActivity(this, -1, 525L, mBundle);
        PartTimeLoginActivity.this.finish();
    }

    /**
     * 设置三秒倒计时
     */
    private void setSeconds() {
        CountDownTextViewHelper helperPay = new CountDownTextViewHelper(partTimeThreeSecondsTv);
        helperPay.setOnFinishListener(new CountDownTextViewHelper.OnFinishListener() {

            @Override
            public void countDownFinish() {
                partTimeAgreeLl.setOnClickListener(PartTimeLoginActivity.this);
                partTimeAgreeBtn.setOnClickListener(PartTimeLoginActivity.this);
                partTimeAgreeSecondsLl.setVisibility(View.INVISIBLE);
                partTimeAgreeBtn.setText("同意");
                partTimeAgreeBtn.setTextColor(ContextCompat.getColor(PartTimeLoginActivity.this, R.color.normal_color));
            }
        });
        helperPay.start();
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.PartTime.MSG_ON_GET_PROTOCOL:
                    getProtocol(result);
                    break;
                case BusinessID.PartTime.MSG_ON_SAVE_PROTOCOL_RECORD:
                    saveProtocol(result);
                    break;
                default:
                    break;
            }
        }
    }

    private void getProtocol(ResultData result) {
        final String msg = result.getInfo();
        if (result.isSuccessed()) {
            ProtocolEntityResult mLoginProtocolEntity = new Gson().fromJson(msg, ProtocolEntityResult.class);
            Log.d(BaseActivity.TAG, "mLoginProtocolEntity=" + mLoginProtocolEntity.toString());
            if (ConstantParams.CONSTANT_PARAMS_0.equals(mLoginProtocolEntity.retCode) && null != mLoginProtocolEntity.getResult()) {
                getProtocolDialogLl.setVisibility(View.VISIBLE);
                getProtocolDialogTv.setVisibility(View.INVISIBLE);
                partTimeAgreeLl.setOnClickListener(null);
                partTimeAgreeBtn.setOnClickListener(null);
                getProtocolTv.setText(mLoginProtocolEntity.getResult().getContent());
                if (0 != mLoginProtocolEntity.getResult().getProtocolId()) {
                    protocolId = mLoginProtocolEntity.getResult().getProtocolId();
                }
                setSeconds();
            }
            showMsg(mLoginProtocolEntity.retInfo);
        } else {
            showMsg(result.getResultInfo());
        }
    }

    private void saveProtocol(ResultData result) {
        final String msg = result.getInfo();
        if (result.isSuccessed()) {
            try {
                BaseResponse mBaseResponse = new Gson().fromJson(msg, BaseResponse.class);
                Log.d(BaseActivity.TAG, "mBaseResponse=" + mBaseResponse.toString());
                if (ConstantParams.CONSTANT_PARAMS_0.equals(mBaseResponse.retCode)) {
                    //3，提交协议保存成功则将兼职督察姓名从缓存中（PRE_USER_PART_TIME_NAME_TEMP）存入内存（PRE_USER_PART_TIME_NAME），否则SP中未存储姓名，再次进入继续第1步
                    String userNameTemp = PrefTool.getStringPerferences(PartTimeLoginActivity.this, Prefs.PRE_USER_PART_TIME_NAME_TEMP);
                    PrefTool.setStringsave(PartTimeLoginActivity.this, Prefs.PRE_USER_PART_TIME_NAME, userNameTemp);
                    //进入兼职督察功能界面
                    loginPartTime();
                }
                showMsg(mBaseResponse.retInfo);
            } catch (Exception e) {
                showMsg(getString(R.string.request_data_fail));
            }
        } else {
            showMsg(result.getResultInfo());
        }
    }

    @Override
    public void onClick(View v) {
        if (v.getId() == R.id.part_time_agree_ll || v.getId() == R.id.part_time_agree_btn) {
            showDialog();
            String userNameTemp = PrefTool.getStringPerferences(PartTimeLoginActivity.this, Prefs.PRE_USER_PART_TIME_NAME_TEMP);
            if (StringUtil.isNotNullAndNotEmpty(userNameTemp)) {
                ProtocolEntity mProtocolEntity = new ProtocolEntity();
                mProtocolEntity.setPartTimeStaffId(BaseActivity.userInfo.getStaffId());
                mProtocolEntity.setPartTimeStaffName(userNameTemp);
                mProtocolEntity.setProtocolId(protocolId);
                String content = new Gson().toJson(mProtocolEntity);
                Log.d(BaseActivity.TAG, content);
                PartTimeService.getInstance().requestSaveProtocolRecord(content, PartTimeLoginActivity.this);
            } else {
                showMsg("请重新登录并填写您的姓名哟！");
            }
        }
    }
}