package com.wgmf.yxgj.module.business.reportmodule.ui.level1list;

import android.os.Bundle;
import android.support.v4.app.FragmentTransaction;
import android.support.v4.content.ContextCompat;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.yxgj.base.BaseBackHandledFragment;
import com.wgmf.yxgj.module.business.reportmodule.R;

import java.util.ArrayList;
import java.util.List;

public class ReportModuleListFragment extends BaseBackHandledFragment implements View.OnClickListener {

    /**
     * 当前选择反馈处理状态位置
     */
    private int position;

    /**
     * 下标集合
     */
    private List<TextView> textViews;

    /**
     * tab集合
     */
    private List<ImageView> imageViews;

    private String branchTitle;
    private Long branchID;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        branchTitle = getArguments().getString("branchTitle");
        branchID = getArguments().getLong("branchID", 0);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_report_module_list, container, false);
        // 防止点击穿透，底层的fragment响应上层点击触摸事件
        view.setClickable(true);
        initView(view);
        initTab();
        refreashProjectFragment();
        return view;
    }

    /**
     * 加载内容
     *
     * @param tag      标签
     * @param fragment 内容
     */
    public void loadFragment(String tag, BaseBackHandledFragment fragment) {
        FragmentTransaction ft = getActivity().getSupportFragmentManager().beginTransaction();
        ft.setTransition(FragmentTransaction.TRANSIT_FRAGMENT_OPEN);
        ft.replace(R.id.report_module_list_search_fl, fragment);
        ft.addToBackStack(tag);
        ft.commit();
    }

    private void initView(View view) {
        LinearLayout llReportModuleByProject = (LinearLayout) view.findViewById(R.id.ll_report_module_by_project);
        LinearLayout llReportModuleByStore = (LinearLayout) view.findViewById(R.id.ll_report_module_by_shop);
        /*
         * 声明标题栏的tab
         */
        TextView reportModuleByProjectTxt = (TextView) view.findViewById(R.id.report_module_by_project_txt);
        TextView reportModuleByStoreTxt = (TextView) view.findViewById(R.id.report_module_by_shop_txt);
        reportModuleByProjectTxt.setText(getString(R.string.report_module_by_project));
        reportModuleByStoreTxt.setText(getString(R.string.report_module_by_shop));
        /*
         * 标题栏的下标
         */
        ImageView reportModuleByProjectImg = (ImageView) view.findViewById(R.id.report_module_by_project_img);
        ImageView reportModuleByStoreImg = (ImageView) view.findViewById(R.id.report_module_by_shop_img);
        llReportModuleByProject.setOnClickListener(this);
        llReportModuleByStore.setOnClickListener(this);
        // 装载控件到集合
        textViews = new ArrayList<>();
        textViews.add(reportModuleByProjectTxt);
        textViews.add(reportModuleByStoreTxt);
        imageViews = new ArrayList<>();
        imageViews.add(reportModuleByProjectImg);
        imageViews.add(reportModuleByStoreImg);

    }

    private void initTab() {
        textViews.get(0).setTextColor(getResources().getColor(R.color.normal_color));
        imageViews.get(0).setVisibility(View.VISIBLE);
        imageViews.get(0).setImageResource(R.color.normal_color);
    }

    @Override
    public boolean onBackPressed() {
        return false;
    }

    private void setSelectedItem(int position) {
        for (int i = 0; i < imageViews.size(); i++) {
            imageViews.get(i).setImageResource(R.color.white);
            textViews.get(i).setTextColor(ContextCompat.getColor(getActivity(), R.color.black));
            imageViews.get(position).setVisibility(View.GONE);
        }
        imageViews.get(position).setVisibility(View.VISIBLE);
        imageViews.get(position).setImageResource(R.color.normal_color);
        textViews.get(position).setTextColor(ContextCompat.getColor(getActivity(), R.color.normal_child));
        textViews.get(position).getPaint().setFakeBoldText(true);
    }

    @Override
    public void onClick(View view) {
        if (view.getId() == R.id.ll_report_module_by_project) {
            position = 0;
            this.setSelectedItem(position);
            refreashProjectFragment();
        } else if (view.getId() == R.id.ll_report_module_by_shop) {
            position = 1;
            this.setSelectedItem(position);
            refreashShopFragment();
        }
    }

    private void refreashShopFragment() {
        ReportModuleShopListFragment reportModuleShopListFragment = new ReportModuleShopListFragment();
        Bundle bundle = new Bundle();
        bundle.putString("branchTitle", branchTitle);
        bundle.putLong("branchID", branchID);
        reportModuleShopListFragment.setArguments(bundle);
        loadFragment("reportModuleShopListFragment", reportModuleShopListFragment);
    }

    private void refreashProjectFragment() {
        ReportModuleProjectListFragment reportModuleProjectListFragment = new ReportModuleProjectListFragment();
        Bundle bundle = new Bundle();
        bundle.putString("branchTitle", branchTitle);
        bundle.putLong("branchID", branchID);
        reportModuleProjectListFragment.setArguments(bundle);
        loadFragment("reportModuleProjectListFragment", reportModuleProjectListFragment);
    }
}