package com.wgmf.yxgj.module.business.reportmodule.ui.level1list;

import android.content.Intent;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;
import android.widget.TextView;

import com.google.gson.Gson;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.base.BaseBackHandledFragment;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.module.business.reportmodule.R;
import com.wgmf.yxgj.module.business.reportmodule.model.ReportShopListEntity;
import com.wgmf.yxgj.module.business.reportmodule.model.ReportShopListResultEntity;
import com.wgmf.yxgj.module.business.reportmodule.service.ReportModuleService;
import com.wgmf.yxgj.module.business.reportmodule.service.ReportStaticData;
import com.wgmf.yxgj.module.business.reportmodule.ui.level2list.ReportModuleListActivity2;
import com.wgmf.yxgj.widgets.EditText.ClearEditText;

import java.util.ArrayList;
import java.util.List;

public class ReportModuleShopListFragment extends BaseBackHandledFragment implements ReportModuleShopListAdapter.ClickListener {
    String branchTitle;
    Long branchID;
    private ClearEditText storeNameEt;
    private ListView mListView;
    private ReportModuleShopListAdapter reportModuleShopListAdapter;
    private List<ReportShopListEntity> reportShopListEntities;
    private List<ReportShopListEntity> reportShopListEntitiesShow;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        branchTitle = getArguments().getString("branchTitle");
        branchID = getArguments().getLong("branchID", 0);
    }

    private void getData() {
        if (null != userInfo) {
            showDialog();
            storeNameEt.setHint(getString(R.string.report_module_by_shop_search));
            ReportModuleService.getInstance().requestGetReportByShop(userInfo.getOrganizationCode(), "", ReportStaticData.getFlag(branchID), this);
        }
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_report_module_project_list, container, false);
        // 防止点击穿透，底层的fragment响应上层点击触摸事件
        view.setClickable(true);
        initView(view);
        getData();
        return view;
    }

    private void initView(View view) {
        mListView = (ListView) view.findViewById(R.id.public_list_view_lv);
        storeNameEt = (ClearEditText) view.findViewById(R.id.store_name_et);
        TextView dataEmpty = (TextView) view.findViewById(R.id.public_list_view_empty_tv);
        mListView.setEmptyView(dataEmpty);
        mListView.setVisibility(View.VISIBLE);
        storeNameEt.setVisibility(View.VISIBLE);
        setListener();
    }

    protected void setListener() {
        storeNameEt.addTextChangedListener(new TextWatcher() {

            @Override
            public void onTextChanged(CharSequence s, int start, int before,
                                      int count) {
            }

            @Override
            public void beforeTextChanged(CharSequence s, int start, int count,
                                          int after) {
            }

            @Override
            public void afterTextChanged(Editable s) {
                textChanged();
            }
        });
    }

    public void textChanged() {
        if (null == reportShopListEntitiesShow) {
            reportShopListEntitiesShow = new ArrayList<>();
        }
        String itemId = storeNameEt.getText().toString().trim();
        if (TextUtils.isEmpty(itemId)) {
            reportShopListEntitiesShow.clear();
            if (null != reportShopListEntities) {
                reportShopListEntitiesShow.addAll(reportShopListEntities);
            }

        } else {
            reportShopListEntitiesShow.clear();
            if (null != reportShopListEntities) {
                for (ReportShopListEntity p : reportShopListEntities) {
                    if (null != p.getShopName()) {
                        if (p.getShopName().contains(itemId)) {
                            reportShopListEntitiesShow.add(p);
                        }
                    }
                }
            }
        }
        reportModuleShopListAdapter = new ReportModuleShopListAdapter(getActivity(), this, reportShopListEntitiesShow);
        mListView.setAdapter(reportModuleShopListAdapter);
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            if (id == BusinessID.ModuleReport.MSG_ON_GET_REPORT_BY_SHOP) {
                final String msg = result.getInfo();
                if (result.isSuccessed()) {
                    ReportShopListResultEntity reportModuleShopResultEntity = new Gson().fromJson(msg, ReportShopListResultEntity.class);
                    Log.d(TAG, "reportModuleShopResultEntity" + reportModuleShopResultEntity);
                    if (null != reportModuleShopResultEntity && null != reportModuleShopResultEntity.getResult() && ConstantParams.CONSTANT_PARAMS_0.equals(reportModuleShopResultEntity.retCode)) {
                        reportShopListEntities = reportModuleShopResultEntity.getResult();
                        reportModuleShopListAdapter = new ReportModuleShopListAdapter(getActivity(), this, reportShopListEntities);
                        mListView.setAdapter(reportModuleShopListAdapter);
                    }
                }
            }
        }
    }

    @Override
    public boolean onBackPressed() {
        return false;
    }

    @Override
    public void menberDayAdapterClick(ReportShopListEntity reportShopListEntity, int position) {
        Intent intent = new Intent(getActivity(), ReportModuleListActivity2.class);
        intent.putExtra("method", "queryProject");
        intent.putExtra("branchTitle", branchTitle);
        intent.putExtra("branchID", branchID);
        intent.putExtra("shopId", reportShopListEntity.getShopId());
        intent.putExtra("shopName", reportShopListEntity.getShopName());
        intent.putExtra("position", position);
        startActivity(intent);
    }
}