package com.wgmf.yxgj.module.business.reportproblem.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;
import com.wgmf.yxgj.module.business.reportproblem.service.request.CreateCabinetRequest;

import java.lang.ref.WeakReference;

/**
 * 作者：XiePing on 2016/5/31 16:31
 * 邮箱：2975837870@qq.com
 */
public class ReportFeedbackService extends BaseService {
    private static BaseSingleton<ReportFeedbackService, Void> mMainService = new BaseSingleton<ReportFeedbackService, Void>() {
        @Override
        protected ReportFeedbackService create(Void var1) {
            return new ReportFeedbackService();
        }
    };

    public static ReportFeedbackService getInstance() {
        return mMainService.get(null);
    }

    private ReportFeedbackService() {
    }

    /**
     * 问题上报物流人员信息查询
     */
    public void requestTelLogistics(final String code,
                                    ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_STREAM_DEALPERSON;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_STREAM_DEALPERSON + "?"
                + "code="
                + code;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /question/product 获取产品:包括产品、问题类型、物流
     */
    public void requestReportProblemProductList(final String url, final String storeNo,
                                                ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_QUESTION_GET_SELECTLIST;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "storeNo=" + storeNo;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /question/saveQuestion 保存问题上报
     */
    public void requestSaveQuestion(final String json,
                                    ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_QUESTION_SAVE_QUESTION;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_PRODUCT_SAVE;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /OAworkflow/createQualityFBWorkFlow 质量问题反馈流程提交
     * <p>
     * 前端生产单号：0110074+75598659+170301082536+2位随机数，同订货单号 String orderId;
     */
    public void createQualityFBWorkFlow(final String staffid, final String shopId, final String content, final String orderId,
                                        ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_CREATE_QUALITY_FB_WORKFLOW;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_CREATE_QUALITY_FB_WORKFLOW + "?"
                + "staffid=" + staffid + "&shopId=" + shopId + "&orderId=" + orderId;
        request.json = content;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /OAworkflow/createCabinetWorkFlow 柜子，磨粉机，物料质量问题，流程提交
     * type:默认0:柜子，1:磨粉机，2：物料质量
     */
    public void createCabinetWorkFlow(final String staffid, final String shopId, final String orderId, final String type, final String content,
                                      ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_CREATE_CABINET_WORKFLOW;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_CREATE_CABINET_WORKFLOW + "?" + "staffid=" + staffid + "&shopId=" + shopId + "&orderId=" + orderId + "&type=" + type;
        request.json = content;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /OAworkflow/createComplaintWorkFlow 我要找督察，内部人员投诉流程
     */
    public void createComplaintWorkFlow(final String staffid, final String shopId, final String content, final String orderId,
                                        ResultData.BusinessCallback callback) {
        CreateCabinetRequest request = new CreateCabinetRequest(content);
        request.taskID = BusinessID.ReportFeedback.MSG_ON_CREATE_COMPLAINT_WORKFLOW;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_CREATE_COMPLAINT_WORKFLOW + "?"
                + "staffid=" + staffid + "&orderId=" + orderId + "&shopId=" + shopId;
        request.json = content;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /OAworkflow/createFeedbackWorkFlow 建议与意见流程
     */
    public void createFeedbackWorkFlow(final String staffid, final String shopId, final String orderId, final String content,
                                       ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_CREATE_FEEDBACK_WORKFLOW;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_CCREATE_FEEDBACK_WORKFLOW + "?"
                + "staffid=" + staffid + "&orderId=" + orderId + "&shopId=" + shopId;
        request.json = content;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /OAworkflow/CreateAOGErrWorkFlow 到货误差流程提交
     */
    public void requestCreateAOGErrWorkFlow(final String staffid, final String shopId, final String json, final String orderId,
                                            ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_CREATE_AOGERR_WORKFLOW;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_CREATE_AOGERR_WORKFLOW + "?"
                + "staffid=" + staffid + "&shopId=" + shopId + "&json=" + json + "&orderId=" + orderId;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /OAworkflow/getAOGWorkFlowInfo 流程查询
     * type 查询类型0:所有，1：未处理和处理中，2：已处理
     * workFlowId 流程类型： 721到货误差，2181柜子，质量问题 2421，内部投诉2441，本机问题6
     * mode=1 营销管家使用,1:辖下所有提交的流程
     */
    public void requestGetAOGWorkFlowInfo(final String staffid, final int type, final String workFlowId, final int mode,
                                          ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_GET_AOGWORKFLOW_INFO;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_AOGWORKFLOW_INFO + "?"
                + "staffid=" + staffid + "&type=" + type + "&workFlowId=" + workFlowId + "&mode=" + mode;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * post /OAworkflow/submitPj 流程查询
     * staffId 工号 query string
     * id id query 	string
     * problemType 问题类型 query 	integer
     * pj 评价星级1,2,3,4 query 	integer
     * content 评价内容 query 	string
     */
    public void requestSubmitPj(final String staffId, final String id, final int problemType, final int pj, final String content,
                                ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_SUBMIT_PJ;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SUBMIT_PJ + "?"
                + "staffId=" + staffId + "&id=" + id + "&problemType=" + problemType + "&pj=" + pj + "&content=" + content;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /machineOrder/findMachineRepairOper
     * 查找机修人员信息 shopId 门店编号query 	string
     */
    public void requestFindMachineRepairOper(final String shopId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_FIND_MACHINE_REPAIR_OPER;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_MACHINE_REPAIR_OPER + "?" + "shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /machineOrder/findMachineOrderList 查找机修工单信息
     * operUserNo  上报人员工号  query 	string
     * morOrderDealsFlag 机修工单处理状态：0/待处理；1/已处理 query 	string
     */
    public void requestFindMachineOrderList(final String operUserNo, final String morOrderDealsFlag, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_FIND_MACHINE_ORDER_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_MACHINE_ORDER_LIST + "?"
                + "operUserNo=" + operUserNo + "&morOrderDealsFlag=" + morOrderDealsFlag;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /machineOrder/findMachineOrderDetail 查找机修工单信息明细
     * morNo 工单号 query 	string
     */
    public void requestFindMachineOrderDetail(final String morNo, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_FIND_MACHINE_ORDER_DETAIL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_MACHINE_ORDER_DETAIL + "?" + "morNo=" + morNo;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * post /machineOrder/saveOrUpdateMachineOrder 创建机修工单
     */
    public void requestSaveOrUpdateMachineOrder(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_SAVE_OR_UPDATE_MACHINE_ORDER;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_OR_UPDATE_MACHINE_ORDER;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * post /machineOrder/updateMachineOrderMaintenance 评价机修工单维修
     */
    public void requestUpdateMachineOrderMaintenance(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ReportFeedback.MSG_ON_UPDATE_MACHINE_ORDER_MAINTENANCE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_UPDATE_MACHINE_ORDER_MAINTENANCE;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.ReportFeedback.MSG_ON_QUESTION_GET_SELECTLIST:
                case BusinessID.ReportFeedback.MSG_ON_QUESTION_SAVE_QUESTION:
                case BusinessID.ReportFeedback.MSG_ON_CREATE_QUALITY_FB_WORKFLOW:
                case BusinessID.ReportFeedback.MSG_ON_CREATE_CABINET_WORKFLOW:
                case BusinessID.ReportFeedback.MSG_ON_CREATE_COMPLAINT_WORKFLOW:
                case BusinessID.ReportFeedback.MSG_ON_CREATE_FEEDBACK_WORKFLOW:
                case BusinessID.ReportFeedback.MSG_ON_CREATE_AOGERR_WORKFLOW:
                case BusinessID.ReportFeedback.MSG_ON_GET_AOGWORKFLOW_INFO:
                case BusinessID.ReportFeedback.MSG_ON_SUBMIT_PJ:
                case BusinessID.ReportFeedback.MSG_ON_FIND_MACHINE_REPAIR_OPER:
                case BusinessID.ReportFeedback.MSG_ON_FIND_MACHINE_ORDER_LIST:
                case BusinessID.ReportFeedback.MSG_ON_FIND_MACHINE_ORDER_DETAIL:
                case BusinessID.ReportFeedback.MSG_ON_SAVE_OR_UPDATE_MACHINE_ORDER:
                case BusinessID.ReportFeedback.MSG_ON_UPDATE_MACHINE_ORDER_MAINTENANCE: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}