package com.wgmf.yxgj.module.business.reportproblem.ui;

import android.content.Context;
import android.graphics.drawable.Drawable;
import android.support.v4.content.ContextCompat;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.RatingBar;
import android.widget.TextView;

import com.wgmf.yxgj.module.business.reportproblem.R;
import com.wgmf.yxgj.module.business.reportproblem.model.ResultInfoEntity;
import com.wgmf.yxgj.module.business.reportproblem.service.QualityBackType;
import com.wgmf.yxgj.widgets.ListView.ListViewForScrollView;

import java.util.List;

@SuppressWarnings("all")
class QueryProblemsErrorListAdapter extends BaseAdapter {
    private List<ResultInfoEntity> listData;
    private Context context;

    QueryProblemsErrorListAdapter(List<ResultInfoEntity> tdlist, Context context, ClickListener clickListener) {
        super();
        this.listData = tdlist;
        this.context = context;
        this.clickListener = clickListener;
    }

    private ClickListener clickListener;

    public interface ClickListener {
        void queryProblemsAdapterClick(ResultInfoEntity resultinfoentity);
    }

    @Override
    public int getCount() {
        return listData.size();
    }

    @Override
    public Object getItem(int position) {
        return listData.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        final ResultInfoEntity item = listData.get(position);
        final ViewHolder holder;
        convertView = null;
        if (null == convertView) {
            convertView = LayoutInflater.from(context).inflate(
                    R.layout.list_item_report_problems, null);
            holder = new ViewHolder(convertView);
            convertView.setTag(holder);
        } else {
            holder = (ViewHolder) convertView.getTag();
        }
        holder.questionQueryTitle.setText(item.getProblemName());
        if (null != item.getPeisbch() && !item.getPeisbch().equals("")) {
            holder.questionQueryDetail.setText("配送波次号：" + item.getPeisbch() + "");
        } else {
            holder.questionQueryDetail.setText("" + item.getContent() + "");
        }
        if (null != item.getSerialNumber() && !item.getSerialNumber().equals("")) {
            holder.questionQuerySerialnumber.setText("流水号：" + item.getSerialNumber() + "");
        }

        if (item.getProblemType() == QualityBackType.MACHINE_PROBLEM.getIndex()) {
            holder.questionQuerySerialnumber.setVisibility(View.GONE);
        }
        //状态为2已处理，其余为处理中
        if (item.getStatus() == 2) {
            holder.questionQueryImg
                    .setBackgroundResource(R.drawable.questionreport_hadprogress);
        } else {
            holder.questionQueryImg
                    .setBackgroundResource(R.drawable.questionreport_nowprogress);
        }
        //是否可以评价
        if (!item.getCanComment()
                || item.getStatus() != 2 //只有已处理才给显示评价
                || (item.getProblemType() != QualityBackType.PRODUCTION_PROBLEM.getIndex()
                && item.getProblemType() != QualityBackType.ARRIVAL_ERROR.getIndex()
                && item.getProblemType() != QualityBackType.CABINET_PROBLEM.getIndex()
                && item.getProblemType() != QualityBackType.SUGGESTION.getIndex())) {
            holder.questionQueryEvaluationBtnLl.setVisibility(View.GONE);
        } else {
            holder.questionQueryEvaluationBtnLl.setVisibility(View.VISIBLE);
            holder.questionQueryEvaluationRb.setRating(4);//星级
            holder.questionQueryEvaluationTv.setText(setEvaluationTxt(4));
            //显示EditText输入框默认提示文字（不同星级，文字不同
            holder.questionQueryEvaluationEt.setHint(getInputHint(4));
        }
        //是否已评价
        if (item.getHasComment()) {
            holder.questionQueryEvaluationSubmitLl.setVisibility(View.GONE);
            holder.questionQueryEvaluationBtnLl.setVisibility(View.VISIBLE);
            holder.questionQueryEvaluation.setText("已评价");
            holder.questionQueryEvaluation.setTextColor(ContextCompat.getColor(context, R.color.common_txt_color));
            holder.questionQueryEvaluationEt.setText(item.getPjContent());
            holder.questionQueryEvaluationEt.setFocusable(!item.getHasComment());//若已评价，就把焦点false掉，禁止输入
            holder.questionQueryEvaluationRb.setIsIndicator(item.getHasComment());//已评价就不能再修改星级栏了，indicator属性应为true了
            holder.questionQueryEvaluationRb.setRating(item.getPj());//星级
            holder.questionQueryEvaluationTv.setText(setEvaluationTxt(item.getPj()));
        }
        holder.questionQueryEvaluation.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (!item.isOpen()) {
                    holder.questionQueryEvaluationLl.setVisibility(View.VISIBLE);
                    holder.questionQueryEvaluation.setCompoundDrawables(null, null, setRow(R.drawable.row_up), null);
                } else {
                    holder.questionQueryEvaluationLl.setVisibility(View.GONE);
                    holder.questionQueryEvaluation.setCompoundDrawables(null, null, setRow(R.drawable.row_down), null);
                }
                item.setOpen(!item.isOpen());
            }
        });
        //评星级变化监听
        holder.questionQueryEvaluationRb.setOnRatingBarChangeListener(new RatingBar.OnRatingBarChangeListener() {
            @Override
            public void onRatingChanged(RatingBar ratingBar, float rating, boolean fromUser) {
                if (rating < 1.0f) {//强制使最低为1星，不允许为0星
                    ratingBar.setRating(1.0f);
                }
                if (holder.questionQueryEvaluationRb.hasWindowFocus()) {
                    //只有在点击的时候才写入到数据源表里（这里必须用hasWindowFocus()，其它不行）
                    item.setPj(rating);
                    //根据星级同步改变满意度文字
                    holder.questionQueryEvaluationTv.setText(setEvaluationTxt(item.getPj()));
                    //显示EditText输入框默认提示文字（不同星级，文字不同
                    holder.questionQueryEvaluationEt.setHint(getInputHint((int) rating));
                }
            }
        });
        holder.questionQueryEvaluationEt.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence charSequence, int i, int i1, int i2) {


            }

            @Override
            public void onTextChanged(CharSequence charSequence, int i, int i1, int i2) {

            }

            @Override
            public void afterTextChanged(Editable s) {
                if (holder.questionQueryEvaluationEt.isFocused()) {
                    //这里必须用isFocused()，不要用hasWindowFocus()，要使它仅在输入时写入到List，排除滚动时。
                    item.setPjContent(holder.questionQueryEvaluationEt.getText().toString());
                }
            }
        });
        holder.questionQueryEvaluationSubmit.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //提交评价信息
                clickListener.queryProblemsAdapterClick(item);
            }
        });
        //问题批复列表
        if (null != item && !item.getReplys().isEmpty()) {
            ProblemsRepliesAdapter problemsRepliesAdapter = new ProblemsRepliesAdapter(context, item.getReplys());
            holder.queryProblemsRepliesLv.setAdapter(problemsRepliesAdapter);
        } else {
            holder.queryProblemsRepliesLl.setVisibility(View.GONE);
        }
        return convertView;
    }

    private Drawable setRow(int id) {
        Drawable drawable = ContextCompat.getDrawable(context, id);
        //必须设置图片大小，否则不显示
        drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
        return drawable;
    }

    private class ViewHolder {
        TextView questionQueryTitle;
        TextView questionQueryDetail;
        TextView questionQueryDate;
        TextView questionQueryImg;
        TextView questionQuerySerialnumber;
        TextView questionQueryEvaluation;
        LinearLayout questionQueryEvaluationBtnLl;
        TextView questionQueryEvaluationTv;
        TextView questionQueryEvaluationSubmit;
        LinearLayout questionQueryEvaluationLl;
        LinearLayout questionQueryEvaluationSubmitLl;
        EditText questionQueryEvaluationEt;
        RatingBar questionQueryEvaluationRb;
        LinearLayout queryProblemsRepliesLl;
        ListViewForScrollView queryProblemsRepliesLv;

        ViewHolder(View convertView) {
            questionQueryImg = (TextView) convertView.findViewById(R.id.question_query_img);
            questionQueryDate = (TextView) convertView.findViewById(R.id.question_query_date);
            questionQueryDetail = (TextView) convertView.findViewById(R.id.question_query_detail);
            questionQueryTitle = (TextView) convertView.findViewById(R.id.question_query_title);
            questionQuerySerialnumber = (TextView) convertView.findViewById(R.id.question_query_serialnumber);
            questionQueryEvaluation = (TextView) convertView.findViewById(R.id.question_query_evaluation);
            questionQueryEvaluationBtnLl = (LinearLayout) convertView.findViewById(R.id.question_query_evaluation_btn_ll);
            questionQueryEvaluationLl = (LinearLayout) convertView.findViewById(R.id.question_query_evaluation_ll);
            questionQueryEvaluationSubmitLl = (LinearLayout) convertView.findViewById(R.id.question_query_evaluation_submit_ll);
            questionQueryEvaluationTv = (TextView) convertView.findViewById(R.id.question_query_evaluation_tv);
            questionQueryEvaluationEt = (EditText) convertView.findViewById(R.id.question_query_evaluation_et);
            questionQueryEvaluationSubmit = (TextView) convertView.findViewById(R.id.question_query_evaluation_submit);
            questionQueryEvaluationRb = (RatingBar) convertView.findViewById(R.id.question_query_evaluation_rb);

            queryProblemsRepliesLl = (LinearLayout) convertView.findViewById(R.id.query_problems_replies_ll);
            queryProblemsRepliesLv = (ListViewForScrollView) convertView.findViewById(R.id.query_problems_replies_lv);
        }
    }

    private String setEvaluationTxt(float pj) {
        String[] evaluationTxt = {"不满意", "不满意", "一般", "满意", "非常满意"};
        int rank;
        try {
            rank = (int) pj;
        } catch (Exception e) {
            rank = 4;
        }
        return evaluationTxt[rank];
    }

    /**
     * 通过星级来返回输入框的提示文字
     *
     * @return 提示文字
     */
    private String getInputHint(int ratingNum) {
        String inputHint = "";
        switch (ratingNum) {
            case 0:
            case 1:
            case 2:
                inputHint = "提出你的意见，我们会努力改进";
                break;
            case 3:
            case 4:
                inputHint = "有更好的建议，也可以提交给我们";
                break;
            default:
        }
        return inputHint;
    }
}