package com.wgmf.yxgj.module.business.reportproblem.ui;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.BaseAdapter;
import android.widget.TextView;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.tools.PrefTool;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.Prefs;
import com.wgmf.yxgj.module.business.reportproblem.R;
import com.wgmf.yxgj.module.business.reportproblem.model.LogisticsTelPhoneNumberEntity;
import com.wgmf.yxgj.module.business.reportproblem.service.ReportFeedbackService;
import com.wgmf.yxgj.publics.ui.SelectorBaseActivity;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.LinkedList;

/**
 * 反馈直通车：物流问题联系人列表
 */
public class TelLogisticsActivity extends SelectorBaseActivity {
    private TelLogisticsAdapter telLogisticsAdapter;
    private ArrayList<LogisticsTelPhoneNumberEntity> childrenlistItem;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getData();
    }

    private void getData() {
        PrefTool.setBooleanSave(this, Prefs.PRE_NOT_TO_BACKGROUD, false);
        if (null != userInfo) {
            showDialog();
            String storeId = userInfo.getOrganizationCode();
            ReportFeedbackService.getInstance().requestTelLogistics(storeId, TelLogisticsActivity.this);
        }
    }

    @Override
    public void initTitle() {
        super.initTitle();
        homeTitleText.setText("物流人员信息");
    }

    @Override
    protected void initContent() {
        super.initContent();
        childrenlistItem = new ArrayList<>();
        storeNameEt.setVisibility(View.GONE);
        telLogisticsAdapter = new TelLogisticsAdapter(this, childrenlistItem);
        mListView.setAdapter(telLogisticsAdapter);
        mListView.setOnItemClickListener(new OnItemClickListener() {

            @Override
            public void onItemClick(AdapterView<?> parent, View view,
                                    int position, long id) {
                PrefTool.setBooleanSave(TelLogisticsActivity.this,
                        Prefs.PRE_NOT_TO_BACKGROUD, true);
            }
        });
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            if (id == BusinessID.ReportFeedback.MSG_ON_STREAM_DEALPERSON) {
                final String msg = result.getInfo();
                if (result.isSuccessed()) {
                    Type listType = new TypeToken<LinkedList<LogisticsTelPhoneNumberEntity>>() {
                    }.getType();

                    Gson gson = new Gson();
                    LinkedList<LogisticsTelPhoneNumberEntity> resources = gson.fromJson(msg, listType);
                    childrenlistItem.addAll(resources);
                    telLogisticsAdapter.notifyDataSetChanged();
                } else {
                    if (!TextUtils.isEmpty(msg)) {
                        showMsg(msg);
                    }
                }
            }
        }
    }

    class TelLogisticsAdapter extends BaseAdapter {
        Context context;
        private ArrayList<LogisticsTelPhoneNumberEntity> childrenlistItem;

        TelLogisticsAdapter(Context context, ArrayList<LogisticsTelPhoneNumberEntity> childrenlistItem) {
            this.context = context;
            this.childrenlistItem = childrenlistItem;
        }

        @Override
        public int getCount() {
            return childrenlistItem.size();
        }

        @Override
        public Object getItem(int position) {
            return position;
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public View getView(final int position, View convertView,
                            ViewGroup parent) {
            if (null == convertView) {
                convertView = TelLogisticsActivity.this.getLayoutInflater()
                        .inflate(R.layout.logistics_telphone_list_item, null);
            }
            TextView principalPositionTxt = (TextView) convertView
                    .findViewById(R.id.principal_position_txt);
            TextView principalNameTxt = (TextView) convertView
                    .findViewById(R.id.principal_name_txt);
            TextView principalPhoneTxt = (TextView) convertView
                    .findViewById(R.id.principal_phone_txt);
            TextView principalMobileTxt = (TextView) convertView
                    .findViewById(R.id.principal_mobile_txt);
            TextView countryPrincipal1PositionTxt = (TextView) convertView
                    .findViewById(R.id.country_principal1_position_txt);
            TextView countryPrincipal1NameTxt = (TextView) convertView
                    .findViewById(R.id.country_principal1_Name_txt);
            TextView countryPrincipal1PhoneTxt = (TextView) convertView
                    .findViewById(R.id.country_principal1_phone_txt);
            TextView countryPrincipal1MobileTxt = (TextView) convertView
                    .findViewById(R.id.country_principal1_mobile_txt);
            TextView countryPrincipal2PositionTxt = (TextView) convertView
                    .findViewById(R.id.country_principal2_position_txt);
            TextView countryPrincipal2NameTxt = (TextView) convertView
                    .findViewById(R.id.country_principal2_name_txt);
            TextView countryPrincipal2MobileTxt = (TextView) convertView
                    .findViewById(R.id.country_principal2_mobile_txt);

            principalPositionTxt.setText(childrenlistItem.get(position)
                    .getPrincipalPosition());
            principalNameTxt.setText(childrenlistItem.get(position)
                    .getPrincipalName());
            principalPhoneTxt.setText(childrenlistItem.get(position)
                    .getPrincipalPhone());
            principalMobileTxt.setText(childrenlistItem.get(position)
                    .getPrincipalMobile());
            countryPrincipal1PositionTxt.setText(childrenlistItem.get(
                    position).getCountryPrincipal1Position());
            countryPrincipal1NameTxt.setText(childrenlistItem.get(position)
                    .getCountryPrincipal1Name());
            countryPrincipal1PhoneTxt.setText(childrenlistItem.get(position)
                    .getCountryPrincipal1Phone());
            countryPrincipal1MobileTxt.setText(childrenlistItem
                    .get(position).getCountryPrincipal1Mobile());
            countryPrincipal2PositionTxt.setText(childrenlistItem.get(
                    position).getCountryPrincipal2Position());
            countryPrincipal2NameTxt.setText(childrenlistItem.get(position)
                    .getCountryPrincipal2Name());
            countryPrincipal2MobileTxt.setText(childrenlistItem
                    .get(position).getCountryPrincipal2Mobile());

            principalPhoneTxt.setOnClickListener(new OnClickListener() {

                @Override
                public void onClick(View v) {
                    telPhone(childrenlistItem.get(position).getPrincipalPhone());
                }

            });
            principalMobileTxt.setOnClickListener(new OnClickListener() {

                @Override
                public void onClick(View v) {
                    telPhone(childrenlistItem.get(position)
                            .getPrincipalMobile());
                }

            });
            countryPrincipal1PhoneTxt
                    .setOnClickListener(new OnClickListener() {

                        @Override
                        public void onClick(View v) {
                            telPhone(childrenlistItem.get(position)
                                    .getCountryPrincipal1Phone());
                        }

                    });
            countryPrincipal1MobileTxt
                    .setOnClickListener(new OnClickListener() {

                        @Override
                        public void onClick(View v) {
                            telPhone(childrenlistItem.get(position)
                                    .getCountryPrincipal1Mobile());
                        }

                    });

            countryPrincipal2MobileTxt
                    .setOnClickListener(new OnClickListener() {

                        @Override
                        public void onClick(View v) {
                            telPhone(childrenlistItem.get(position)
                                    .getCountryPrincipal2Mobile());
                        }
                    });
            return convertView;
        }
    }

    private void telPhone(String work) {
        PrefTool.setBooleanSave(this, Prefs.PRE_NOT_TO_BACKGROUD, true);
        Uri telUri = Uri.parse("tel:" + work);
        Intent dial = new Intent(Intent.ACTION_DIAL, telUri);
        startActivity(dial);
    }
}