package com.wgmf.yxgj.module.business.reportproblem.ui.mechanicorder;

import android.os.Bundle;
import android.support.v4.content.ContextCompat;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.bumptech.glide.Glide;
import com.google.gson.Gson;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.module.business.reportproblem.R;
import com.wgmf.yxgj.module.business.reportproblem.model.MachineOrderResultList;
import com.wgmf.yxgj.module.business.reportproblem.service.ReportFeedbackService;
import com.xp.arouter.RouterParams;

import java.util.ArrayList;
import java.util.List;

@Route(path = RouterParams.URL_QUERYMECHANICORDERACTIVITY)
public class QueryMechanicOrderActivity extends BaseParentAct implements View.OnClickListener {

    private ListView reportModuleDetailContentLv;
    private ReportMechanicOrderListAdapter mReportModuleDetailAdapter;
    /**
     * 当前选择反馈处理状态位置
     */
    private int position;

    /**
     * 下标集合
     */
    private List<TextView> textViews;

    /**
     * tab集合
     */
    private List<ImageView> imageViews;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.fragment_report_mechanic_order_list);
        initView();
        initTitle();
        initTab();
        //从消息推送进来，直接进入已处理页面
        position= getIntent().getIntExtra("position",0);
    }

    @Override
    protected void onResume() {
        super.onResume();
        getData(position + "");
    }

    @Override
    protected void initTitle() {
        super.initTitle();
        homeTitleText.setText("查询工单进度");
        homeTitleBackLl.setVisibility(View.VISIBLE);
    }

    private void getData(String morOrderDealsFlag) {
        showDialog();
        ReportFeedbackService.getInstance().requestFindMachineOrderList(userInfo.getStaffId(), morOrderDealsFlag, this);
    }

    private void initView() {
        reportModuleDetailContentLv = (ListView) findViewById(R.id.report_module_detail_content_lv);
        //为列表添加空布局
        View emptyView = findViewById(R.id.public_list_view_empty_ll);
        ImageView publicListViewEmptyIv = (ImageView) findViewById(R.id.public_list_view_empty_iv);
        Glide.with(this).load(R.drawable.img_load_fail).asGif().into(publicListViewEmptyIv);
        reportModuleDetailContentLv.setEmptyView(emptyView);
        LinearLayout llReportModuleByProject = (LinearLayout) findViewById(R.id.ll_report_module_by_project);
        LinearLayout llReportModuleByStore = (LinearLayout) findViewById(R.id.ll_report_module_by_shop);
        /*
         * 声明标题栏的tab
         */
        TextView reportModuleByProjectTxt = (TextView) findViewById(R.id.report_module_by_project_txt);
        TextView reportModuleByStoreTxt = (TextView) findViewById(R.id.report_module_by_shop_txt);
        /*
         * 标题栏的下标
         */
        ImageView reportModuleByProjectImg = (ImageView) findViewById(R.id.report_module_by_project_img);
        ImageView reportModuleByStoreImg = (ImageView) findViewById(R.id.report_module_by_shop_img);
        llReportModuleByProject.setOnClickListener(this);
        llReportModuleByStore.setOnClickListener(this);
        // 装载控件到集合
        textViews = new ArrayList<>();
        textViews.add(reportModuleByProjectTxt);
        textViews.add(reportModuleByStoreTxt);
        imageViews = new ArrayList<>();
        imageViews.add(reportModuleByProjectImg);
        imageViews.add(reportModuleByStoreImg);
    }

    private void initTab() {
        textViews.get(0).setTextColor(getResources().getColor(R.color.normal_color));
        imageViews.get(0).setVisibility(View.VISIBLE);
        imageViews.get(0).setImageResource(R.color.normal_color);
    }

    private void setSelectedItem(int position) {
        for (int i = 0; i < imageViews.size(); i++) {
            imageViews.get(i).setImageResource(R.color.white);
            textViews.get(i).setTextColor(ContextCompat.getColor(this, R.color.black));
            imageViews.get(position).setVisibility(View.GONE);
        }
        imageViews.get(position).setVisibility(View.VISIBLE);
        imageViews.get(position).setImageResource(R.color.normal_color);
        textViews.get(position).setTextColor(ContextCompat.getColor(this, R.color.normal_child));
        textViews.get(position).getPaint().setFakeBoldText(true);
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.ReportFeedback.MSG_ON_FIND_MACHINE_ORDER_LIST: {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        MachineOrderResultList machineOrderResult = new Gson().fromJson(msg, MachineOrderResultList.class);
                        Log.d(TAG, "machineOrderResult=" + machineOrderResult.toString());
                        mReportModuleDetailAdapter = new ReportMechanicOrderListAdapter(this, machineOrderResult.getResultList());
                        reportModuleDetailContentLv.setAdapter(mReportModuleDetailAdapter);
                    } else {
                        showMsg(result.getResultInfo());
                    }
                }
                break;
                default:
                    break;
            }
        }
    }

    @Override
    public void onClick(View view) {
        if (view.getId() == R.id.ll_report_module_by_project) {
            position = 0;
        } else if (view.getId() == R.id.ll_report_module_by_shop) {
            position = 1;
        }
        this.setSelectedItem(position);
        getData(position + "");
    }
}
