package com.wgmf.library.utils;

import android.text.TextUtils;
import android.util.Log;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/**
 * 功能描述：日期操作类
 *
 * @author xiep
 */
@SuppressWarnings("all")
public class DateUtil {

    public static String FORMATDEFAULT = "yyyy-MM-dd";
    public static String FORMATTIME = "yyyy-MM-dd HH:mm";
    public static String FORMAT = "yyyy-MM-dd HH:mm:ss";

    /**
     * 功能描述：格式化日期
     *
     * @param dateStr String 字符型日期
     * @param format  String 格式
     * @return Date 日期
     */
    private static Date parseDate(String dateStr, String format) {
        Date date = null;
        try {
            DateFormat dateFormat = new SimpleDateFormat(format);
            String dt = dateStr.replaceAll("-", "/");
            if ((!dt.equals("")) && (dt.length() < format.length())) {
                dt += format.substring(dt.length()).replaceAll("[YyMmDdHhSs]",
                        "0");
            }
            date = dateFormat.parse(dt);
        } catch (Exception e) {
            Log.e("DateUtil", "parseDate: ", e);
        }
        return date;
    }

    /**
     * 功能描述：格式化日期
     *
     * @param dateStr String 字符型日期：YYYY-MM-DD 格式
     * @return Date
     */
    private static Date parseDate(String dateStr) {
        return parseDate(dateStr, "yyyy/MM/dd");
    }

    /**
     * 功能描述：格式化输出日期
     *
     * @param date   Date 日期
     * @param format String 格式
     * @return 返回字符型日期
     */
    public static String format(Date date, String format) {
        String result = "";
        try {
            if (date != null) {
                DateFormat dateFormat = new SimpleDateFormat(format);
                result = dateFormat.format(date);
            }
        } catch (Exception e) {
            Log.e("DateUtil", "format: ", e);
        }
        return result;
    }

    /**
     * @param date Date 日期
     * @return 格式化日期
     */
    public static String format(Date date) {
        return format(date, "yyyy/MM/dd");
    }

    /**
     * 功能描述：返回月份
     *
     * @param date Date 日期
     * @return 返回月份
     */
    public static int getMonth(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        return calendar.get(Calendar.MONTH) + 1;
    }

    /**
     * 功能描述：返回毫秒
     *
     * @param date 日期
     * @return 返回毫秒
     */
    public static long getMillis(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        return calendar.getTimeInMillis();
    }

    /**
     * 功能描述：返回字符型日期
     *
     * @param date 日期
     * @return 返回字符型日期 yyyy-MM-dd 格式
     */
    public static String getDate(Date date) {
        return format(date, "yyyy-MM-dd");
    }

    public static String getFormatNowMonthBegin() {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");

        // 获取前月的第一天
        Calendar c = Calendar.getInstance();
        c.add(Calendar.MONTH, 0);
        // 设置为1号,当前日期既为本月第一天
        c.set(Calendar.DAY_OF_MONTH, 1);

        return format.format(c.getTime());
    }

    /**
     * 功能描述：取得指定月份的第一天
     *
     * @param strdate String 字符型日期
     * @return String yyyy-MM-dd 格式
     */
    public static String getMonthBegin(String strdate) {
        Date date = parseDate(strdate);
        return format(date, "yyyy-MM") + "-01";
    }

    /**
     * @param date   日期
     * @param mMonth 月
     * @param nDay   日
     * @return 返回与指定日期相差mMonth月，nDay天的日期
     */
    public static Date getDayOfMonth(Date date, int mMonth, int nDay) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(calendar.get(Calendar.YEAR),
                calendar.get(Calendar.MONTH) + mMonth, nDay);
        return calendar.getTime();
    }

    /**
     * @param date 指定日期
     * @return 返回指定日期的月的第一天
     */
    public static Date getFirstDayOfMonth(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(calendar.get(Calendar.YEAR),
                calendar.get(Calendar.MONTH), 1);
        return calendar.getTime();
    }

    /**
     * 功能描述：取得指定月份的最后一天
     *
     * @param strdate String 字符型日期
     * @return String 日期字符串 yyyy-MM-dd格式
     */
    public static String getMonthEnd(String strdate) {
        Date date = parseDate(getMonthBegin(strdate));
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.add(Calendar.MONTH, 1);
        calendar.add(Calendar.DAY_OF_YEAR, -1);
        return formatDate(calendar.getTime());
    }

    /**
     * 功能描述：常用的格式化日期
     *
     * @param date Date 日期
     * @return String 日期字符串 yyyy-MM-dd格式
     */
    private static String formatDate(Date date) {
        return formatDateByFormat(date);
    }

    /**
     * 功能描述：以指定的格式来格式化日期
     *
     * @param date Date 日期
     * @return String 日期字符串
     */
    private static String formatDateByFormat(Date date) {
        String result = "";
        if (date != null) {
            try {
                SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                result = sdf.format(date);
            } catch (Exception e) {
                Log.e("DateUtil", "Error formatDateByFormat:", e);
            }
        }
        return result;
    }

    /**
     * @param format 日期格式
     * @param month  月份
     * @return 月份与当月的差数
     */
    public static String getFormatMonth(String format, int month) {
        Calendar c = Calendar.getInstance();
        c.add(Calendar.MONTH, month);
        return new SimpleDateFormat(format).format(c.getTime());
    }

    /**
     * 日期格式转换
     *
     * @param from 初始日期格式
     */
    public static String getFormatMonthFromTo(String from) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM");
        String ntime = from;
        try {
            Date timee = sdf.parse(from);
            ntime = sdf.format(timee);
        } catch (ParseException e) {
            Log.e("DateUtil", "string2Date: ", e);
        }
        return ntime;
    }

    /**
     * 根据自定义格式返回当前时间
     *
     * @param format yyMMddHHmmss等格式可自定义
     * @return
     */
    public static String getFormatCurrentDate(String format) {
        SimpleDateFormat formatter = new SimpleDateFormat(format);
        Date curDate = new Date(System.currentTimeMillis());
        return formatter.format(curDate);
    }

    /**
     * @param str 一定格式的时间
     * @return 将一定格式的时间字符串转换成Date
     */
    public static Date string2Date(String str, String format) {
        SimpleDateFormat sdf = new SimpleDateFormat(format);
        Date date = null;
        try {
            date = sdf.parse(str);
        } catch (ParseException e) {
            Log.e("DateUtil", "string2Date: ", e);
        }
        return date;
    }

    /**
     * 将一定格式的时间字符串转换成Date
     *
     * @param str 一定格式的时间
     * @return
     */
    public static Date String2Date(String str, String format) {
        if (TextUtils.isEmpty(str)) return null;
        SimpleDateFormat sdf = new SimpleDateFormat(format);
        Date date = null;
        try {
            date = sdf.parse(str);
        } catch (ParseException e) {

        }
        return date;
    }

    /**
     * @param date 日期
     * @return 把日期转为字符串
     */
    public static String Date2String(Date date, String format) {
        SimpleDateFormat sdf = new SimpleDateFormat(format);
        return new SimpleDateFormat(format).format(date);
    }

    /**
     * @param date 日期
     * @return 把日期转为字符串
     */
    public static String converToString(Date date) {
        return new SimpleDateFormat("yyyy-MM-dd").format(date);
    }

    /**
     * @param sdate 开始的日期
     * @param edate 结束的日期
     * @return 两个日期相差的天数
     */
    public static int timeBetween(Date sdate, Date edate) {
        Calendar cal = Calendar.getInstance();
        cal.setTime(sdate);
        // 开始的时间
        long time1 = cal.getTimeInMillis();
        cal.setTime(edate);
        // 结束的时间
        long time2 = cal.getTimeInMillis();
        long betweenTimes = (time2 - time1);
        return (int) betweenTimes;
    }
    /**
     * @param sdate 开始的日期
     * @param edate 结束的日期
     * @return 两个日期相差的天数
     */
    public static int daysBetween(Date sdate, Date edate) {
        Calendar cal = Calendar.getInstance();
        cal.setTime(sdate);
        // 开始的时间
        long time1 = cal.getTimeInMillis();
        cal.setTime(edate);
        // 结束的时间
        long time2 = cal.getTimeInMillis();
        long betweenDays = (time2 - time1) / (1000 * 3600 * 24);
        return (int) betweenDays;
    }

    public static int getNowYear() {
        Calendar calendar = Calendar.getInstance();
        return calendar.get(Calendar.YEAR);
    }

    public static int getNowMonth() {
        Calendar calendar = Calendar.getInstance();
        // 获得当前时间的月份，月份从0开始所以结果要加1
        // 配合月份adapter
        return calendar.get(Calendar.MONTH);
    }

    public static Date getNowMonthNext() {
        // 得到一个Calendar的实例
        Calendar ca = Calendar.getInstance();
        // 设置时间为当前选中时间
        ca.setTime(string2Date(getFormatCurrentDate("yyyy-MM"), "yyyy-MM"));
        ca.add(Calendar.MONTH, 0);
        return ca.getTime();
    }

    /**
     * 根据年 月 获取对应的月份 天数
     */
    public static int getDaysByYearMonth(int year, int month) {
        Calendar a = Calendar.getInstance();
        a.set(Calendar.YEAR, year);
        a.set(Calendar.MONTH, month - 1);
        a.set(Calendar.DATE, 1);
        a.roll(Calendar.DATE, -1);
        return a.get(Calendar.DATE);
    }


    /**
     * 判断当前日期是星期几
     *
     * @param pTime 要判断的时间
     * @return dayForWeek 判断结果
     */
    public static int dayForWeek(String pTime) throws Exception {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        Calendar c = Calendar.getInstance();
        c.setTime(format.parse(pTime));
        int dayForWeek;
        if (c.get(Calendar.DAY_OF_WEEK) == Calendar.MONDAY) {
            dayForWeek = 7;
        } else {
            dayForWeek = c.get(Calendar.DAY_OF_WEEK) - 1;
        }
        return dayForWeek;
    }

    /**
     * 日期增加一年
     *
     * @param date 基础日期
     * @return nextYear 基础日期增加一年
     */
    public static String getNextYear(String date) throws Exception {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        Calendar cal = Calendar.getInstance();
        cal.setTime(format.parse(date));//设置起时间
        cal.add(Calendar.YEAR, 1);//增加一年
        String nextYear = converToString(cal.getTime());
        System.out.println("输出::" + nextYear);
        return nextYear;
    }
}