package com.wgmf.library.utils;

import android.content.Context;
import android.util.Log;

import com.amap.api.location.AMapLocation;
import com.amap.api.location.AMapLocationClient;
import com.amap.api.location.AMapLocationClientOption;
import com.amap.api.location.AMapLocationListener;
import com.wgmf.library.global.LocationParams;

/**
 * @author xiep on 2016/7/15 18:24
 */
@SuppressWarnings("all")
public class LocationUtil {
    public interface OnCallback {
        void onFinish(String longitude, String latitude, String address, String city, int code, String error);

    }

    private OnCallback mOnCallback;
    private AMapLocationClient mLocationClient;

    public LocationUtil(Context cxt, OnCallback callback) {
        Context mContext = cxt;
        mOnCallback = callback;
        // 高精度定位模式：会同时使用网络定位和GPS定位，优先返回最高精度的定位结果；
        // 低功耗定位模式：不会使用GPS，只会使用网络定位（Wi-Fi和基站定位）；
        // 仅用设备定位模式：不需要连接网络，只使用GPS进行定位，这种模式下不支持室内环境的定位。

        // 初始化定位
        mLocationClient = new AMapLocationClient(mContext.getApplicationContext());
        // 初始化定位参数
        AMapLocationClientOption mLocationOption = new AMapLocationClientOption();
        // 设置定位模式为高精度模式，Battery_Saving为低功耗模式，Device_Sensors是仅设备模式
        mLocationOption.setLocationMode(AMapLocationClientOption.AMapLocationMode.Hight_Accuracy);
        // 设置是否返回地址信息（默认返回地址信息）
        mLocationOption.setNeedAddress(true);
        // 设置是否只定位一次,默认为false
        mLocationOption.setOnceLocation(false);
        // 设置是否强制刷新WIFI，默认为强制刷新
        mLocationOption.setWifiActiveScan(true);
        // 设置是否允许模拟位置,默认为false，不允许模拟位置
        mLocationOption.setMockEnable(false);
        // 设置定位间隔,单位毫秒,默认为2000ms
        mLocationOption.setInterval(2000);
        AMapLocationListener mLocationListener = new AMapLocationListener() {
            @Override
            public void onLocationChanged(AMapLocation amapLocation) {
                if (amapLocation != null) {
                    // 1 GPS定位结果
                    // 2 返回上次定位结果
                    // 4 缓存定位结果
                    // 5 Wifi定位结果
                    // 6 基站定位结果
                    if (amapLocation.getErrorCode() == 0) {
                        Log.i("Amap", "amapLocation:" + amapLocation.toStr());
                        LocationParams.Longitude = String.valueOf(amapLocation.getLongitude());
                        LocationParams.Latitude = String.valueOf(amapLocation.getLatitude());
                        LocationParams.Address = amapLocation.getAddress();
                        LocationParams.city = amapLocation.getCity();
                        // // 定位成功回调信息，设置相关消息
                        // amapLocation.getLocationType();//
                        // 获取当前定位结果来源，如网络定位结果，详见定位类型表
                        // amapLocation.getLatitude();// 获取纬度
                        // amapLocation.getLongitude();// 获取经度
                        // amapLocation.getAccuracy();// 获取精度信息
                        // SimpleDateFormat df = new
                        // SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                        // Date date = new Date(amapLocation.getTime());
                        // df.format(date);// 定位时间
                        // amapLocation.getAddress();//
                        // 地址，如果option中设置isNeedAddress为false，则没有此结果
                        // amapLocation.getCountry();// 国家信息
                        // amapLocation.getProvince();// 省信息
                        // amapLocation.getCity();// 城市信息
                        // amapLocation.getDistrict();// 城区信息
                        // amapLocation.getRoad();// 街道信息
                        // amapLocation.getCityCode();// 城市编码
                        // amapLocation.getAdCode();// 地区编码
                    } else {
                        // 显示错误信息ErrCode是错误码，errInfo是错误信息，详见错误码表。
                        Log.e("Amap", "location Error, ErrCode:" + amapLocation.getErrorCode() + ", errInfo:" + amapLocation.getErrorInfo());
                    }
                    if (null != mOnCallback) {
                        mOnCallback.onFinish(LocationParams.Longitude, LocationParams.Latitude, LocationParams.Address, LocationParams.city, amapLocation.getErrorCode(), amapLocation.getErrorInfo());
                    }
                    // 停止定位
                    mLocationClient.stopLocation();
                    // 销毁定位客户端
                    mLocationClient.onDestroy();
                } else {
                    Log.e("Amap", "onLocationChanged null");
                }
            }

        };
        mLocationClient.setLocationListener(mLocationListener);
        // 给定位客户端对象设置定位参数
        mLocationClient.setLocationOption(mLocationOption);
        // 启动定位
        mLocationClient.startLocation();
        Log.i("Amap", "mLocationClient.startLocation()");
    }

    private static double EARTH_RADIUS = 6378.137;

    private static double rad(double d) {
        return d * Math.PI / 180.0;
    }

    /**
     * 通过经纬度获取距离(单位：米)
     */
    public static double getDistance(double lat1, double lng1, double lat2, double lng2) {
        double radLat1 = rad(lat1);
        double radLat2 = rad(lat2);
        double a = radLat1 - radLat2;
        double b = rad(lng1) - rad(lng2);
        double s = 2 * Math.asin(Math.sqrt(Math.pow(Math.sin(a / 2), 2)
                + Math.cos(radLat1) * Math.cos(radLat2)
                * Math.pow(Math.sin(b / 2), 2)));
        s = s * EARTH_RADIUS;
        s = Math.round(s * 10000d) / 10000d;
        s = s * 1000;
        return s;
    }

    /**
     * @param distance 距离单位米
     * @return 大于1千米显示单位为千米，否则单位为米
     */
    public static String setDistanceUint(double distance) {
        String dis;
        if (distance >= 1000) {
            return dis = distance / 1000 + "千米";
        } else {
            return dis = distance + "米";
        }
    }
}