package com.wgmf.library.utils;

import android.os.Handler;
import android.os.Looper;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/**
 * 线程池工具类
 * @author xiep on 2017/2/22 09:14
 */
@SuppressWarnings("all")
public class ThreadUtils {

    private static ExecutorService threadPool = Executors.newCachedThreadPool();

    private static Handler sMainHandler = new Handler(Looper.getMainLooper());

    /**
     * 非UI线程执行
     *
     * @param runnable
     */
    public static void runOnNonUiThread(Runnable runnable) {
        threadPool.submit(runnable);
    }

    /**
     * UI线程执行
     *
     * @param runnable
     */
    public static void runOnUiThread(Runnable runnable) {
        sMainHandler.post(runnable);
    }

    public static void postDelayedOnUiThread(Runnable runnable, long delayMillis) {
        sMainHandler.postDelayed(runnable, delayMillis);
    }

    public static boolean isMainThread() {
        return Looper.myLooper() == Looper.getMainLooper();
    }

    /**
     * 获取当前线程名称
     */
    public static String getCurrentThreadName() {
        String result = "UNKOWN";
        Looper looper = Looper.myLooper();
        if (looper != null) {
            result = looper.getThread().getName();
        }
        return result;
    }

    public static Handler getsMainHandler() {
        return sMainHandler;
    }
}